@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * module_manager.cc
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -106,37 +106,40 @@ void GSStatusReporter::statusUpdate(double dltotal,
 {
 	if (!dltotal)
 		return;
-	double filefraction  = (dlnow / dltotal);
+	double filefraction = (dlnow / dltotal);
 	update_install_progress(filefraction);
 }
 
-
-ModuleManager::ModuleManager() {
+ModuleManager::ModuleManager()
+	: mgr(NULL),
+	  list_mgr(NULL),
+	  installMgr(NULL)
+{
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	baseDir = (envhomedir) ? envhomedir : ".";
 	baseDir += "/" DOTSWORD "/InstallMgr";
 	statusReporter = new GSStatusReporter();
 }
 
-ModuleManager::~ModuleManager() {
-
+ModuleManager::~ModuleManager()
+{
 }
 
-char *backend_mod_mgr_get_config_entry(const char *module_name,
-				       const char *entry) {
-	SWModule *mod;
-	ModMap::iterator it;	//-- iteratior
-	//-- iterate through the modules until we find modName
+char *backend_mod_mgr_get_config_entry(char *module_name,
+				       const char *entry)
+{
+	ModMap::iterator it; //-- iteratior
+
 	it = mgr->Modules.find(module_name);
-	//-- if we find the module
 	if (it != mgr->Modules.end()) {
-		mod = (*it).second;
-		return g_strdup((char *) mod->getConfigEntry(entry));
+		SWModule *mod = (*it).second;
+		return g_strdup((char *)mod->getConfigEntry(entry));
 	} else
 		return NULL;
 }
 
-int backend_mod_mgr_is_module(const char *mod_name) {
+int backend_mod_mgr_is_module(const char *mod_name)
+{
 	ModMap::iterator it = mgr->Modules.find(mod_name);
 	if (it != mgr->Modules.end()) {
 		return 1;
@@ -163,15 +166,21 @@ int backend_mod_mgr_is_module(const char *mod_name) {
 MOD_MGR *backend_module_mgr_get_next_module(void)
 {
 	MOD_MGR *mod_info = NULL;
-	SWModule *module;
 
 	if (list_it != list_end) {
-		module = list_it->second;
+		SWModule *module = list_it->second;
 		mod_info = g_new(MOD_MGR, 1);
-		const gchar *name = module->getName();
+		gchar *name = g_strdup(module->getName());
 
 		if (name) {
 			mod_info->name = g_strdup(name);
+
+			mod_info->abbreviation = (char *)module->getConfigEntry("Abbreviation");
+			if (mod_info->abbreviation) {
+				mod_info->abbreviation = g_strdup(mod_info->abbreviation);
+				main_add_abbreviation(mod_info->name, mod_info->abbreviation);
+			}
+
 			mod_info->language =
 			    main_get_language_map(module->getLanguage());
 			mod_info->type = g_strdup(module->getType());
@@ -185,12 +194,12 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 				int isize = atoi(installsize);
 				char *num;
 				// round to nearest M or k.
-				if (isize > (3*1024*1024)) {
-					num = main_format_number((isize+(512*1024))/(1024*1024));
+				if (isize > (3 * 1024 * 1024)) {
+					num = main_format_number((isize + (512 * 1024)) / (1024 * 1024));
 					mod_info->installsize =
 					    g_strdup_printf("%sM", num);
 				} else {
-					num = main_format_number((isize+512)/1024);
+					num = main_format_number((isize + 512) / 1024);
 					mod_info->installsize =
 					    g_strdup_printf("%sk", num);
 				}
@@ -202,8 +211,8 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 			mod_info->is_devotional = (feature && !strcmp(feature, "DailyDevotion"));
 
 			char *category = (char *)module->getConfigEntry("Category");
-			mod_info->is_maps     = (category && !strcmp(category, "Maps"));
-			mod_info->is_images   = (category && !strcmp(category, "Images"));
+			mod_info->is_maps = (category && !strcmp(category, "Maps"));
+			mod_info->is_images = (category && !strcmp(category, "Images"));
 			mod_info->is_glossary = (category && !strcmp(category, "Glossaries"));
 			mod_info->is_cult =
 			    (category &&
@@ -216,15 +225,15 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 			mod_info->description = g_strdup(module->getDescription());
 			mod_info->locked =
 			    ((module->getConfigEntry("CipherKey")) ? 1 : 0);
-			list_it++;
-			return (MOD_MGR *) mod_info;
+			++list_it;
+			g_free(name);
+			return (MOD_MGR *)mod_info;
 		}
 	}
-        g_free(mod_info);
+	g_free(mod_info);
 	return NULL;
 }
 
-
 /******************************************************************************
  * Name
  *   backend_module_mgr_remote_list_modules
@@ -254,7 +263,6 @@ void backend_module_mgr_remote_list_modules_init(const char *sourceName)
 	list_end = source->second->getMgr()->Modules.end();
 }
 
-
 /******************************************************************************
  * Name
  *   backend_module_mgr_list_local_modules
@@ -273,14 +281,13 @@ void backend_module_mgr_remote_list_modules_init(const char *sourceName)
 
 void backend_module_mgr_list_local_modules_init(bool for_install)
 {
-        if (for_install){
-                list_it = list_mgr->Modules.begin();
-                list_end = list_mgr->Modules.end();
-        }
-        else{
-                list_it = mgr->Modules.begin();
-                list_end = mgr->Modules.end();
-        }
+	if (for_install) {
+		list_it = list_mgr->Modules.begin();
+		list_end = list_mgr->Modules.end();
+	} else {
+		list_it = mgr->Modules.begin();
+		list_end = mgr->Modules.end();
+	}
 }
 
 /******************************************************************************
@@ -304,7 +311,7 @@ int backend_uninstall_module(const char *dir,
 			     const char *modName)
 {
 	SWModule *module;
-	SWMgr  *tmp_mgr;
+	SWMgr *tmp_mgr;
 	int retval = -1;
 	if (dir)
 		tmp_mgr = new SWMgr(dir);
@@ -314,7 +321,7 @@ int backend_uninstall_module(const char *dir,
 	ModMap::iterator it = tmp_mgr->Modules.find(modName);
 	if (it == tmp_mgr->Modules.end()) {
 		printf("Couldn't find module [%s] to remove\n",
-			modName);
+		       modName);
 		return -1;
 	}
 	module = it->second;
@@ -323,7 +330,6 @@ int backend_uninstall_module(const char *dir,
 	return retval;
 }
 
-
 /******************************************************************************
  * Name
  *   backend_remote_install_module
@@ -349,7 +355,7 @@ int backend_remote_install_module(const char *destdir,
 	    installMgr->sources.find(sourceName);
 	if (source == installMgr->sources.end()) {
 		printf("Couldn't find remote source [%s]\n",
-			sourceName);
+		       sourceName);
 		return -1;
 	}
 	InstallSource *is = source->second;
@@ -357,9 +363,8 @@ int backend_remote_install_module(const char *destdir,
 	ModMap::iterator it = rmgr->Modules.find(modName);
 	if (it == rmgr->Modules.end()) {
 		printf("Remote source [%s] does not make available module [%s]\n",
-			sourceName, modName);
+		       sourceName, modName);
 		return -1;
-
 	}
 
 	SWMgr dmgr((destdir ? destdir : settings.path_to_mods),
@@ -367,7 +372,6 @@ int backend_remote_install_module(const char *destdir,
 	return installMgr->installModule(&dmgr, 0, modName, is);
 }
 
-
 /******************************************************************************
  * Name
  *   backend_local_install_module
@@ -388,12 +392,11 @@ int backend_local_install_module(const char *destdir,
 				 const char *srcdir,
 				 const char *mod_name)
 {
-        SWMgr lmgr((destdir ? destdir : settings.path_to_mods),
+	SWMgr lmgr((destdir ? destdir : settings.path_to_mods),
 		   true, 0, false, false);
 	return installMgr->installModule(&lmgr, srcdir, mod_name);
 }
 
-
 /******************************************************************************
  * Name
  *   backend_module_mgr_list_remote_sources
@@ -412,22 +415,21 @@ int backend_local_install_module(const char *destdir,
 
 GList *backend_module_mgr_list_remote_sources(void)
 {
-	MOD_MGR_SOURCE *mms;
 	GList *retval = NULL;
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	SWBuf baseDir = (envhomedir) ? envhomedir : ".";
 	baseDir += "/" DOTSWORD "/InstallMgr";
+
 	InstallMgr *inst_mgr = new InstallMgr(baseDir,
 					      (StatusReporter *)0,
-					      (SWBuf)"ftp",
-					      (SWBuf)"xiphos@xiphos.org"
-					      );
+					      (SWBuf) "ftp",
+					      (SWBuf) ftp_password());
 	inst_mgr->setUserDisclaimerConfirmed(true);
 
 	for (InstallSourceMap::iterator it =
-	     inst_mgr->sources.begin();
-	     it != inst_mgr->sources.end(); it++) {
-		mms = g_new(MOD_MGR_SOURCE, 1);
+		 inst_mgr->sources.begin();
+	     it != inst_mgr->sources.end(); ++it) {
+		MOD_MGR_SOURCE *mms = g_new(MOD_MGR_SOURCE, 1);
 		mms->caption = g_strdup(it->second->caption);
 		mms->type = g_strdup(it->second->type);
 		mms->source = g_strdup(it->second->source);
@@ -435,13 +437,12 @@ GList *backend_module_mgr_list_remote_sources(void)
 		mms->user = g_strdup(it->second->u);
 		mms->pass = g_strdup(it->second->p);
 		mms->uid = g_strdup(it->second->uid);
-		retval = g_list_append(retval, (MOD_MGR_SOURCE *) mms);
+		retval = g_list_append(retval, (MOD_MGR_SOURCE *)mms);
 	}
 	delete inst_mgr;
 	return retval;
 }
 
-
 /******************************************************************************
  * Name
  *   backend_module_mgr_list_local_sources
@@ -460,12 +461,11 @@ GList *backend_module_mgr_list_remote_sources(void)
 
 GList *backend_module_mgr_list_local_sources(void)
 {
-	MOD_MGR_SOURCE *mms;
 	GList *retval = NULL;
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	SWBuf confPath = (envhomedir) ? envhomedir : ".";
 	confPath += "/" DOTSWORD "/InstallMgr/InstallMgr.conf";
-	SWConfig *installConf= new SWConfig(confPath.c_str());
+	SWConfig *installConf = new SWConfig(confPath.c_str());
 
 	SectionMap::iterator sourcesSection;
 	ConfigEntMap::iterator sourceBegin;
@@ -477,9 +477,9 @@ GList *backend_module_mgr_list_local_sources(void)
 		sourceEnd = sourcesSection->second.upper_bound("DIRSource");
 
 		while (sourceBegin != sourceEnd) {
-			mms = g_new(MOD_MGR_SOURCE, 1);
+			MOD_MGR_SOURCE *mms = g_new(MOD_MGR_SOURCE, 1);
 			InstallSource *is = new InstallSource("DIR",
-					sourceBegin->second.c_str());
+							      sourceBegin->second.c_str());
 			mms->caption = is->caption;
 			mms->type = is->type;
 			mms->source = is->source;
@@ -487,15 +487,14 @@ GList *backend_module_mgr_list_local_sources(void)
 			mms->user = is->u;
 			mms->pass = is->p;
 			mms->uid = is->uid;
-			retval = g_list_append(retval,(MOD_MGR_SOURCE*) mms);
-			sourceBegin++;
+			retval = g_list_append(retval, (MOD_MGR_SOURCE *)mms);
+			++sourceBegin;
 		}
 	}
 	delete installConf;
 	return retval;
 }
 
-
 /******************************************************************************
  * Name
  *   backend_module_mgr_refresh_remote_source
@@ -518,7 +517,7 @@ int backend_module_mgr_refresh_remote_source(const char *sourceName)
 
 	if (source == installMgr->sources.end()) {
 		printf("Couldn't find remote source [%s]\n",
-			sourceName);
+		       sourceName);
 		return 1;
 	}
 	installMgr->refreshRemoteSource(source->second);
@@ -639,7 +638,6 @@ void backend_module_mgr_reread_config(void)
 	installMgr->readInstallConf();
 }
 
-
 /******************************************************************************
  * Name
  *   backend_module_mgr_add_source
@@ -663,14 +661,14 @@ void backend_module_mgr_reread_config(void)
  *   void
  */
 
-void backend_module_mgr_add_source(const char * vtype,
-				   const char * type,
-				   const char * caption,
-				   const char * source,
-				   const char * directory,
-				   const char * user,
-				   const char * pass,
-				   const char * uid)
+void backend_module_mgr_add_source(const char *vtype,
+				   const char *type,
+				   const char *caption,
+				   const char *source,
+				   const char *directory,
+				   const char *user,
+				   const char *pass,
+				   const char *uid)
 {
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	SWBuf confPath = (envhomedir) ? envhomedir : ".";
@@ -687,7 +685,7 @@ void backend_module_mgr_add_source(const char * vtype,
 	is.p = pass;
 	is.uid = uid;
 	config.Sections["Sources"].insert(ConfigEntMap::value_type(vtype,
-		is.getConfEnt().c_str()));
+								   is.getConfEnt().c_str()));
 	config.Save();
 }
 
@@ -711,35 +709,35 @@ void backend_init_module_mgr(const char *dir,
 			     gboolean augment,
 			     gboolean regular)
 {
-	// complicated overloading just to init a swmgr.
-	// beyond the directory, we send in 3 defaults plus "something."
-	// autoload    -> true
-	// filtermgr   -> null (0)
-	// multimod    -> false
-	// AUGMENTHOME -> are we setting the regular mgr?
-	//                then "as sent" ([a] total list or [b] per-area list)
-	//		  else "false for local install" (always per-area)
+// complicated overloading just to init a swmgr.
+// beyond the directory, we send in 3 defaults plus "something."
+// autoload    -> true
+// filtermgr   -> null (0)
+// multimod    -> false
+// AUGMENTHOME -> are we setting the regular mgr?
+//                then "as sent" ([a] total list or [b] per-area list)
+//		  else "false for local install" (always per-area)
 
-#ifdef DEBUG
+#ifdef CHATTY
 	GTimer *t;
 	double d;
 	t = g_timer_new();
 #endif
 
-	if (regular) {		// use main (regular) swmgr.
+	if (regular) { // use main (regular) swmgr.
 		if (mgr)
 			delete mgr;
-	        mgr = new SWMgr(dir, true, 0, false, augment);
+		mgr = new SWMgr(dir, true, 0, false, augment);
 	} else {
 		if (list_mgr)
 			delete list_mgr;
 		list_mgr = new SWMgr(dir, true, 0, false, false);
 	}
 
-#ifdef DEBUG
+#ifdef CHATTY
 	g_timer_stop(t);
 	d = g_timer_elapsed(t, NULL);
-	GS_message(("create SWMgr time is %f", d));
+	XI_message(("create SWMgr time is %f", d));
 #endif
 
 	const gchar *envhomedir = g_getenv(HOMEVAR);
@@ -752,8 +750,8 @@ void backend_init_module_mgr(const char *dir,
 		delete installMgr;
 	installMgr = new InstallMgr(baseDir,
 				    statusReporter,
-				    (SWBuf)"ftp",
-				    (SWBuf)"xiphos@xiphos.org");
+				    (SWBuf) "ftp",
+				    (SWBuf) ftp_password());
 	installMgr->setUserDisclaimerConfirmed(true);
 }
 
@@ -800,6 +798,6 @@ void backend_shut_down_module_mgr(void)
 	installMgr = NULL;
 	delete mgr;
 	mgr = NULL;
-        delete list_mgr;
+	delete list_mgr;
 	list_mgr = NULL;
 }
