@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * link_dialog.f - dialog for inserting a link
  *
- * Copyright (C) 2005-2014 Xiphos Developer Team
+ * Copyright (C) 2005-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,31 +23,27 @@
 #define _LINK_DIALOG_H
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 #include <config.h>
 #include <glib.h>
 
-
-#ifdef USE_WEBKIT_EDITOR	
+#ifdef USE_WEBKIT_EDITOR
 #include "editor/webkit_editor.h"
 #include "editor/editor.h"
 #else
 #include "editor/slib-editor.h"
 #endif
 
-
-void editor_link_dialog (EDITOR *e);
+void editor_link_dialog(EDITOR *e);
 void entry_verse_changed_cb(GObject *object, EDITOR *e);
 void button_ok_clicked_cb(GObject *object, EDITOR *e);
 void button_test_clicked_cb(GObject *object, gpointer user_data);
-void button_cancel_clicked_cb(GObject *object, gpointer user_data);
-
+void button_cancel_clicked_cb(GObject *object,
+			      gpointer user_data);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _LINK_DIALOG_H */
