@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * slib-editor.h - the html editor using gtkhtml-editor (slib)
  *
- * Copyright (C) 2005-2014 Xiphos Developer Team
+ * Copyright (C) 2005-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,23 +23,23 @@
 #define _SLIB_EDITOR_H
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 #include <config.h>
 
 #ifndef USE_WEBKIT_EDITOR
-	
+
 #include <gtk/gtk.h>
 
 #include "main/navbar_versekey.h"
 
 typedef struct _editor EDITOR;
-struct _editor {
+struct _editor
+{
 	GtkWidget *window;
 	GtkWidget *toolbar;
-    	GtkWidget *treeview;
+	GtkWidget *treeview;
 	GtkWidget *sync_button;
 	GtkWidget *html_widget;
 	GtkWidget *statusbar;
@@ -65,24 +65,22 @@ enum {
 	BOOK_EDITOR
 };
 
-
 /*
 void button_test_clicked_cb(GtkObject *object, gpointer user_data);
 void button_ok_clicked_cb(GtkObject *object, gpointer user_data);
 void button_cancel_clicked_cb(GtkObject *object, gpointer user_data);*/
 void editor_sync_with_main(void);
-void editor_load_note(EDITOR * e, const gchar * module_name, const gchar * key);
-void editor_load_book(EDITOR * e);
-gint editor_create_new(const gchar * filename, const gchar * key, gint note);
-void editor_save_book(EDITOR * e);
+void editor_load_note(EDITOR *e, const gchar *module_name,
+		      const gchar *key);
+void editor_load_book(EDITOR *e);
+gint editor_create_new(const gchar *filename, const gchar *key,
+		       gint note);
+void editor_save_book(EDITOR *e);
 void editor_maybe_save_all(void);
-GtkWidget * editor_new (const gchar * title, EDITOR *e);
-
+GtkWidget *editor_new(const gchar *title, EDITOR *e);
 
 #ifdef __cplusplus
 }
 #endif
-
-
 #endif /* !USE_WEBKIT_EDITOR */
 #endif /* _SLIB_EDITOR_H */
