@@ -1,8 +1,8 @@
 /*
  * Xiphos Bible Study Tool
- * about_xiphos.c - Xiphos about dialog
+ * about_sword.c - Xiphos "About Sword" dialog
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@
  */
 
 static void
-on_dialog_response(GtkDialog * dialog, gint response_id,
+on_dialog_response(GtkDialog *dialog, gint response_id,
 		   gpointer user_data)
 {
 	gtk_widget_destroy(GTK_WIDGET(dialog));
@@ -71,14 +71,12 @@ on_dialog_response(GtkDialog * dialog, gint response_id,
  *   GtkWidget *
  */
 
-GtkWidget*
-gui_create_about_sword(void)
+GtkWidget *gui_create_about_sword(void)
 {
 	GdkPixbuf *about1_logo_pixbuf;
 	GtkWidget *about1;
 	gchar *about =
-	    _
-	    ("The SWORD Project is an effort to create an ever-expanding \
+	    _("The SWORD Project is an effort to create an ever-expanding \
 software package for research and study of God and His Word. \
 The SWORD Project framework allows easy use and study of Bible \
 texts, commentaries, lexicons, dictionaries, and other books. \
@@ -87,28 +85,21 @@ set of books may be shared among all frontends using the \
 framework.\n\n \
 Books can be downloaded from the SWORD Project.");
 
-
 	about1_logo_pixbuf = pixbuf_finder("sword-big.png", 0, NULL);
 
 	about1 = gtk_about_dialog_new();
 	g_signal_connect(about1, "response",
 			 G_CALLBACK(on_dialog_response), NULL);
-	gtk_about_dialog_set_program_name
-	    (GTK_ABOUT_DIALOG (about1), "The SWORD Project");
-	gtk_about_dialog_set_version
-	    (GTK_ABOUT_DIALOG (about1), (gchar *)main_get_sword_version());
-	gtk_about_dialog_set_comments
-	    (GTK_ABOUT_DIALOG (about1), about);
-#ifndef WIN32
-	gtk_about_dialog_set_website
-	    (GTK_ABOUT_DIALOG (about1), "http://www.crosswire.org/sword");
-	gtk_about_dialog_set_website_label
-	    (GTK_ABOUT_DIALOG (about1), _("The SWORD Project"));
-#endif
-	gtk_about_dialog_set_logo
-	    (GTK_ABOUT_DIALOG (about1), about1_logo_pixbuf);
+	gtk_about_dialog_set_program_name(GTK_ABOUT_DIALOG(about1), "The SWORD Project");
+	gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(about1), (gchar *)main_get_sword_version());
+	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about1), about);
 
-	set_window_icon (GTK_WINDOW(about1));
+	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(about1), "http://www.crosswire.org/");
+	gtk_about_dialog_set_website_label(GTK_ABOUT_DIALOG(about1), _("The SWORD Project"));
+
+	gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(about1), about1_logo_pixbuf);
+
+	set_window_icon(GTK_WINDOW(about1));
 
 	return about1;
 }
