@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * about_xiphos.c - Xiphos about dialog
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,8 +45,8 @@ static const gchar *authors[] = {
     "Simon Meers",
     "Martin Zibricky",
     "Dmitrijs Ledkovs",
-    NULL
-};
+    "Christopher Bayliss",
+    NULL};
 
 static const gchar *documenters[] = {
     "Pierre Benz",
@@ -55,10 +55,10 @@ static const gchar *documenters[] = {
     "Karl Kleinpaste",
     "Matthew Talbert",
     "Simon Meers",
-    NULL
-};
+    NULL};
 
-static gchar *translators = "Jan Paul Schmidt\nJorge Chacon\nDominique Corbex\nZdenko Podobn\nPavlo Bohmat\nMartin Zibricky\nAri Constancio\nGertjan Francke\nEicke Godehardt\nAndy Piper\nThomas Abthorpe\nEeli Kaikkonen";
+static gchar *translators =
+    "Jan Paul Schmidt\nJorge Chacon\nDominique Corbex\nZdenko Podobn\nPavlo Bohmat\nMartin Zibricky\nAri Constancio\nGertjan Francke\nEicke Godehardt\nAndy Piper\nThomas Abthorpe\nEeli Kaikkonen";
 
 /******************************************************************************
  * Name
@@ -78,7 +78,7 @@ static gchar *translators = "Jan Paul Schmidt\nJorge Chacon\nDominique Corbex\nZ
  */
 
 static void
-on_dialog_response(GtkDialog * dialog, gint response_id,
+on_dialog_response(GtkDialog *dialog, gint response_id,
 		   gpointer user_data)
 {
 	gtk_widget_destroy(GTK_WIDGET(dialog));
@@ -100,14 +100,23 @@ on_dialog_response(GtkDialog * dialog, gint response_id,
  *   GtkWidget *
  */
 
-GtkWidget*
-gui_create_about_xiphos(void)
+#ifdef USE_GTK_3
+# ifdef USE_WEBKIT2
+#  define	BUILD_TYPE	"gtk3 webkit2"
+# else
+#  define	BUILD_TYPE	"gtk3 webkit1"
+# endif
+#else
+#  define	BUILD_TYPE	"gtk2 webkit1"
+#endif
+
+GtkWidget *gui_create_about_xiphos(void)
 {
 	GdkPixbuf *about1_logo_pixbuf;
 	GtkWidget *about1;
 	gchar versionbuild[128];
 
-	snprintf(versionbuild, 120, "%s", VERSION);
+	snprintf(versionbuild, 120, "%s (%s)", VERSION, BUILD_TYPE);
 
 	about1_logo_pixbuf = pixbuf_finder("about.png", 0, NULL);
 
@@ -115,26 +124,19 @@ gui_create_about_xiphos(void)
 	g_signal_connect(about1, "response",
 			 G_CALLBACK(on_dialog_response), NULL);
 
-	gtk_about_dialog_set_version
-	    (GTK_ABOUT_DIALOG (about1), versionbuild);
-	gtk_about_dialog_set_copyright
-	    (GTK_ABOUT_DIALOG (about1),
-	     _("Copyright © 2000-2014 Xiphos Development Team"));
-	gtk_about_dialog_set_comments
-	    (GTK_ABOUT_DIALOG (about1),
-	     _("\nPowered by The SWORD Project.\nWe would like to thank Troy Griffitts and all the other folks who have given us The SWORD Project."));
-	gtk_about_dialog_set_website
-	    (GTK_ABOUT_DIALOG (about1), "http://xiphos.org/");
-	gtk_about_dialog_set_authors
-	    (GTK_ABOUT_DIALOG (about1), authors);
-	gtk_about_dialog_set_documenters
-	    (GTK_ABOUT_DIALOG (about1), documenters);
-	gtk_about_dialog_set_translator_credits
-	    (GTK_ABOUT_DIALOG (about1), translators);
-	gtk_about_dialog_set_logo
-	    (GTK_ABOUT_DIALOG (about1), about1_logo_pixbuf);
+	gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(about1), versionbuild);
+	gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(about1),
+				       _("Copyright © 2000-2015 Xiphos Development Team"));
+	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about1),
+				      _("\nPowered by The SWORD Project.\nWe would like to thank Troy Griffitts and all the other folks who have given us The SWORD Project."));
+	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(about1),
+				     "http://xiphos.org/");
+	gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(about1), authors);
+	gtk_about_dialog_set_documenters(GTK_ABOUT_DIALOG(about1), documenters);
+	gtk_about_dialog_set_translator_credits(GTK_ABOUT_DIALOG(about1), translators);
+	gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(about1), about1_logo_pixbuf);
 
-	set_window_icon (GTK_WINDOW(about1));
+	set_window_icon(GTK_WINDOW(about1));
 
 	return about1;
 }
