@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * bibletext.c - gui for Bible text modules
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@
 
 #include "xiphos_html/xiphos_html.h"
 
-
 #include "gui/xiphos.h"
 #include "gui/bibletext.h"
 #include "gui/bibletext_dialog.h"
@@ -55,8 +54,10 @@
 
 gboolean shift_key_pressed = FALSE;
 guint scroll_adj_signal;
-GtkAdjustment* adjustment;
+GtkAdjustment *adjustment;
 
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 /******************************************************************************
  * Name
  *
@@ -75,21 +76,18 @@ GtkAdjustment* adjustment;
 
 void gui_popup_pm_text(void)
 {
-   /* gui_menu_popup (settings.MainWindowModule,
-			NULL);*/
+	/* gui_menu_popup (settings.MainWindowModule,
+	   NULL); */
 }
-
+#endif
 
 static gboolean
-_popupmenu_requested_cb (XiphosHtml *html,
-			    gchar *uri ,
-			     gpointer user_data)
+_popupmenu_requested_cb(XiphosHtml *html, gchar *uri, gpointer user_data)
 {
-	gui_menu_popup(html, settings.MainWindowModule, NULL);  
+	gui_menu_popup(html, settings.MainWindowModule, NULL);
 	return TRUE;
 }
 
-
 /******************************************************************************
  * Name
  *   gui_create_bible_pane
@@ -116,20 +114,17 @@ GtkWidget *gui_create_bible_pane(void)
 
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
-	gtk_box_pack_start(GTK_BOX(vbox),
-			   scrolledwindow,
-	                   TRUE,
-			   TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), scrolledwindow, TRUE, TRUE, 0);
 
-	widgets.html_text = GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, TEXT_TYPE));
+	widgets.html_text =
+	    GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, TEXT_TYPE));
 	gtk_widget_show(widgets.html_text);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow),
-	                  widgets.html_text);
-	                  
-	g_signal_connect((gpointer)widgets.html_text,
-	              "popupmenu_requested",
-	              G_CALLBACK (_popupmenu_requested_cb),
-	              NULL);
+			  widgets.html_text);
 
-	return 	vbox;
+	g_signal_connect((gpointer)widgets.html_text,
+			 "popupmenu_requested",
+			 G_CALLBACK(_popupmenu_requested_cb), NULL);
+
+	return vbox;
 }
