@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * bookmarks_treeview.c - gui for bookmarks using treeview
  *
- * Copyright (C) 2003-2014 Xiphos Developer Team
+ * Copyright (C) 2003-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,42 +82,45 @@ BookMarksPixbufs *bm_pixbufs;
  *   void
  */
 
-void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
+void gui_verselist_to_bookmarks(GList *verses, gint save_as_single)
 {
 	gint test;
-	gchar *tmpbuf;
 	gchar *module_name = NULL;
-	GString *str;
 	GtkTreeIter parent;
 	GtkTreeIter iter;
 	GS_DIALOG *info;
 	RESULTS *list_item;
 
 	/*gchar *dlg = g_strdup_printf("<span weight=\"bold\">%s</span>\n%s",
-					   _("Save these results as a single bookmark?"),
-					   _("(rather than as a series of bookmarks)"));*/
+	   _("Save these results as a single bookmark?"),
+	   _("(rather than as a series of bookmarks)")); */
 	if (save_as_single) {
 		GString *name = g_string_new(NULL);
 		GString *verse_string = g_string_new("");
 		gboolean first_entry = TRUE;
 
-		g_string_printf(name, _("Search result: %s"), settings.searchText);
+		g_string_printf(name, _("Search result: %s"),
+				settings.searchText);
 		while (verses) {
-			list_item = (RESULTS *) verses->data;
+			list_item = (RESULTS *)verses->data;
 			if (main_is_Bible_key(list_item->module, list_item->key)) {
 				if (first_entry) {
-					module_name = g_strdup(list_item->module);
+					module_name =
+					    g_strdup(list_item->module);
 					first_entry = FALSE;
 				} else {
-					verse_string = g_string_append(verse_string,
-								       "; ");
+					verse_string =
+					    g_string_append(verse_string,
+							    "; ");
 				}
-				verse_string = g_string_append(verse_string,
-							       list_item->key);
+				verse_string =
+				    g_string_append(verse_string,
+						    list_item->key);
 			}
 			verses = g_list_next(verses);
 		}
-		gui_bookmark_dialog(name->str, module_name, verse_string->str);
+		gui_bookmark_dialog(name->str, module_name,
+				    verse_string->str);
 		g_string_free(name, TRUE);
 		g_string_free(verse_string, TRUE);
 		g_free(module_name);
@@ -128,10 +131,10 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 	info = gui_new_dialog();
 #ifdef HAVE_GTK_310
 	info->stock_icon = "document-open";
-#else   	
+#else
 	info->stock_icon = GTK_STOCK_OPEN;
-#endif	 
-	
+#endif
+
 	info->title = _("Bookmark");
 	info->label_top = _("Enter Folder Name");
 	info->text1 = g_strdup(settings.searchText);
@@ -151,18 +154,16 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 				   COL_CLOSED_PIXBUF,
 				   bm_pixbufs->pixbuf_closed,
 				   COL_CAPTION, info->text1,
-				   COL_KEY, NULL,
-				   COL_MODULE, NULL,
-				   -1);
-//              set_results_position((char) 1); // TOP
-		str = g_string_new(" ");
+				   COL_KEY, NULL, COL_MODULE, NULL, -1);
+		//              set_results_position((char) 1); // TOP
+		GString *str = g_string_new(" ");
 		while (verses) {
-			list_item = (RESULTS *) verses->data;
+			list_item = (RESULTS *)verses->data;
 			module_name = list_item->module;
-			tmpbuf = list_item->key;
+			gchar *tmpbuf = list_item->key;
 			g_string_printf(str, "%s, %s", tmpbuf,
-					 module_name);
-			XI_message(("bookmark: %s",str->str));
+					module_name);
+			XI_message(("bookmark: %s", str->str));
 			gtk_tree_store_append(GTK_TREE_STORE(model),
 					      &iter, &parent);
 			gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
@@ -171,8 +172,7 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 					   COL_CLOSED_PIXBUF, NULL,
 					   COL_CAPTION, str->str,
 					   COL_KEY, tmpbuf,
-					   COL_MODULE, module_name,
-					   -1);
+					   COL_MODULE, module_name, -1);
 			verses = g_list_next(verses);
 		}
 		g_string_free(str, TRUE);
@@ -200,11 +200,11 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
  *   void
  */
 
-static void get_xml_folder_data(xmlNodePtr cur, BOOKMARK_DATA * data)
+static void get_xml_folder_data(xmlNodePtr cur, BOOKMARK_DATA *data)
 {
 	xmlChar *folder;
 
-	folder = xmlGetProp(cur, (const xmlChar *) "caption");
+	folder = xmlGetProp(cur, (const xmlChar *)"caption");
 	data->caption = g_strdup((char *)folder);
 	data->key = NULL;
 	data->module = NULL;
@@ -215,7 +215,6 @@ static void get_xml_folder_data(xmlNodePtr cur, BOOKMARK_DATA * data)
 	data->closed = bm_pixbufs->pixbuf_closed;
 }
 
-
 /******************************************************************************
  * Name
  *    get_xml_bookmark_data
@@ -232,7 +231,7 @@ static void get_xml_folder_data(xmlNodePtr cur, BOOKMARK_DATA * data)
  *   void
  */
 
-static void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)
+static void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA *data)
 {
 	xmlChar *mod1;
 	xmlChar *key;
@@ -264,7 +263,6 @@ static void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)
 	data->is_leaf = TRUE;
 }
 
-
 /******************************************************************************
  * Name
  *  free_bookmark_data
@@ -281,7 +279,7 @@ static void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)
  *   void
  */
 
-static void free_bookmark_data(BOOKMARK_DATA * data)
+static void free_bookmark_data(BOOKMARK_DATA *data)
 {
 	if (data->caption)
 		g_free(data->caption);
@@ -312,8 +310,8 @@ static void free_bookmark_data(BOOKMARK_DATA * data)
  *   GtkCTreeNode
  */
 
-void gui_add_item_to_tree(GtkTreeIter * iter, GtkTreeIter * parent,
-			     BOOKMARK_DATA * data)
+void gui_add_item_to_tree(GtkTreeIter *iter, GtkTreeIter *parent,
+			  BOOKMARK_DATA *data)
 {
 	gtk_tree_store_append(GTK_TREE_STORE(model), iter, parent);
 
@@ -344,7 +342,7 @@ void gui_add_item_to_tree(GtkTreeIter * iter, GtkTreeIter * parent,
  *   void
  */
 
-static void add_node(xmlNodePtr cur, GtkTreeIter * parent)
+static void add_node(xmlNodePtr cur, GtkTreeIter *parent)
 {
 	GtkTreeIter iter;
 	BOOKMARK_DATA data, *p = NULL;
@@ -355,13 +353,11 @@ static void add_node(xmlNodePtr cur, GtkTreeIter * parent)
 		return;
 
 	for (work = cur->xmlChildrenNode; work; work = work->next) {
-		if (!xmlStrcmp
-		    (work->name, (const xmlChar *) "Bookmark")) {
+		if (!xmlStrcmp(work->name, (const xmlChar *)"Bookmark")) {
 			get_xml_bookmark_data(work, p);
 			gui_add_item_to_tree(&iter, parent, p);
 			free_bookmark_data(p);
-		} else if (!xmlStrcmp
-			   (work->name, (const xmlChar *) "Folder")) {
+		} else if (!xmlStrcmp(work->name, (const xmlChar *)"Folder")) {
 			get_xml_folder_data(work, p);
 			gui_add_item_to_tree(&iter, parent, p);
 			free_bookmark_data(p);
@@ -370,7 +366,6 @@ static void add_node(xmlNodePtr cur, GtkTreeIter * parent)
 	}
 }
 
-
 /******************************************************************************
  * Name
  *  gui_parse_bookmarks
@@ -387,8 +382,8 @@ static void add_node(xmlNodePtr cur, GtkTreeIter * parent)
  *   void
  */
 
-void gui_parse_bookmarks(GtkTreeView * tree, const xmlChar * file,
-		     GtkTreeIter * parent)
+void gui_parse_bookmarks(GtkTreeView *tree, const xmlChar *file,
+			 GtkTreeIter *parent)
 {
 	xmlNodePtr cur = NULL;
 	BOOKMARK_DATA data, *p = NULL;
@@ -399,7 +394,7 @@ void gui_parse_bookmarks(GtkTreeView * tree, const xmlChar * file,
 	cur = xml_load_bookmark_file(file);
 	//cur = cur->xmlChildrenNode;
 	while (cur != NULL) {
-		if (!xmlStrcmp(cur->name, (const xmlChar *) "Bookmark")) {
+		if (!xmlStrcmp(cur->name, (const xmlChar *)"Bookmark")) {
 			get_xml_bookmark_data(cur, p);
 			gui_add_item_to_tree(&iter, parent, p);
 			free_bookmark_data(p);
@@ -439,19 +434,18 @@ void gui_parse_bookmarks(GtkTreeView * tree, const xmlChar * file,
  *   void
  */
 
-static void load_xml_bookmarks(GtkTreeView * tree, GtkTreeIter * iter)
+static void load_xml_bookmarks(GtkTreeView *tree, GtkTreeIter *iter)
 {
 	GString *str;
 	const xmlChar *file;
 
 	str = g_string_new(NULL);
 	g_string_printf(str, "%s/bookmarks.xml", settings.swbmDir);
-	file = (const xmlChar *) str->str;
+	file = (const xmlChar *)str->str;
 	gui_parse_bookmarks(tree, file, iter);
 	g_string_free(str, TRUE);
 }
 
-
 /******************************************************************************
  * Name
  *   row_changed
@@ -469,14 +463,13 @@ static void load_xml_bookmarks(GtkTreeView * tree, GtkTreeIter * iter)
  *   void
  */
 
-static void row_changed(GtkTreeModel * treemodel, GtkTreePath * arg1,
-			GtkTreeIter * arg2, gpointer user_data)
+static void row_changed(GtkTreeModel *treemodel, GtkTreePath *arg1,
+			GtkTreeIter *arg2, gpointer user_data)
 {
 	bookmarks_changed = TRUE;
 	gui_save_bookmarks_treeview();
 }
 
-
 /******************************************************************************
  * Name
  *   row_changed
@@ -494,14 +487,13 @@ static void row_changed(GtkTreeModel * treemodel, GtkTreePath * arg1,
  *   void
  */
 
-static void row_deleted(GtkTreeModel * treemodel, GtkTreePath * arg1,
+static void row_deleted(GtkTreeModel *treemodel, GtkTreePath *arg1,
 			gpointer user_data)
 {
 	bookmarks_changed = TRUE;
 	gui_save_bookmarks_treeview();
 }
 
-
 /******************************************************************************
  * Name
  *   create_pixbufs
@@ -520,57 +512,53 @@ static void row_deleted(GtkTreeModel * treemodel, GtkTreePath * arg1,
 
 static void create_pixbufs(void)
 {
-	GtkTextDirection dir = gtk_widget_get_direction (GTK_WIDGET(widgets.app));
+	GtkTextDirection dir =
+	    gtk_widget_get_direction(GTK_WIDGET(widgets.app));
 
 	bm_pixbufs = g_new0(BookMarksPixbufs, 1);
 
 	if (dir == GTK_TEXT_DIR_LTR) {
 		/* leave this for if we make custom reversable icons
-		  if (!bm_pixbufs->pixbuf_closed)
-			bm_pixbufs->pixbuf_closed =
-				pixbuf_finder("book_closed.png", 16, NULL);
-		*/
+		   if (!bm_pixbufs->pixbuf_closed)
+		   bm_pixbufs->pixbuf_closed =
+		   pixbuf_finder("book_closed.png", 16, NULL);
+		 */
 
 		bm_pixbufs->pixbuf_opened =
-			pixbuf_finder("book_open.png", 16, NULL);
-	}
-	else {
+		    pixbuf_finder("book_open.png", 16, NULL);
+	} else {
 		/* leave this for if we make custom reversable icons
-		  if (!bm_pixbufs->pixbuf_closed)
-			bm_pixbufs->pixbuf_closed =
-				pixbuf_finder("book_closed_rtol.png", 16, NULL);
-		*/
+		   if (!bm_pixbufs->pixbuf_closed)
+		   bm_pixbufs->pixbuf_closed =
+		   pixbuf_finder("book_closed_rtol.png", 16, NULL);
+		 */
 
 		bm_pixbufs->pixbuf_opened =
-			pixbuf_finder("book_open_rtol.png", 16, NULL);
+		    pixbuf_finder("book_open_rtol.png", 16, NULL);
 	}
 
 	bm_pixbufs->pixbuf_closed =
-		pixbuf_finder("epiphany-bookmarks.png", 0, NULL);
-
+	    pixbuf_finder("epiphany-bookmarks.png", 0, NULL);
 
 	bm_pixbufs->pixbuf_helpdoc =
-		pixbuf_finder("epiphany-bookmark-page.png", 0, NULL);
+	    pixbuf_finder("epiphany-bookmark-page.png", 0, NULL);
 
 	if (!bm_pixbufs->pixbuf_helpdoc)
-
 #ifdef USE_GTK_3
-	bm_pixbufs->pixbuf_helpdoc = 
+		bm_pixbufs->pixbuf_helpdoc =
 #ifdef HAVE_GTK_310
-	    GDK_PIXBUF(gtk_image_new_from_icon_name ("gtk-dnd",
-                    		    GTK_ICON_SIZE_BUTTON));
-#else                        
-		
-	    gtk_widget_render_icon_pixbuf(widgets.app,
-                                              GTK_STOCK_DND,
-                                              GTK_ICON_SIZE_MENU );
-#endif	 
-		
-#else	
-		bm_pixbufs->pixbuf_helpdoc
-		    = gtk_widget_render_icon(widgets.app,
-					     GTK_STOCK_DND,
-					     GTK_ICON_SIZE_MENU, NULL);
+		    GDK_PIXBUF(gtk_image_new_from_icon_name("gtk-dnd",
+							    GTK_ICON_SIZE_BUTTON));
+#else
+		    gtk_widget_render_icon_pixbuf(widgets.app,
+						  GTK_STOCK_DND,
+						  GTK_ICON_SIZE_MENU);
+#endif
+
+#else
+		bm_pixbufs->pixbuf_helpdoc = gtk_widget_render_icon(widgets.app,
+								    GTK_STOCK_DND,
+								    GTK_ICON_SIZE_MENU, NULL);
 #endif
 }
 
@@ -590,7 +578,7 @@ static void create_pixbufs(void)
  *   void
  */
 
-void gui_add_columns(GtkTreeView * tree)
+void gui_add_columns(GtkTreeView *tree)
 {
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
@@ -599,13 +587,10 @@ void gui_add_columns(GtkTreeView * tree)
 
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_pixbuf_new());
 	gtk_tree_view_column_pack_start(column, renderer, FALSE);
-	gtk_tree_view_column_set_attributes
-	    (column, renderer,
-	     "pixbuf", COL_OPEN_PIXBUF,
-	     "pixbuf-expander-open", COL_OPEN_PIXBUF,
-	     "pixbuf-expander-closed", COL_CLOSED_PIXBUF, NULL);
-
-
+	gtk_tree_view_column_set_attributes(column, renderer,
+					    "pixbuf", COL_OPEN_PIXBUF,
+					    "pixbuf-expander-open", COL_OPEN_PIXBUF,
+					    "pixbuf-expander-closed", COL_CLOSED_PIXBUF, NULL);
 
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
@@ -614,7 +599,6 @@ void gui_add_columns(GtkTreeView * tree)
 	gtk_tree_view_append_column(tree, column);
 	gtk_tree_view_column_set_sort_column_id(column, COL_CAPTION);
 
-
 	column = gtk_tree_view_column_new();
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
@@ -635,8 +619,7 @@ void gui_add_columns(GtkTreeView * tree)
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes(column, renderer,
-					    "text", COL_MODULE_DESC,
-					    NULL);
+					    "text", COL_MODULE_DESC, NULL);
 	gtk_tree_view_append_column(tree, column);
 	gtk_tree_view_column_set_visible(column, FALSE);
 
@@ -644,13 +627,11 @@ void gui_add_columns(GtkTreeView * tree)
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes(column, renderer,
-					    "text", COL_DESCRIPTION,
-					    NULL);
+					    "text", COL_DESCRIPTION, NULL);
 	gtk_tree_view_append_column(tree, column);
 	gtk_tree_view_column_set_visible(column, FALSE);
 }
 
-
 /******************************************************************************
  * Name
  *   create_model
@@ -681,7 +662,6 @@ static GtkTreeModel *create_model(void)
 	return GTK_TREE_MODEL(model);
 }
 
-
 /******************************************************************************
  * Name
  *   button_release_event
@@ -700,20 +680,17 @@ static GtkTreeModel *create_model(void)
  *   void
  */
 
-static gboolean button_release_event(GtkWidget * widget,
-				     GdkEventButton * event,
-				     gpointer data)
+static gboolean button_release_event(GtkWidget *widget,
+				     GdkEventButton *event, gpointer data)
 {
 	GtkTreeSelection *selection = NULL;
 	GtkTreeIter selected;
-	GtkTreePath *path;
 	gboolean is_selected = FALSE;
 	gchar *caption = NULL;
 	gchar *key = NULL;
 	gchar *module = NULL;
 	gchar *mod_desc = NULL;
 	gchar *description = NULL;
-	gchar *url = NULL;
 	button_one = FALSE;
 
 	selection = gtk_tree_view_get_selection(bookmark_tree);
@@ -723,11 +700,8 @@ static gboolean button_release_event(GtkWidget * widget,
 				   2, &caption,
 				   3, &key,
 				   4, &module,
-				   5, &mod_desc,
-				   6, &description,
-				   -1);
-		if (!gtk_tree_model_iter_has_child
-		    (GTK_TREE_MODEL(model), &selected) && key != NULL) {
+				   5, &mod_desc, 6, &description, -1);
+		if (!gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model), &selected) && key != NULL) {
 			gboolean multi = (strpbrk(key, "-;,") != NULL);
 			gtk_widget_set_sensitive(menu.in_tab, !multi);
 			gtk_widget_set_sensitive(menu.in_dialog, !multi);
@@ -736,15 +710,16 @@ static gboolean button_release_event(GtkWidget * widget,
 			gtk_widget_set_sensitive(menu.remove, FALSE);
 		} else {
 			/* click on treeview folder to expand or collapse it */
-			path = gtk_tree_model_get_path(
-					GTK_TREE_MODEL (model), &selected);
-			if (gtk_tree_view_row_expanded (bookmark_tree, path))
-			       gtk_tree_view_collapse_row (bookmark_tree,
+			GtkTreePath *path =
+			    gtk_tree_model_get_path(GTK_TREE_MODEL(model),
+						    &selected);
+			if (gtk_tree_view_row_expanded(bookmark_tree, path))
+				gtk_tree_view_collapse_row(bookmark_tree,
 							   path);
 			else
-			       gtk_tree_view_expand_row (bookmark_tree,
+				gtk_tree_view_expand_row(bookmark_tree,
 							 path, FALSE);
-			gtk_tree_path_free ( path );
+			gtk_tree_path_free(path);
 
 			gtk_widget_set_sensitive(menu.in_tab, FALSE);
 			gtk_widget_set_sensitive(menu.in_dialog, FALSE);
@@ -799,27 +774,31 @@ static gboolean button_release_event(GtkWidget * widget,
 			return FALSE;
 		}
 		break;
-
 	}
 	if (is_selected) {
-		if (!gtk_tree_model_iter_has_child
-		    (GTK_TREE_MODEL(model), &selected) && key != NULL) {
-			if (!strcmp(module,"studypad"))
+		if (!gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model), &selected) && key != NULL) {
+			// might have an abbrev.  get the real.
+			const gchar *real_mod = main_get_name(module);
+			gchar *url = NULL;
+
+			if (!strcmp(module, "studypad"))
 				url =
-				    g_strdup_printf
-				    ("passagestudy.jsp?action=showStudypad&"
-				     "type=9&value=%s&module=%s",
-				     main_url_encode(key),
-				     main_url_encode(module));
+				    g_strdup_printf("passagestudy.jsp?action=showStudypad&"
+						    "type=9&value=%s&module=%s",
+						    main_url_encode(key),
+						    main_url_encode((real_mod
+								     ? real_mod
+								     : module)));
 
 			else if (button_one)
 				url =
-				    g_strdup_printf
-				    ("passagestudy.jsp?action=showBookmark&"
-				     "type=%s&value=%s&module=%s",
-				     "currentTab",
-				     main_url_encode(key),
-				     main_url_encode(module));
+				    g_strdup_printf("passagestudy.jsp?action=showBookmark&"
+						    "type=%s&value=%s&module=%s",
+						    "currentTab",
+						    main_url_encode(key),
+						    main_url_encode((real_mod
+								     ? real_mod
+								     : module)));
 			if (url) {
 				main_url_handler(url, TRUE);
 				g_free(url);
