@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * cipher_key_dialog.c  - asks for key to unlock sword module
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <gtk/gtk.h>
@@ -32,8 +32,6 @@
 #include "main/settings.h"
 #include "main/sword.h"
 
-
-
 /******************************************************************************
  * Name
  *   gui_add_cipher_key
@@ -58,12 +56,13 @@ gchar *gui_add_cipher_key(const char *mod_name, gchar *cipher_old)
 	info = gui_new_dialog();
 #ifdef HAVE_GTK_310
 	info->stock_icon = "dialog-warning";
-#else   	
+#else
 	info->stock_icon = GTK_STOCK_DIALOG_WARNING;
-#endif	 
-	info->label_top = g_strdup_printf(_("Cipher key for module %s"), mod_name);
+#endif
+	info->label_top =
+	    g_strdup_printf(_("Cipher key for module %s"), mod_name);
 	info->label_middle = _("for:");
-	info->label_bottom = (char*)mod_name;
+	info->label_bottom = (char *)mod_name;
 	info->text1 = g_strdup(cipher_old);
 	info->label1 = _("Enter Key: ");
 	info->ok = TRUE;
