@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * commentary_dialog.c - dialog for a commentary module
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <gtk/gtk.h>
@@ -54,7 +54,6 @@ extern gboolean do_display;
  */
 DIALOG_DATA *cur_d;
 
-
 /******************************************************************************
  * Name
  *   on_dialog_destroy
@@ -72,15 +71,15 @@ DIALOG_DATA *cur_d;
  *   void
  */
 
-static void on_dialog_destroy(GObject *object,
-			      DIALOG_DATA *d)
+static void on_dialog_destroy(GObject *object, DIALOG_DATA *d)
 {
 	if (!dialog_freed)
 		main_free_on_destroy(d);
 	dialog_freed = FALSE;
 }
 
-
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 /******************************************************************************
  * Name
  *   gui_close_comm_dialog
@@ -97,14 +96,14 @@ static void on_dialog_destroy(GObject *object,
  *   void
  */
 
-void gui_close_comm_dialog(DIALOG_DATA * d)
+void gui_close_comm_dialog(DIALOG_DATA *d)
 {
 	if (d->dialog) {
 		dialog_freed = FALSE;
 		gtk_widget_destroy(d->dialog);
 	}
 }
-
+#endif
 
 /******************************************************************************
  * Name
@@ -131,7 +130,7 @@ static gboolean on_dialog_motion_notify_event(GtkWidget *widget,
 	return FALSE;
 }
 
-
+#if 0
 /******************************************************************************
  * Name
  *   sync_with_main
@@ -150,13 +149,12 @@ static gboolean on_dialog_motion_notify_event(GtkWidget *widget,
 
 static void sync_with_main(DIALOG_DATA *d)
 {
-	gchar *url =
-	    g_strdup_printf("sword:///%s", settings.currentverse);
+	gchar *url = g_strdup_printf("sword:///%s", settings.currentverse);
 	main_dialogs_url_handler(d, url, TRUE);
 	cur_d = d;
 	g_free(url);
 }
-
+#endif
 
 /******************************************************************************
  * Name
@@ -181,11 +179,9 @@ static GtkWidget *create_nav_toolbar(DIALOG_DATA *d)
 }
 
 static void
-_popupmenu_requested_cb (XiphosHtml *html,
-			 gchar *uri,
-			 DIALOG_DATA *d)
+_popupmenu_requested_cb(XiphosHtml *html, gchar *uri, DIALOG_DATA *d)
 {
-    	gui_menu_popup (html, cur_d->mod_name, cur_d);
+	gui_menu_popup(html, cur_d->mod_name, cur_d);
 	//gui_commentary_dialog_create_menu(d);
 }
 
@@ -205,8 +201,7 @@ _popupmenu_requested_cb (XiphosHtml *html,
  *   void
  */
 
-void gui_create_commentary_dialog(DIALOG_DATA *d,
-				  gboolean do_edit)
+void gui_create_commentary_dialog(DIALOG_DATA *d, gboolean do_edit)
 {
 	GtkWidget *vbox30;
 	GtkWidget *vbox_toolbars;
@@ -217,8 +212,7 @@ void gui_create_commentary_dialog(DIALOG_DATA *d,
 	cur_d = d;
 	d->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-	g_object_set_data(G_OBJECT(d->dialog), "d->dialog",
-			  d->dialog);
+	g_object_set_data(G_OBJECT(d->dialog), "d->dialog", d->dialog);
 	gtk_window_set_title(GTK_WINDOW(d->dialog),
 			     main_get_module_description(d->mod_name));
 	//gtk_window_set_default_size(GTK_WINDOW(d->dialog), 462, 280);
@@ -251,22 +245,23 @@ void gui_create_commentary_dialog(DIALOG_DATA *d,
 	scrolledwindow38 = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow38);
 	gtk_container_add(GTK_CONTAINER(frame19), scrolledwindow38);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
-				       (scrolledwindow38),
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow38),
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 					    scrolledwindow38,
 					    settings.shadow_type);
 
-	d->html = GTK_WIDGET(XIPHOS_HTML_NEW(((DIALOG_DATA*) d),TRUE,DIALOG_COMMENTARY_TYPE));
+	d->html =
+	    GTK_WIDGET(XIPHOS_HTML_NEW(((DIALOG_DATA *)d), TRUE,
+				       DIALOG_COMMENTARY_TYPE));
 
 	gtk_container_add(GTK_CONTAINER(scrolledwindow38), d->html);
 	gtk_widget_show(d->html);
 	g_signal_connect((gpointer)d->html,
-		      "popupmenu_requested",
-		      G_CALLBACK (_popupmenu_requested_cb),
-		      (DIALOG_DATA*)d);
+			 "popupmenu_requested",
+			 G_CALLBACK(_popupmenu_requested_cb),
+			 (DIALOG_DATA *)d);
 
 	g_signal_connect(G_OBJECT(d->dialog), "destroy",
 			 G_CALLBACK(on_dialog_destroy), d);
@@ -275,9 +270,10 @@ void gui_create_commentary_dialog(DIALOG_DATA *d,
 			 G_CALLBACK(on_dialog_motion_notify_event), d);
 }
 
-
-void gui_commentary_dialog_sync_toggled(GtkToggleButton * button,
-					DIALOG_DATA * d)
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
+void gui_commentary_dialog_sync_toggled(GtkToggleButton *button,
+					DIALOG_DATA *d)
 {
 	if (d == NULL)
 		d = cur_d;
@@ -287,6 +283,6 @@ void gui_commentary_dialog_sync_toggled(GtkToggleButton * button,
 	} else
 		d->sync = FALSE;
 }
-
+#endif
 
 /******   end of file   ******/
