@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * dialog.c -
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,8 +41,8 @@ static GtkWidget *entry5 = NULL;
 static GtkWidget *entry6 = NULL;
 static gint retval = 3;
 
-GS_DIALOG * standard_info;
-GtkWidget * dialog_request;
+GS_DIALOG *standard_info;
+GtkWidget *dialog_request;
 
 /******************************************************************************
  * Name
@@ -60,7 +60,7 @@ GtkWidget * dialog_request;
  *   void
  */
 
-static void get_entry_text(GS_DIALOG * info)
+static void get_entry_text(GS_DIALOG *info)
 {
 	if (entry1) {
 		if (info->text1)
@@ -98,11 +98,8 @@ static void get_entry_text(GS_DIALOG * info)
 		info->text6 =
 		    g_strdup(gtk_entry_get_text(GTK_ENTRY(entry6)));
 	}
-
 }
 
-
-
 /******************************************************************************
  * Name
  *   on_dialog_response
@@ -119,7 +116,8 @@ static void get_entry_text(GS_DIALOG * info)
  *   void
  */
 
-static void on_dialog_response(GtkDialog * dialog, gint response_id, GS_DIALOG * info)
+static void on_dialog_response(GtkDialog *dialog, gint response_id,
+			       GS_DIALOG *info)
 {
 	switch (response_id) {
 	case GTK_RESPONSE_OK:
@@ -136,7 +134,6 @@ static void on_dialog_response(GtkDialog * dialog, gint response_id, GS_DIALOG *
 	case GTK_RESPONSE_CANCEL:
 		retval = GS_CANCEL;
 		break;
-
 	}
 }
 
@@ -158,33 +155,30 @@ static void on_dialog_response(GtkDialog * dialog, gint response_id, GS_DIALOG *
 
 static void on_dialog_enter(void)
 {
-	on_dialog_response(GTK_DIALOG(dialog_request), GTK_RESPONSE_OK, standard_info);
+	on_dialog_response(GTK_DIALOG(dialog_request), GTK_RESPONSE_OK,
+			   standard_info);
 	gtk_widget_destroy(GTK_WIDGET(dialog_request));
 }
 
-
-static GtkWidget *create_dialog_alert(GS_DIALOG * info)
+static GtkWidget *create_dialog_alert(GS_DIALOG *info)
 {
 	GtkWidget *dialog_alert;
 	GtkWidget *dialog_vbox2;
 	GtkWidget *hbox3;
-	GtkWidget *image5;
 	GtkWidget *vbox2;
 	GtkWidget *label7;
-	GtkWidget *label10;
 	GtkWidget *dialog_action_area2;
-	GtkWidget *scrolledwindow;
-	GtkWidget *viewport;
 
 	dialog_alert = gtk_dialog_new();
 	gtk_container_set_border_width(GTK_CONTAINER(dialog_alert), 5);
 	gtk_window_set_title(GTK_WINDOW(dialog_alert), " ");
-    
+
 #ifndef USE_GTK_3
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_alert), FALSE);
 #endif
 
-	dialog_vbox2 = gtk_dialog_get_content_area(GTK_DIALOG(dialog_alert));
+	dialog_vbox2 =
+	    gtk_dialog_get_content_area(GTK_DIALOG(dialog_alert));
 	gtk_widget_show(dialog_vbox2);
 
 	UI_HBOX(hbox3, FALSE, 12);
@@ -193,24 +187,21 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 	gtk_container_set_border_width(GTK_CONTAINER(hbox3), 6);
 
 	if (info->stock_icon) {
-		image5 =
+		GtkWidget *image5 =
 #ifdef HAVE_GTK_310
-			gtk_image_new_from_icon_name
-#else		    
-			gtk_image_new_from_stock
-#endif	
-					(info->stock_icon,
-					     GTK_ICON_SIZE_DIALOG);	
+		    gtk_image_new_from_icon_name
+#else
+		    gtk_image_new_from_stock
+#endif
+		    (info->stock_icon, GTK_ICON_SIZE_DIALOG);
 		gtk_widget_show(image5);
-		gtk_box_pack_start(GTK_BOX(hbox3), image5, FALSE, TRUE,
-				   0);
+		gtk_box_pack_start(GTK_BOX(hbox3), image5, FALSE, TRUE, 0);
 #ifndef HAVE_GTK_310
 		gtk_misc_set_alignment(GTK_MISC(image5), 0.5, 0);
 		gtk_misc_set_padding(GTK_MISC(image5), 12, 0);
 #endif
 	}
 
-
 	UI_VBOX(vbox2, FALSE, 6);
 	gtk_widget_show(vbox2);
 	gtk_box_pack_start(GTK_BOX(hbox3), vbox2, TRUE, TRUE, 0);
@@ -226,27 +217,36 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 #endif
 
 	if (info->label2) {
-		gtk_window_set_default_size (GTK_WINDOW (dialog_alert), 380, 200);
-		scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-		gtk_widget_show (scrolledwindow);
-		gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow, TRUE, TRUE, 0);
-		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
-				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		gtk_window_set_default_size(GTK_WINDOW(dialog_alert), 380,
+					    200);
+		GtkWidget *scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
+		gtk_widget_show(scrolledwindow);
+		gtk_box_pack_start(GTK_BOX(vbox2), scrolledwindow, TRUE,
+				   TRUE, 0);
+		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow),
+					       GTK_POLICY_AUTOMATIC,
+					       GTK_POLICY_AUTOMATIC);
 
-		viewport = gtk_viewport_new (NULL, NULL);
-		gtk_widget_show (viewport);
-		gtk_container_add (GTK_CONTAINER (scrolledwindow), viewport);
+		GtkWidget *viewport = gtk_viewport_new(NULL, NULL);
+		gtk_widget_show(viewport);
+		gtk_container_add(GTK_CONTAINER(scrolledwindow), viewport);
 
-		label10 = gtk_label_new(info->label2);
+		GtkWidget *label10 = gtk_label_new(info->label2);
 		gtk_widget_show(label10);
-		gtk_container_add (GTK_CONTAINER (viewport), label10);
-		gtk_label_set_justify(GTK_LABEL(label10), GTK_JUSTIFY_LEFT);
+		gtk_container_add(GTK_CONTAINER(viewport), label10);
+		gtk_label_set_justify(GTK_LABEL(label10),
+				      GTK_JUSTIFY_LEFT);
 #ifndef HAVE_GTK_310
 		gtk_misc_set_alignment(GTK_MISC(label10), 0, 0.5);
 #endif
 	}
 
-	dialog_action_area2 = gtk_dialog_get_action_area(GTK_DIALOG(dialog_alert));
+	dialog_action_area2 =
+#ifdef HAVE_GTK_312
+	    gtk_dialog_get_content_area(GTK_DIALOG(dialog_alert));
+#else
+	    gtk_dialog_get_action_area(GTK_DIALOG(dialog_alert));
+#endif
 	gtk_widget_show(dialog_action_area2);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area2),
 				  GTK_BUTTONBOX_END);
@@ -265,9 +265,8 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 				      "_No", GTK_RESPONSE_NO);
 	if (info->cancel)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
-				      "_Cancel",
-				      GTK_RESPONSE_CANCEL);
-#else	
+				      "_Cancel", GTK_RESPONSE_CANCEL);
+#else
 	if (info->ok)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
 				      GTK_STOCK_OK, GTK_RESPONSE_OK);
@@ -276,8 +275,7 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 				      GTK_STOCK_YES, GTK_RESPONSE_YES);
 	if (info->save)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
-                                             GTK_STOCK_SAVE,
-                                             GTK_RESPONSE_YES);
+				      GTK_STOCK_SAVE, GTK_RESPONSE_YES);
 	if (info->no)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
 				      GTK_STOCK_NO, GTK_RESPONSE_NO);
@@ -285,19 +283,18 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
 				      GTK_STOCK_CANCEL,
 				      GTK_RESPONSE_CANCEL);
-#endif	
+#endif
 	if (info->no_save)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_alert),
-                                             _("Close without Saving"),
-                                             GTK_RESPONSE_NO);
+				      _("Close without Saving"),
+				      GTK_RESPONSE_NO);
 
-	g_signal_connect((gpointer) dialog_alert, "response",
+	g_signal_connect((gpointer)dialog_alert, "response",
 			 G_CALLBACK(on_dialog_response), info);
 
 	return dialog_alert;
 }
 
-
 /******************************************************************************
  * Name
  *   create_dialog_request
@@ -314,11 +311,10 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
  *   GtkWidget *
  */
 
-static GtkWidget *create_dialog_request(GS_DIALOG * info)
+static GtkWidget *create_dialog_request(GS_DIALOG *info)
 {
 	GtkWidget *dialog_vbox3 = NULL;
 	GtkWidget *hbox4 = NULL;
-	GtkWidget *image6 = NULL;
 	GtkWidget *vbox3 = NULL;
 	GtkWidget *label8 = NULL;
 	GtkWidget *table2 = NULL;
@@ -343,7 +339,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 #ifndef USE_GTK_3
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_request), FALSE);
 #endif
-	dialog_vbox3 = gtk_dialog_get_content_area(GTK_DIALOG(dialog_request));
+	dialog_vbox3 =
+	    gtk_dialog_get_content_area(GTK_DIALOG(dialog_request));
 	gtk_widget_show(dialog_vbox3);
 
 	UI_HBOX(hbox4, FALSE, 12);
@@ -353,18 +350,17 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 
 	if (info->stock_icon) {
 #ifdef HAVE_GTK_310
-		image6 = 
-		     gtk_image_new_from_icon_name (info->stock_icon,
-                                            GTK_ICON_SIZE_DIALOG);
+		GtkWidget *image6 =
+		    gtk_image_new_from_icon_name(info->stock_icon,
+						 GTK_ICON_SIZE_DIALOG);
 
 #else
-		image6 =
+		GtkWidget *image6 =
 		    gtk_image_new_from_stock(info->stock_icon,
 					     GTK_ICON_SIZE_DIALOG);
 #endif
 		gtk_widget_show(image6);
-		gtk_box_pack_start(GTK_BOX(hbox4), image6, FALSE, TRUE,
-				   0);
+		gtk_box_pack_start(GTK_BOX(hbox4), image6, FALSE, TRUE, 0);
 #ifndef HAVE_GTK_310
 		gtk_misc_set_alignment(GTK_MISC(image6), 0.5, 0);
 		gtk_misc_set_padding(GTK_MISC(image6), 12, 0);
@@ -387,8 +383,7 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 	if (info->label1) {
 		label9 = gtk_label_new(info->label1);
 		gtk_widget_show(label9);
-		gtk_label_set_justify(GTK_LABEL(label9),
-				      GTK_JUSTIFY_LEFT);
+		gtk_label_set_justify(GTK_LABEL(label9), GTK_JUSTIFY_LEFT);
 #ifndef HAVE_GTK_310
 		gtk_misc_set_alignment(GTK_MISC(label9), 0, 0.5);
 #endif
@@ -396,9 +391,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		entry1 = gtk_entry_new();
 		gtk_widget_show(entry1);
 		if (info->text1)
-			gtk_entry_set_text(GTK_ENTRY(entry1),
-					   info->text1);
-		g_signal_connect((gpointer) entry1, "activate",
+			gtk_entry_set_text(GTK_ENTRY(entry1), info->text1);
+		g_signal_connect((gpointer)entry1, "activate",
 				 G_CALLBACK(on_dialog_enter), info);
 	}
 
@@ -414,9 +408,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		entry2 = gtk_entry_new();
 		gtk_widget_show(entry2);
 		if (info->text2)
-			gtk_entry_set_text(GTK_ENTRY(entry2),
-					   info->text2);
-		g_signal_connect((gpointer) entry2, "activate",
+			gtk_entry_set_text(GTK_ENTRY(entry2), info->text2);
+		g_signal_connect((gpointer)entry2, "activate",
 				 G_CALLBACK(on_dialog_enter), info);
 	}
 
@@ -432,9 +425,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		entry3 = gtk_entry_new();
 		gtk_widget_show(entry3);
 		if (info->text3)
-			gtk_entry_set_text(GTK_ENTRY(entry3),
-					   info->text3);
-		g_signal_connect((gpointer) entry3, "activate",
+			gtk_entry_set_text(GTK_ENTRY(entry3), info->text3);
+		g_signal_connect((gpointer)entry3, "activate",
 				 G_CALLBACK(on_dialog_enter), info);
 	}
 
@@ -449,11 +441,10 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 
 		entry4 = gtk_entry_new();
 		gtk_widget_show(entry4);
-		
+
 		if (info->text4)
-			gtk_entry_set_text(GTK_ENTRY(entry4),
-					   info->text4);
-		g_signal_connect((gpointer) entry4, "activate",
+			gtk_entry_set_text(GTK_ENTRY(entry4), info->text4);
+		g_signal_connect((gpointer)entry4, "activate",
 				 G_CALLBACK(on_dialog_enter), info);
 	}
 
@@ -468,11 +459,10 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 
 		entry5 = gtk_entry_new();
 		gtk_widget_show(entry5);
-		
+
 		if (info->text5)
-			gtk_entry_set_text(GTK_ENTRY(entry5),
-					   info->text5);
-		g_signal_connect((gpointer) entry5, "activate",
+			gtk_entry_set_text(GTK_ENTRY(entry5), info->text5);
+		g_signal_connect((gpointer)entry5, "activate",
 				 G_CALLBACK(on_dialog_enter), info);
 	}
 
@@ -487,73 +477,70 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 
 		entry6 = gtk_entry_new();
 		gtk_widget_show(entry6);
-		
+
 		if (info->text6)
-			gtk_entry_set_text(GTK_ENTRY(entry6),
-					   info->text6);
-		g_signal_connect((gpointer) entry6, "activate",
+			gtk_entry_set_text(GTK_ENTRY(entry6), info->text6);
+		g_signal_connect((gpointer)entry6, "activate",
 				 G_CALLBACK(on_dialog_enter), info);
 	}
-	
 #ifdef HAVE_GTK_34
 	table2 = gtk_grid_new();
 	gtk_widget_show(table2);
 	gtk_box_pack_start(GTK_BOX(vbox3), table2, TRUE, TRUE, 0);
-	gtk_grid_set_row_spacing (GTK_GRID(table2), 3);
-	gtk_grid_set_column_spacing (GTK_GRID(table2), 3);
+	gtk_grid_set_row_spacing(GTK_GRID(table2), 3);
+	gtk_grid_set_column_spacing(GTK_GRID(table2), 3);
 
 	if (info->label1) {
 		gtk_grid_attach(GTK_GRID(table2), label9, 0, 0, 1, 1);
 
-		gtk_grid_attach(GTK_GRID(table2), entry1, 1, 0, 1, 1); 
+		gtk_grid_attach(GTK_GRID(table2), entry1, 1, 0, 1, 1);
 		++nextrow;
-
 	}
 
 	if (info->label2) {
-		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
-		
+		gtk_grid_insert_row(GTK_GRID(table2), nextrow);
+
 		gtk_grid_attach(GTK_GRID(table2), label10, 0, 1, 1, 1);
-		
+
 		gtk_grid_attach(GTK_GRID(table2), entry2, 1, 1, 1, 1);
 		++nextrow;
 	}
 
 	if (info->label3) {
-		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
-		
+		gtk_grid_insert_row(GTK_GRID(table2), nextrow);
+
 		gtk_grid_attach(GTK_GRID(table2), label11, 0, 2, 1, 1);
-		
+
 		gtk_grid_attach(GTK_GRID(table2), entry3, 1, 2, 1, 1);
 		++nextrow;
 	}
 
 	if (info->label4) {
-		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
-		
+		gtk_grid_insert_row(GTK_GRID(table2), nextrow);
+
 		gtk_grid_attach(GTK_GRID(table2), label12, 0, 3, 1, 1);
-		
+
 		gtk_grid_attach(GTK_GRID(table2), entry4, 1, 3, 1, 1);
 		++nextrow;
 	}
 
 	if (info->label5) {
-		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
-		
+		gtk_grid_insert_row(GTK_GRID(table2), nextrow);
+
 		gtk_grid_attach(GTK_GRID(table2), label13, 0, 4, 1, 1);
-		
+
 		gtk_grid_attach(GTK_GRID(table2), entry5, 1, 4, 1, 1);
 		++nextrow;
 	}
 
 	if (info->label6) {
-		gtk_grid_insert_row (GTK_GRID(table2),nextrow);
-		
+		gtk_grid_insert_row(GTK_GRID(table2), nextrow);
+
 		gtk_grid_attach(GTK_GRID(table2), label14, 0, 5, 1, 1);
-		
+
 		gtk_grid_attach(GTK_GRID(table2), entry6, 1, 5, 1, 1);
 	}
-#else 
+#else
 	table2 = gtk_table_new(3, 2, FALSE);
 	gtk_widget_show(table2);
 	gtk_box_pack_start(GTK_BOX(vbox3), table2, TRUE, TRUE, 0);
@@ -562,74 +549,78 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 
 	if (info->label1) {
 		gtk_table_attach(GTK_TABLE(table2), label9, 0, 1, 0, 1,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+				 (GtkAttachOptions)(GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
 
 		gtk_table_attach(GTK_TABLE(table2), entry1, 1, 2, 0, 1,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+				 (GtkAttachOptions)(GTK_EXPAND |
+						    GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
 	}
 
 	if (info->label2) {
 		gtk_table_attach(GTK_TABLE(table2), label10, 0, 1, 1, 2,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
-		
+				 (GtkAttachOptions)(GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
+
 		gtk_table_attach(GTK_TABLE(table2), entry2, 1, 2, 1, 2,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+				 (GtkAttachOptions)(GTK_EXPAND |
+						    GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
 	}
 
 	if (info->label3) {
 		gtk_table_attach(GTK_TABLE(table2), label11, 0, 1, 2, 3,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
-		
+				 (GtkAttachOptions)(GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
+
 		gtk_table_attach(GTK_TABLE(table2), entry3, 1, 2, 2, 3,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+				 (GtkAttachOptions)(GTK_EXPAND |
+						    GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
 	}
 
 	if (info->label4) {
 		gtk_table_attach(GTK_TABLE(table2), label12, 0, 1, 3, 4,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
-		
+				 (GtkAttachOptions)(GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
+
 		gtk_table_attach(GTK_TABLE(table2), entry4, 1, 2, 3, 4,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+				 (GtkAttachOptions)(GTK_EXPAND |
+						    GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
 	}
 
 	if (info->label5) {
-		
+
 		gtk_table_attach(GTK_TABLE(table2), label13, 0, 1, 4, 5,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
-		
+				 (GtkAttachOptions)(GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
+
 		gtk_table_attach(GTK_TABLE(table2), entry5, 1, 2, 4, 5,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+				 (GtkAttachOptions)(GTK_EXPAND |
+						    GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
 	}
 
 	if (info->label6) {
-		
+
 		gtk_table_attach(GTK_TABLE(table2), label14, 0, 1, 5, 6,
-				 (GtkAttachOptions) (GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
-		
+				 (GtkAttachOptions)(GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
+
 		gtk_table_attach(GTK_TABLE(table2), entry6, 1, 2, 5, 6,
-				 (GtkAttachOptions) (GTK_EXPAND |
-						     GTK_FILL),
-				 (GtkAttachOptions) (0), 0, 0);
+				 (GtkAttachOptions)(GTK_EXPAND |
+						    GTK_FILL),
+				 (GtkAttachOptions)(0), 0, 0);
 	}
-	
 #endif
-	dialog_action_area3 = gtk_dialog_get_action_area(GTK_DIALOG(dialog_request));
+	dialog_action_area3 =
+#ifdef HAVE_GTK_312
+	    gtk_dialog_get_content_area(GTK_DIALOG(dialog_request));
+#else
+	    gtk_dialog_get_action_area(GTK_DIALOG(dialog_request));
+#endif
 	gtk_widget_show(dialog_action_area3);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area3),
 				  GTK_BUTTONBOX_END);
@@ -642,12 +633,11 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 				      "_Yes", GTK_RESPONSE_YES);
 	if (info->cancel)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
-				      "_Cancel",
-				      GTK_RESPONSE_CANCEL);
+				      "_Cancel", GTK_RESPONSE_CANCEL);
 	if (info->ok)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
 				      "_OK", GTK_RESPONSE_OK);
-#else	
+#else
 	if (info->no)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
 				      GTK_STOCK_NO, GTK_RESPONSE_NO);
@@ -662,13 +652,12 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		gtk_dialog_add_button(GTK_DIALOG(dialog_request),
 				      GTK_STOCK_OK, GTK_RESPONSE_OK);
 #endif
-	g_signal_connect((gpointer) dialog_request, "response",
+	g_signal_connect((gpointer)dialog_request, "response",
 			 G_CALLBACK(on_dialog_response), info);
 
 	return dialog_request;
 }
 
-
 /******************************************************************************
  * Name
  *   gui_new_dialog
@@ -700,7 +689,6 @@ GS_DIALOG *gui_new_dialog(void)
 	return standard_info;
 }
 
-
 /******************************************************************************
  * Name
  *   gui_generic_warning_modal
@@ -727,9 +715,9 @@ void gui_generic_warning_modal(const char *message)
 	dialog = gui_new_dialog();
 	dialog->stock_icon =
 #ifdef HAVE_GTK_310
-		"dialog-information";
+	    "dialog-information";
 #else
-		GTK_STOCK_DIALOG_INFO;
+	    GTK_STOCK_DIALOG_INFO;
 #endif
 
 	dialog_text = g_strdup_printf("<span weight=\"bold\">%s</span>",
@@ -743,7 +731,6 @@ void gui_generic_warning_modal(const char *message)
 	g_free(dialog_text);
 }
 
-
 /******************************************************************************
  * Name
  *   gui_generic_warning
@@ -765,20 +752,18 @@ void gui_generic_warning(const char *message)
 {
 	GtkWidget *dialog;
 
-	dialog = gtk_message_dialog_new_with_markup
-	    (NULL,	/* no need for a parent window */
-	     GTK_DIALOG_DESTROY_WITH_PARENT,
-	     GTK_MESSAGE_INFO,
-	     GTK_BUTTONS_OK,
-	     "<b><big>Xiphos</big></b>\n\n%s", message);
+	dialog = gtk_message_dialog_new_with_markup(NULL, /* no need for a parent window */
+						    GTK_DIALOG_DESTROY_WITH_PARENT,
+						    GTK_MESSAGE_INFO,
+						    GTK_BUTTONS_OK,
+						    "<b><big>Xiphos</big></b>\n\n%s",
+						    message);
 
-	g_signal_connect_swapped (dialog, "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  dialog);
+	g_signal_connect_swapped(dialog, "response",
+				 G_CALLBACK(gtk_widget_destroy), dialog);
 	gtk_widget_show(dialog);
 }
 
-
 /******************************************************************************
  * Name
  *   gui_gs_dialog
@@ -795,16 +780,15 @@ void gui_generic_warning(const char *message)
  *   gint
  */
 
-gint gui_gs_dialog(GS_DIALOG * info)
+gint gui_gs_dialog(GS_DIALOG *info)
 {
-	GtkWidget *dialog;
 	static gboolean is_running = FALSE;
 
 	if (!is_running) {
-		dialog = create_dialog_request(info);
+		GtkWidget *dialog = create_dialog_request(info);
 		retval = 4;
 		is_running = TRUE;
-		gtk_dialog_run((GtkDialog *) dialog);
+		gtk_dialog_run((GtkDialog *)dialog);
 		is_running = FALSE;
 		gtk_widget_destroy(dialog);
 		return retval;
@@ -828,16 +812,15 @@ gint gui_gs_dialog(GS_DIALOG * info)
  *   gint
  */
 
-gint gui_alert_dialog(GS_DIALOG * info)
+gint gui_alert_dialog(GS_DIALOG *info)
 {
-	GtkWidget *dialog;
 	static gboolean is_running = FALSE;
 
 	if (!is_running) {
-		dialog = create_dialog_alert(info);	//gs_dialog_build(info);
+		GtkWidget *dialog = create_dialog_alert(info); //gs_dialog_build(info);
 		retval = 4;
 		is_running = TRUE;
-		gtk_dialog_run((GtkDialog *) dialog);
+		gtk_dialog_run((GtkDialog *)dialog);
 		is_running = FALSE;
 		gtk_widget_destroy(dialog);
 		return retval;
@@ -861,28 +844,29 @@ gint gui_alert_dialog(GS_DIALOG * info)
  *   gint
  */
 
-gint gui_close_confirmation_dialog(GS_DIALOG * info)
+gint gui_close_confirmation_dialog(GS_DIALOG *info)
 {
-	GtkWidget *dialog;
 	static gboolean is_running = FALSE;
 
 	if (!is_running) {
-		dialog = create_dialog_alert(info);
-		gtk_dialog_add_button (GTK_DIALOG (dialog),
-				       _("Close _without Saving"),
-				       GTK_RESPONSE_NO);
-#ifdef HAVE_GTK_310	
-		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-					"_Cancel", GTK_RESPONSE_CANCEL,
-					"document-save", GTK_RESPONSE_YES, NULL);
-#else	
-		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_SAVE, GTK_RESPONSE_YES, NULL);
+		GtkWidget *dialog = create_dialog_alert(info);
+		gtk_dialog_add_button(GTK_DIALOG(dialog),
+				      _("Close _without Saving"),
+				      GTK_RESPONSE_NO);
+#ifdef HAVE_GTK_310
+		gtk_dialog_add_buttons(GTK_DIALOG(dialog),
+				       "_Cancel", GTK_RESPONSE_CANCEL,
+				       "document-save", GTK_RESPONSE_YES,
+				       NULL);
+#else
+		gtk_dialog_add_buttons(GTK_DIALOG(dialog),
+				       GTK_STOCK_CANCEL,
+				       GTK_RESPONSE_CANCEL, GTK_STOCK_SAVE,
+				       GTK_RESPONSE_YES, NULL);
 #endif
 		retval = 4;
 		is_running = TRUE;
-		gtk_dialog_run((GtkDialog *) dialog);
+		gtk_dialog_run((GtkDialog *)dialog);
 		is_running = FALSE;
 		gtk_widget_destroy(dialog);
 		return retval;
@@ -912,11 +896,11 @@ gint gui_yes_no_dialog(char *question, char *icon)
 	gint result;
 
 	yes_no = gui_new_dialog();
-#ifdef HAVE_GTK_310	
+#ifdef HAVE_GTK_310
 	yes_no->stock_icon = (icon ? icon : "dialog-question");
-#else	
+#else
 	yes_no->stock_icon = (icon ? icon : GTK_STOCK_DIALOG_QUESTION);
-#endif	
+#endif
 	yes_no->label_top = question;
 	yes_no->yes = TRUE;
 	yes_no->no = TRUE;
