@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * gbs_dialog.c - dialog for displaying a gbs module
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,8 +59,6 @@ static DIALOG_DATA *cur_dlg;
 static GtkTreeModel *model;
 //static gint tree_level;
 
-
-
 /******************************************************************************
  * Name
  *   dialog_destroy
@@ -77,15 +75,13 @@ static GtkTreeModel *model;
  *   void
  */
 
-static void dialog_destroy(GObject *object,
-			   DIALOG_DATA *dlg)
+static void dialog_destroy(GObject *object, DIALOG_DATA *dlg)
 {
 	if (!dialog_freed)
 		main_free_on_destroy(dlg);
 	dialog_freed = FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   dialog_url
@@ -169,7 +165,7 @@ static void dialog_url(GtkHTML * html, const gchar * url,
  */
 
 static void tree_selection_changed(GtkTreeSelection *selection,
-				  DIALOG_DATA *g)
+				   DIALOG_DATA *g)
 {
 	GtkTreeModel *model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(g->tree));
@@ -177,72 +173,61 @@ static void tree_selection_changed(GtkTreeSelection *selection,
 	main_dialogs_tree_selection_changed(model, selection, TRUE, g);
 }
 
-static GtkTreeModel *create_model (void)
+static GtkTreeModel *create_model(void)
 {
 	GtkTreeStore *model;
 
 	/* create tree store */
-	model = gtk_tree_store_new (N_COLUMNS,
-				    GDK_TYPE_PIXBUF,
-				    GDK_TYPE_PIXBUF,
-				    G_TYPE_STRING,
-				    G_TYPE_STRING,
-				    G_TYPE_STRING);
+	model = gtk_tree_store_new(N_COLUMNS,
+				   GDK_TYPE_PIXBUF,
+				   GDK_TYPE_PIXBUF,
+				   G_TYPE_STRING,
+				   G_TYPE_STRING, G_TYPE_STRING);
 	return GTK_TREE_MODEL(model);
 }
 
 static void add_columns(GtkTreeView *tree)
 {
 	GtkTreeViewColumn *column;
-//	GtkTreeViewColumn *column2;
+	//      GtkTreeViewColumn *column2;
 	GtkCellRenderer *renderer;
 
-	column = gtk_tree_view_column_new ();
+	column = gtk_tree_view_column_new();
 
-	renderer = GTK_CELL_RENDERER (gtk_cell_renderer_pixbuf_new ());
-	gtk_tree_view_column_pack_start (column, renderer, FALSE);
-	gtk_tree_view_column_set_attributes
-		(column, renderer,
-		 "pixbuf", COL_OPEN_PIXBUF,
-		 "pixbuf-expander-open", COL_OPEN_PIXBUF,
-		 "pixbuf-expander-closed", COL_CLOSED_PIXBUF,
-		 NULL);
+	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_pixbuf_new());
+	gtk_tree_view_column_pack_start(column, renderer, FALSE);
+	gtk_tree_view_column_set_attributes(column, renderer,
+					    "pixbuf", COL_OPEN_PIXBUF,
+					    "pixbuf-expander-open", COL_OPEN_PIXBUF,
+					    "pixbuf-expander-closed", COL_CLOSED_PIXBUF, NULL);
 
+	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_attributes(column, renderer,
+					    "text", COL_TITLE, NULL);
+	gtk_tree_view_append_column(tree, column);
 
+	column = gtk_tree_view_column_new();
+	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_attributes(column, renderer,
+					    "text", COL_BOOK, NULL);
+	gtk_tree_view_append_column(tree, column);
+	gtk_tree_view_column_set_visible(column, FALSE);
 
-	renderer = GTK_CELL_RENDERER (gtk_cell_renderer_text_new ());
-	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes (column, renderer,
-					     "text", COL_TITLE,
-					     NULL);
-	gtk_tree_view_append_column (tree, column);
-
-
-	column = gtk_tree_view_column_new ();
-	renderer = GTK_CELL_RENDERER (gtk_cell_renderer_text_new ());
-	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes (column, renderer,
-					     "text", COL_BOOK,
-					     NULL);
-	gtk_tree_view_append_column (tree, column);
-	gtk_tree_view_column_set_visible(column,FALSE);
-
-	column = gtk_tree_view_column_new ();
-	renderer = GTK_CELL_RENDERER (gtk_cell_renderer_text_new ());
-	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes (column, renderer,
-					     "text", COL_OFFSET,
-					     NULL);
-	gtk_tree_view_append_column (tree, column);
-	gtk_tree_view_column_set_visible(column,FALSE);
+	column = gtk_tree_view_column_new();
+	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_attributes(column, renderer,
+					    "text", COL_OFFSET, NULL);
+	gtk_tree_view_append_column(tree, column);
+	gtk_tree_view_column_set_visible(column, FALSE);
 }
 
 static void
-_popupmenu_requested_cb (XiphosHtml *html,
-			 gchar *uri,
-			 DIALOG_DATA *d)
+_popupmenu_requested_cb(XiphosHtml *html, gchar *uri, DIALOG_DATA *d)
 {
-	gui_menu_popup (html, cur_dlg->mod_name, cur_dlg);
+	gui_menu_popup(html, cur_dlg->mod_name, cur_dlg);
 }
 
 /******************************************************************************
@@ -287,29 +272,26 @@ void gui_create_gbs_dialog(DIALOG_DATA *dlg)
 
 	hpaned = UI_HPANE();
 	gtk_widget_show(hpaned);
-	gtk_box_pack_start(GTK_BOX(vbox_dialog), hpaned, TRUE, TRUE,
-			   0);
+	gtk_box_pack_start(GTK_BOX(vbox_dialog), hpaned, TRUE, TRUE, 0);
 	//gtk_container_add(GTK_CONTAINER(frame_gbs), hpaned);
 	//gtk_paned_set_position(GTK_PANED(hpaned), 190);
 
 	scrolledwindow_ctree = gtk_scrolled_window_new(NULL, NULL);
 	//gtk_widget_show(scrolledwindow_ctree);
 	gtk_paned_pack1(GTK_PANED(hpaned), scrolledwindow_ctree, FALSE,
-		      TRUE);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
-				       (scrolledwindow_ctree),
+			TRUE);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow_ctree),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_ctree,
-                                             settings.shadow_type);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolledwindow_ctree,
+					    settings.shadow_type);
 
 	model = create_model();
 	dlg->tree = gtk_tree_view_new_with_model(model);
-	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(dlg->tree),
-					  FALSE);
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(dlg->tree), FALSE);
 	gtk_widget_show(dlg->tree);
-	gtk_container_add(GTK_CONTAINER(scrolledwindow_ctree),
-			  dlg->tree);
+	gtk_container_add(GTK_CONTAINER(scrolledwindow_ctree), dlg->tree);
 	add_columns(GTK_TREE_VIEW(dlg->tree));
 
 	selection =
@@ -317,37 +299,39 @@ void gui_create_gbs_dialog(DIALOG_DATA *dlg)
 
 	scrolledwindow_html = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow_html);
-	gtk_paned_pack2(GTK_PANED(hpaned), scrolledwindow_html, FALSE, TRUE);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
-				       (scrolledwindow_html),
+	gtk_paned_pack2(GTK_PANED(hpaned), scrolledwindow_html, FALSE,
+			TRUE);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow_html),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolledwindow_html,
-                                             settings.shadow_type);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolledwindow_html,
+					    settings.shadow_type);
 
-	dlg->html = GTK_WIDGET(XIPHOS_HTML_NEW(((DIALOG_DATA*) dlg),TRUE,DIALOG_BOOK_TYPE));
+	dlg->html =
+	    GTK_WIDGET(XIPHOS_HTML_NEW(((DIALOG_DATA *)dlg), TRUE, DIALOG_BOOK_TYPE));
 	gtk_container_add(GTK_CONTAINER(scrolledwindow_html), dlg->html);
 	gtk_widget_show(dlg->html);
 	g_signal_connect((gpointer)dlg->html,
-		      "popupmenu_requested",
-		      G_CALLBACK (_popupmenu_requested_cb),
-		      (DIALOG_DATA*)dlg);
+			 "popupmenu_requested",
+			 G_CALLBACK(_popupmenu_requested_cb),
+			 (DIALOG_DATA *)dlg);
 
 	g_signal_connect(selection, "changed",
 			 G_CALLBACK(tree_selection_changed),
-			   (DIALOG_DATA *) dlg);
+			 (DIALOG_DATA *)dlg);
 	dlg->statusbar = gtk_statusbar_new();
 	gtk_widget_show(dlg->statusbar);
 	gtk_box_pack_start(GTK_BOX(vbox_dialog), dlg->statusbar, FALSE,
 			   FALSE, 0);
 
 	g_signal_connect(G_OBJECT(dlg->dialog), "destroy",
-			   G_CALLBACK(dialog_destroy),
-			   (DIALOG_DATA *) dlg); 
-	cur_dlg =  dlg;
+			 G_CALLBACK(dialog_destroy), (DIALOG_DATA *)dlg);
+	cur_dlg = dlg;
 }
 
-
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 /******************************************************************************
  * Name
  *   gui_close_gbs_dialog
@@ -364,12 +348,13 @@ void gui_create_gbs_dialog(DIALOG_DATA *dlg)
  *   void
  */
 
-void gui_close_gbs_dialog(DIALOG_DATA * dlg)
+void gui_close_gbs_dialog(DIALOG_DATA *dlg)
 {
 	if (dlg->dialog) {
 		dialog_freed = FALSE;
 		gtk_widget_destroy(dlg->dialog);
 	}
 }
+#endif
 
 //******  end of file  ******/
