@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar_verse.c - navigation bar for versekey modules
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 #include <gtk/gtk.h>
 #ifndef USE_GTKBUILDER
-  #include <glade/glade-xml.h>
+#include <glade/glade-xml.h>
 #endif
 
 #include "editor/slib-editor.h"
@@ -35,7 +35,6 @@
 #include "gui/tabbed_browser.h"
 #include "gui/utilities.h"
 
-
 #include "main/module_dialogs.h"
 #include "main/navbar_versekey.h"
 #include "main/settings.h"
@@ -49,8 +48,6 @@ NAVBAR_VERSEKEY navbar_versekey;
 
 extern PASSAGE_TAB_INFO *cur_passage_tab;
 
-
-
 /******************************************************************************
  * Name
  *   menu_deactivate_callback
@@ -67,16 +64,17 @@ extern PASSAGE_TAB_INFO *cur_passage_tab;
  *   void
  */
 
-static void menu_deactivate_callback(GtkWidget * widget, gpointer user_data)
+static void menu_deactivate_callback(GtkWidget *widget,
+				     gpointer user_data)
 {
 	GtkWidget *menu_button;
 
 	menu_button = GTK_WIDGET(user_data);
 
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(menu_button), FALSE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(menu_button),
+				     FALSE);
 }
 
-
 /******************************************************************************
  * Name
  *   menu_position_under
@@ -95,32 +93,28 @@ static void menu_deactivate_callback(GtkWidget * widget, gpointer user_data)
  *   void
  */
 
-static
-void menu_position_under(GtkMenu * menu, int * x, int * y,
-				gboolean * push_in, gpointer user_data)
+static void menu_position_under(GtkMenu *menu, int *x, int *y,
+				gboolean *push_in, gpointer user_data)
 {
 	GtkWidget *widget;
 	GtkAllocation allocation;
 
 	g_return_if_fail(GTK_IS_BUTTON(user_data));
 #if defined(HAVE_GTK_220) || defined(USE_GTK_3)
-        g_return_if_fail (gtk_widget_get_window(user_data));
+	g_return_if_fail(gtk_widget_get_window(user_data));
 #else
-	g_return_if_fail (GTK_WIDGET_NO_WINDOW (user_data));
+	g_return_if_fail(GTK_WIDGET_NO_WINDOW(user_data));
 #endif
 	widget = GTK_WIDGET(user_data);
 
-	
-	gdk_window_get_origin(gtk_widget_get_window (widget), x, y);
-	gtk_widget_get_allocation (widget, &allocation);
+	gdk_window_get_origin(gtk_widget_get_window(widget), x, y);
+	gtk_widget_get_allocation(widget, &allocation);
 	*x += allocation.x;
 	*y += allocation.y + allocation.height;
 
-
 	*push_in = FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   select_button_press_callback
@@ -140,8 +134,8 @@ void menu_position_under(GtkMenu * menu, int * x, int * y,
  *   gboolean
  */
 
-static gboolean select_button_press_callback(GtkWidget * widget,
-					     GdkEventButton * event,
+static gboolean select_button_press_callback(GtkWidget *widget,
+					     GdkEventButton *event,
 					     gpointer user_data)
 {
 	GtkWidget *menu;
@@ -153,19 +147,16 @@ static gboolean select_button_press_callback(GtkWidget * widget,
 			 G_CALLBACK(menu_deactivate_callback), widget);
 	if ((event->type == GDK_BUTTON_PRESS) && event->button == 1) {
 		gtk_widget_grab_focus(widget);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
-		gtk_menu_popup(GTK_MENU(menu), 
-		           NULL, 
-		           NULL,
-		           menu_position_under, 
-		           widget, event->button,
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
+					     TRUE);
+		gtk_menu_popup(GTK_MENU(menu), NULL, NULL,
+			       menu_position_under, widget, event->button,
 			       event->time);
 		return TRUE;
 	}
 	return FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   select_button_press_callback
@@ -185,9 +176,9 @@ static gboolean select_button_press_callback(GtkWidget * widget,
  *   gboolean
  */
 
-static gboolean select_book_button_press_callback(GtkWidget * widget,
-					     GdkEventButton * event,
-					     gpointer user_data)
+static gboolean select_book_button_press_callback(GtkWidget *widget,
+						  GdkEventButton *event,
+						  gpointer user_data)
 {
 	GtkWidget *menu;
 
@@ -198,17 +189,18 @@ static gboolean select_book_button_press_callback(GtkWidget * widget,
 	guint32 time_add;
 #endif
 
-	g_get_current_time( &start_time );
-//	XI_message(("Start time is: %d sec %d mil", start_time.tv_sec, start_time.tv_usec));
+	g_get_current_time(&start_time);
+	//      XI_message(("Start time is: %d sec %d mil", start_time.tv_sec, start_time.tv_usec));
 
 	menu = main_versekey_drop_down_book_menu(navbar_versekey, NB_MAIN,
-						NULL,NULL);
+						 NULL, NULL);
 
-	g_get_current_time( &end_time );
-//	XI_message(("End time is: %d sec %d mil", end_time.tv_sec, end_time.tv_usec));
+	g_get_current_time(&end_time);
+//      XI_message(("End time is: %d sec %d mil", end_time.tv_sec, end_time.tv_usec));
 #ifdef WIN32
-	time_diff = ((end_time.tv_sec - start_time.tv_sec) * 1000000) + (end_time.tv_usec - start_time.tv_usec);
-	time_add = 0;
+	time_diff =
+	    ((end_time.tv_sec - start_time.tv_sec) * 1000000) +
+	    (end_time.tv_usec - start_time.tv_usec);
 	//if (time_diff > 10000)
 	time_add = (guint32)(time_diff / 1000);
 #endif
@@ -218,21 +210,20 @@ static gboolean select_book_button_press_callback(GtkWidget * widget,
 			 G_CALLBACK(menu_deactivate_callback), widget);
 	if ((event->type == GDK_BUTTON_PRESS) && event->button == 1) {
 		gtk_widget_grab_focus(widget);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
+					     TRUE);
 		gtk_menu_popup(GTK_MENU(menu), NULL, NULL,
-			       menu_position_under,widget, event->button,
+			       menu_position_under, widget, event->button,
 #ifdef WIN32
 			       event->time + time_add);
 #else
-		               event->time);
+			       event->time);
 #endif
 		return TRUE;
 	}
 	return FALSE;
 }
 
-
-
 /******************************************************************************
  * Name
  *   select_button_press_callback
@@ -252,21 +243,24 @@ static gboolean select_book_button_press_callback(GtkWidget * widget,
  *   gboolean
  */
 
-static gboolean select_chapter_button_press_callback(GtkWidget * widget,
-					     GdkEventButton * event,
-					     gpointer user_data)
+static gboolean select_chapter_button_press_callback(GtkWidget *widget,
+						     GdkEventButton *
+							 event,
+						     gpointer user_data)
 {
 	GtkWidget *menu;
 
-	menu = main_versekey_drop_down_chapter_menu(navbar_versekey, NB_MAIN,
-						NULL,NULL);
+	menu =
+	    main_versekey_drop_down_chapter_menu(navbar_versekey, NB_MAIN,
+						 NULL, NULL);
 	if (!menu)
 		return 0;
 	g_signal_connect(menu, "deactivate",
 			 G_CALLBACK(menu_deactivate_callback), widget);
 	if ((event->type == GDK_BUTTON_PRESS) && event->button == 1) {
 		gtk_widget_grab_focus(widget);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
+					     TRUE);
 		gtk_menu_popup(GTK_MENU(menu), NULL, NULL,
 			       menu_position_under, widget, event->button,
 			       event->time);
@@ -275,8 +269,6 @@ static gboolean select_chapter_button_press_callback(GtkWidget * widget,
 	return FALSE;
 }
 
-
-
 /******************************************************************************
  * Name
  *   select_button_press_callback
@@ -296,21 +288,22 @@ static gboolean select_chapter_button_press_callback(GtkWidget * widget,
  *   gboolean
  */
 
-static gboolean select_verse_button_press_callback(GtkWidget * widget,
-					     GdkEventButton * event,
-					     gpointer user_data)
+static gboolean select_verse_button_press_callback(GtkWidget *widget,
+						   GdkEventButton *event,
+						   gpointer user_data)
 {
 	GtkWidget *menu;
 
 	menu = main_versekey_drop_down_verse_menu(navbar_versekey, NB_MAIN,
-						NULL,NULL);
+						  NULL, NULL);
 	if (!menu)
 		return 0;
 	g_signal_connect(menu, "deactivate",
 			 G_CALLBACK(menu_deactivate_callback), widget);
 	if ((event->type == GDK_BUTTON_PRESS) && event->button == 1) {
 		gtk_widget_grab_focus(widget);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
+					     TRUE);
 		gtk_menu_popup(GTK_MENU(menu), NULL, NULL,
 			       menu_position_under, widget, event->button,
 			       event->time);
@@ -319,7 +312,6 @@ static gboolean select_verse_button_press_callback(GtkWidget * widget,
 	return FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *  on_button_history_next_clicked
@@ -336,13 +328,11 @@ static gboolean select_verse_button_press_callback(GtkWidget * widget,
  *   void
  */
 
-static
-void on_button_history_next_clicked(GtkButton * button, gpointer user_data)
+static void on_button_history_next_clicked(GtkButton *button, gpointer user_data)
 {
 	main_navigate_tab_history(1);
 }
 
-
 /******************************************************************************
  * Name
  *  on_button_history_back_clicked
@@ -359,8 +349,7 @@ void on_button_history_next_clicked(GtkButton * button, gpointer user_data)
  *   void
  */
 
-static
-void on_button_history_back_clicked(GtkButton * button, gpointer user_data)
+static void on_button_history_back_clicked(GtkButton *button, gpointer user_data)
 {
 	main_navigate_tab_history(0);
 }
@@ -381,7 +370,7 @@ void on_button_history_back_clicked(GtkButton * button, gpointer user_data)
  *   void
  */
 
-static void on_entry_activate(GtkEntry * entry, gpointer user_data)
+static void on_entry_activate(GtkEntry *entry, gpointer user_data)
 {
 	char *rawtext;
 	const gchar *gkey, *buf = gtk_entry_get_text(entry);
@@ -389,43 +378,46 @@ static void on_entry_activate(GtkEntry * entry, gpointer user_data)
 	if (buf == NULL)
 		return;
 	/* handle potential subsection anchor */
-	if ((settings.special_anchor = strchr(buf, '#')) ||	/* thml */
-	    (settings.special_anchor = strchr(buf, '!')))	/* osisref */
+	if ((settings.special_anchor = strchr(buf, '#')) || /* thml */
+	    (settings.special_anchor = strchr(buf, '!')))   /* osisref */
 		*settings.special_anchor = '\0';
 
-	rawtext = main_get_raw_text(navbar_versekey.module_name->str, (gchar*)buf);
-	if (!rawtext || (rawtext && (strlen(rawtext) < 2))){
+	rawtext =
+	    main_get_raw_text(navbar_versekey.module_name->str,
+			      (gchar *)buf);
+	if (!rawtext || (rawtext && (strlen(rawtext) < 2))) {
 		gtk_entry_set_text(entry, navbar_versekey.key->str);
 		g_free(rawtext);
 		return;
 	}
 
-	gkey = main_get_valid_key(settings.MainWindowModule, (gchar*)buf);
+	gkey =
+	    main_get_valid_key(settings.MainWindowModule, (gchar *)buf);
 
 	// we got a valid key. but was it really a valid key within v11n?
 	// for future use in determining whether to show normal navbar content.
-	navbar_versekey.valid_key = main_is_Bible_key(settings.MainWindowModule, gkey);
+	navbar_versekey.valid_key =
+	    main_is_Bible_key(settings.MainWindowModule, gkey);
 
 	if (settings.special_anchor)
-		*settings.special_anchor = '#';			/* put it back. */
+		*settings.special_anchor = '#'; /* put it back. */
 	if (gkey == NULL)
 		return;
 
-	gchar *url = g_strdup_printf("sword:///%s%s", gkey, (settings.special_anchor
-							     ? settings.special_anchor
-							     : ""));
+	gchar *url = g_strdup_printf("sword:///%s%s", gkey,
+				     (settings.special_anchor ? settings.special_anchor : ""));
 
-	navbar_versekey.module_name = g_string_assign(navbar_versekey.module_name,
-						      settings.MainWindowModule);
+	navbar_versekey.module_name =
+	    g_string_assign(navbar_versekey.module_name,
+			    settings.MainWindowModule);
 	main_navbar_versekey_set(navbar_versekey, gkey);
 	main_url_handler(url, TRUE);
 	if (url)
 		g_free(url);
 	if (gkey)
-		g_free((gchar*)gkey);
+		g_free((gchar *)gkey);
 }
 
-
 /******************************************************************************
  * Name
  *  on_button_verse_menu_verse_scroll_event
@@ -444,17 +436,15 @@ static void on_entry_activate(GtkEntry * entry, gpointer user_data)
  *   gboolean
  */
 
-static
-gboolean on_button_verse_menu_verse_scroll_event(GtkWidget * widget,
-                                            GdkEvent * event,
-                                            gpointer user_data)
+static gboolean on_button_verse_menu_verse_scroll_event(GtkWidget *widget,
+							GdkEvent *event,
+							gpointer user_data)
 {
-	main_navbar_versekey_spin_verse(navbar_versekey, event->scroll.direction);
+	main_navbar_versekey_spin_verse(navbar_versekey,
+					event->scroll.direction);
 	return FALSE;
 }
 
-
-
 /******************************************************************************
  * Name
  *  on_button_verse_menu_chapter_scroll_event
@@ -473,18 +463,15 @@ gboolean on_button_verse_menu_verse_scroll_event(GtkWidget * widget,
  *   gboolean
  */
 
-static
-gboolean on_button_verse_menu_chapter_scroll_event(GtkWidget * widget,
-                                            GdkEvent * event,
-                                            gpointer user_data)
+static gboolean on_button_verse_menu_chapter_scroll_event(GtkWidget *widget,
+							  GdkEvent *event,
+							  gpointer user_data)
 {
 	main_navbar_versekey_spin_chapter(navbar_versekey,
-				event->scroll.direction);
+					  event->scroll.direction);
 	return FALSE;
 }
 
-
-
 /******************************************************************************
  * Name
  *  on_button_verse_menu_book_scroll_event
@@ -503,17 +490,15 @@ gboolean on_button_verse_menu_chapter_scroll_event(GtkWidget * widget,
  *   gboolean
  */
 
-static
-gboolean on_button_verse_menu_book_scroll_event(GtkWidget * widget,
-                                            GdkEvent * event,
-                                            gpointer user_data)
+static gboolean on_button_verse_menu_book_scroll_event(GtkWidget *widget,
+						       GdkEvent *event,
+						       gpointer user_data)
 {
 	main_navbar_versekey_spin_book(navbar_versekey,
-				event->scroll.direction);
+				       event->scroll.direction);
 	return FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   on_up_enter_notify_event
@@ -532,28 +517,27 @@ gboolean on_button_verse_menu_book_scroll_event(GtkWidget * widget,
  *   gboolean
  */
 
-static
-gboolean on_up_enter_notify_event(GtkWidget * widget, GdkEventCrossing * event,
-                                        gpointer  user_data)
+static gboolean on_up_enter_notify_event(GtkWidget *widget,
+					 GdkEventCrossing *event,
+					 gpointer user_data)
 {
 	switch (GPOINTER_TO_INT(user_data)) {
-		case BOOK_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_book_up);
-			gtk_widget_show(navbar_versekey.arrow_book_up_box);
+	case BOOK_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_book_up);
+		gtk_widget_show(navbar_versekey.arrow_book_up_box);
 		break;
-		case CHAPTER_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_chapter_up);
-			gtk_widget_show(navbar_versekey.arrow_chapter_up_box);
+	case CHAPTER_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_chapter_up);
+		gtk_widget_show(navbar_versekey.arrow_chapter_up_box);
 		break;
-		case VERSE_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_verse_up);
-			gtk_widget_show(navbar_versekey.arrow_verse_up_box);
+	case VERSE_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_verse_up);
+		gtk_widget_show(navbar_versekey.arrow_verse_up_box);
 		break;
 	}
 	return FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   on_down_enter_notify_event
@@ -572,28 +556,27 @@ gboolean on_up_enter_notify_event(GtkWidget * widget, GdkEventCrossing * event,
  *   gboolean
  */
 
-static
-gboolean on_down_enter_notify_event(GtkWidget * widget, GdkEventCrossing * event,
-                                        gpointer user_data)
+static gboolean on_down_enter_notify_event(GtkWidget *widget,
+					   GdkEventCrossing *event,
+					   gpointer user_data)
 {
 	switch (GPOINTER_TO_INT(user_data)) {
-		case BOOK_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_book_down);
-			gtk_widget_show(navbar_versekey.arrow_book_down_box);
+	case BOOK_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_book_down);
+		gtk_widget_show(navbar_versekey.arrow_book_down_box);
 		break;
-		case CHAPTER_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_chapter_down);
-			gtk_widget_show(navbar_versekey.arrow_chapter_down_box);
+	case CHAPTER_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_chapter_down);
+		gtk_widget_show(navbar_versekey.arrow_chapter_down_box);
 		break;
-		case VERSE_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_verse_down);
-			gtk_widget_show(navbar_versekey.arrow_verse_down_box);
+	case VERSE_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_verse_down);
+		gtk_widget_show(navbar_versekey.arrow_verse_down_box);
 		break;
 	}
 	return FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   on_up_leave_notify_event
@@ -612,28 +595,27 @@ gboolean on_down_enter_notify_event(GtkWidget * widget, GdkEventCrossing * event
  *   gboolean
  */
 
-static
-gboolean on_up_leave_notify_event(GtkWidget * widget, GdkEventCrossing * event,
-                                        gpointer user_data)
+static gboolean on_up_leave_notify_event(GtkWidget *widget,
+					 GdkEventCrossing *event,
+					 gpointer user_data)
 {
 	switch (GPOINTER_TO_INT(user_data)) {
-		case BOOK_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_book_up_box);
-			gtk_widget_show(navbar_versekey.arrow_book_up);
+	case BOOK_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_book_up_box);
+		gtk_widget_show(navbar_versekey.arrow_book_up);
 		break;
-		case CHAPTER_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_chapter_up_box);
-			gtk_widget_show(navbar_versekey.arrow_chapter_up);
+	case CHAPTER_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_chapter_up_box);
+		gtk_widget_show(navbar_versekey.arrow_chapter_up);
 		break;
-		case VERSE_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_verse_up_box);
-			gtk_widget_show(navbar_versekey.arrow_verse_up);
+	case VERSE_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_verse_up_box);
+		gtk_widget_show(navbar_versekey.arrow_verse_up);
 		break;
 	}
 	return FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   on_down_leave_notify_event
@@ -652,28 +634,27 @@ gboolean on_up_leave_notify_event(GtkWidget * widget, GdkEventCrossing * event,
  *   gboolean
  */
 
-static
-gboolean on_down_leave_notify_event(GtkWidget * widget, GdkEventCrossing * event,
-                                        gpointer user_data)
+static gboolean on_down_leave_notify_event(GtkWidget *widget,
+					   GdkEventCrossing *event,
+					   gpointer user_data)
 {
 	switch (GPOINTER_TO_INT(user_data)) {
-		case BOOK_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_book_down_box);
-			gtk_widget_show(navbar_versekey.arrow_book_down);
+	case BOOK_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_book_down_box);
+		gtk_widget_show(navbar_versekey.arrow_book_down);
 		break;
-		case CHAPTER_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_chapter_down_box);
-			gtk_widget_show(navbar_versekey.arrow_chapter_down);
+	case CHAPTER_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_chapter_down_box);
+		gtk_widget_show(navbar_versekey.arrow_chapter_down);
 		break;
-		case VERSE_BUTTON:
-			gtk_widget_hide(navbar_versekey.arrow_verse_down_box);
-			gtk_widget_show(navbar_versekey.arrow_verse_down);
+	case VERSE_BUTTON:
+		gtk_widget_hide(navbar_versekey.arrow_verse_down_box);
+		gtk_widget_show(navbar_versekey.arrow_verse_down);
 		break;
 	}
 	return FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   on_up_eventbox_button_release_event
@@ -692,26 +673,24 @@ gboolean on_down_leave_notify_event(GtkWidget * widget, GdkEventCrossing * event
  *   gboolean
  */
 
-static
-gboolean on_up_eventbox_button_release_event (GtkWidget * widget,
-                                        	GdkEventButton * event,
-                                        	gpointer user_data)
+static gboolean on_up_eventbox_button_release_event(GtkWidget *widget,
+						    GdkEventButton *event,
+						    gpointer user_data)
 {
 	switch (GPOINTER_TO_INT(user_data)) {
-		case BOOK_BUTTON:
-			main_navbar_versekey_spin_book(navbar_versekey,0);
+	case BOOK_BUTTON:
+		main_navbar_versekey_spin_book(navbar_versekey, 0);
 		break;
-		case CHAPTER_BUTTON:
-			main_navbar_versekey_spin_chapter(navbar_versekey,0);
+	case CHAPTER_BUTTON:
+		main_navbar_versekey_spin_chapter(navbar_versekey, 0);
 		break;
-		case VERSE_BUTTON:
-			main_navbar_versekey_spin_verse(navbar_versekey,0);
+	case VERSE_BUTTON:
+		main_navbar_versekey_spin_verse(navbar_versekey, 0);
 		break;
 	}
 	return FALSE;
 }
 
-
 /******************************************************************************
  * Name
  *   on_down_eventbox_button_release_event
@@ -730,20 +709,19 @@ gboolean on_up_eventbox_button_release_event (GtkWidget * widget,
  *   gboolean
  */
 
-static
-gboolean on_down_eventbox_button_release_event(GtkWidget * widget,
-                                       	GdkEventButton * event,
-                                       	gpointer user_data)
+static gboolean on_down_eventbox_button_release_event(GtkWidget *widget,
+						      GdkEventButton *event,
+						      gpointer user_data)
 {
 	switch (GPOINTER_TO_INT(user_data)) {
-		case BOOK_BUTTON:
-			main_navbar_versekey_spin_book(navbar_versekey,1);
+	case BOOK_BUTTON:
+		main_navbar_versekey_spin_book(navbar_versekey, 1);
 		break;
-		case CHAPTER_BUTTON:
-			main_navbar_versekey_spin_chapter(navbar_versekey,1);
+	case CHAPTER_BUTTON:
+		main_navbar_versekey_spin_chapter(navbar_versekey, 1);
 		break;
-		case VERSE_BUTTON:
-			main_navbar_versekey_spin_verse(navbar_versekey,1);
+	case VERSE_BUTTON:
+		main_navbar_versekey_spin_verse(navbar_versekey, 1);
 		break;
 	}
 	return FALSE;
@@ -767,8 +745,7 @@ gboolean on_down_eventbox_button_release_event(GtkWidget * widget,
 
 gboolean access_on_up_eventbox_button_release_event(gint element)
 {
-	return on_up_eventbox_button_release_event
-	    (NULL, NULL, GINT_TO_POINTER(element));
+	return on_up_eventbox_button_release_event(NULL, NULL, GINT_TO_POINTER(element));
 }
 
 /******************************************************************************
@@ -789,8 +766,7 @@ gboolean access_on_up_eventbox_button_release_event(gint element)
 
 gboolean access_on_down_eventbox_button_release_event(gint element)
 {
-	return on_down_eventbox_button_release_event
-	    (NULL, NULL, GINT_TO_POINTER(element));
+	return on_down_eventbox_button_release_event(NULL, NULL, GINT_TO_POINTER(element));
 }
 
 /******************************************************************************
@@ -809,118 +785,123 @@ gboolean access_on_down_eventbox_button_release_event(gint element)
  *  void
  */
 
-static
-void _connect_signals(NAVBAR_VERSEKEY navbar)
+static void _connect_signals(NAVBAR_VERSEKEY navbar)
 {
 
-	g_signal_connect((gpointer) navbar.lookup_entry,
-			 "activate", G_CALLBACK(on_entry_activate),
-			 NULL);
-	g_signal_connect((gpointer) navbar.button_book_up,
-			 "button_release_event",
-			G_CALLBACK(on_up_eventbox_button_release_event),
-			 GINT_TO_POINTER(BOOK_BUTTON));
-	g_signal_connect((gpointer) navbar.button_book_down,
-			 "button_release_event",
-			G_CALLBACK(on_down_eventbox_button_release_event),
-			 GINT_TO_POINTER(BOOK_BUTTON));
-	g_signal_connect((gpointer) navbar.button_chapter_up,
-			 "button_release_event",
-			G_CALLBACK(on_up_eventbox_button_release_event),
-			GINT_TO_POINTER(CHAPTER_BUTTON) );
-	g_signal_connect((gpointer) navbar.button_chapter_down,
-			 "button_release_event",
-			G_CALLBACK(on_down_eventbox_button_release_event),
-			GINT_TO_POINTER(CHAPTER_BUTTON) );
-	g_signal_connect((gpointer) navbar.button_verse_up,
+	g_signal_connect((gpointer)navbar.lookup_entry,
+			 "activate", G_CALLBACK(on_entry_activate), NULL);
+	g_signal_connect((gpointer)navbar.button_book_up,
 			 "button_release_event",
 			 G_CALLBACK(on_up_eventbox_button_release_event),
-			GINT_TO_POINTER(VERSE_BUTTON) );
-	g_signal_connect((gpointer) navbar.button_verse_down,
+			 GINT_TO_POINTER(BOOK_BUTTON));
+	g_signal_connect((gpointer)navbar.button_book_down,
 			 "button_release_event",
 			 G_CALLBACK(on_down_eventbox_button_release_event),
-			GINT_TO_POINTER(VERSE_BUTTON) );
+			 GINT_TO_POINTER(BOOK_BUTTON));
+	g_signal_connect((gpointer)navbar.button_chapter_up,
+			 "button_release_event",
+			 G_CALLBACK(on_up_eventbox_button_release_event),
+			 GINT_TO_POINTER(CHAPTER_BUTTON));
+	g_signal_connect((gpointer)navbar.button_chapter_down,
+			 "button_release_event",
+			 G_CALLBACK(on_down_eventbox_button_release_event),
+			 GINT_TO_POINTER(CHAPTER_BUTTON));
+	g_signal_connect((gpointer)navbar.button_verse_up,
+			 "button_release_event",
+			 G_CALLBACK(on_up_eventbox_button_release_event),
+			 GINT_TO_POINTER(VERSE_BUTTON));
+	g_signal_connect((gpointer)navbar.button_verse_down,
+			 "button_release_event",
+			 G_CALLBACK(on_down_eventbox_button_release_event),
+			 GINT_TO_POINTER(VERSE_BUTTON));
 	/*     */
-	g_signal_connect ((gpointer) navbar.button_book_up,
-			"enter_notify_event",
-		    	G_CALLBACK (on_up_enter_notify_event),
-		    	GINT_TO_POINTER(BOOK_BUTTON));
-	g_signal_connect ((gpointer) navbar.button_book_up,
-			"leave_notify_event",
-		    	G_CALLBACK (on_up_leave_notify_event),
-		    	GINT_TO_POINTER(BOOK_BUTTON));
+	g_signal_connect((gpointer)navbar.button_book_up,
+			 "enter_notify_event",
+			 G_CALLBACK(on_up_enter_notify_event),
+			 GINT_TO_POINTER(BOOK_BUTTON));
+	g_signal_connect((gpointer)navbar.button_book_up,
+			 "leave_notify_event",
+			 G_CALLBACK(on_up_leave_notify_event),
+			 GINT_TO_POINTER(BOOK_BUTTON));
 
-	g_signal_connect ((gpointer)navbar.button_book_down ,
-			"enter_notify_event",
-		    	G_CALLBACK (on_down_enter_notify_event),
-		    	GINT_TO_POINTER(BOOK_BUTTON));
-	g_signal_connect ((gpointer)navbar.button_book_down ,
-			"leave_notify_event",
-		    	G_CALLBACK (on_down_leave_notify_event),
-		    	GINT_TO_POINTER(BOOK_BUTTON));
+	g_signal_connect((gpointer)navbar.button_book_down,
+			 "enter_notify_event",
+			 G_CALLBACK(on_down_enter_notify_event),
+			 GINT_TO_POINTER(BOOK_BUTTON));
+	g_signal_connect((gpointer)navbar.button_book_down,
+			 "leave_notify_event",
+			 G_CALLBACK(on_down_leave_notify_event),
+			 GINT_TO_POINTER(BOOK_BUTTON));
 
 	/*    */
-	g_signal_connect ((gpointer) navbar.button_chapter_up, "enter_notify_event",
-		    G_CALLBACK (on_up_enter_notify_event),
-		    GINT_TO_POINTER(CHAPTER_BUTTON));
-	g_signal_connect ((gpointer)navbar.button_chapter_up , "leave_notify_event",
-		    G_CALLBACK (on_up_leave_notify_event),
-		    GINT_TO_POINTER(CHAPTER_BUTTON));
+	g_signal_connect((gpointer)navbar.button_chapter_up,
+			 "enter_notify_event",
+			 G_CALLBACK(on_up_enter_notify_event),
+			 GINT_TO_POINTER(CHAPTER_BUTTON));
+	g_signal_connect((gpointer)navbar.button_chapter_up,
+			 "leave_notify_event",
+			 G_CALLBACK(on_up_leave_notify_event),
+			 GINT_TO_POINTER(CHAPTER_BUTTON));
 
-	g_signal_connect ((gpointer) navbar.button_chapter_down, "enter_notify_event",
-		    G_CALLBACK (on_down_enter_notify_event),
-		    GINT_TO_POINTER(CHAPTER_BUTTON));
-	g_signal_connect ((gpointer)navbar.button_chapter_down , "leave_notify_event",
-		    G_CALLBACK (on_down_leave_notify_event),
-		    GINT_TO_POINTER(CHAPTER_BUTTON));
+	g_signal_connect((gpointer)navbar.button_chapter_down,
+			 "enter_notify_event",
+			 G_CALLBACK(on_down_enter_notify_event),
+			 GINT_TO_POINTER(CHAPTER_BUTTON));
+	g_signal_connect((gpointer)navbar.button_chapter_down,
+			 "leave_notify_event",
+			 G_CALLBACK(on_down_leave_notify_event),
+			 GINT_TO_POINTER(CHAPTER_BUTTON));
 
 	/*    */
-	g_signal_connect ((gpointer) navbar.button_verse_up, "enter_notify_event",
-		    G_CALLBACK (on_up_enter_notify_event),
-		    GINT_TO_POINTER(VERSE_BUTTON));
-	g_signal_connect ((gpointer)navbar.button_verse_up , "leave_notify_event",
-		    G_CALLBACK (on_up_leave_notify_event),
-		    GINT_TO_POINTER(VERSE_BUTTON));
+	g_signal_connect((gpointer)navbar.button_verse_up,
+			 "enter_notify_event",
+			 G_CALLBACK(on_up_enter_notify_event),
+			 GINT_TO_POINTER(VERSE_BUTTON));
+	g_signal_connect((gpointer)navbar.button_verse_up,
+			 "leave_notify_event",
+			 G_CALLBACK(on_up_leave_notify_event),
+			 GINT_TO_POINTER(VERSE_BUTTON));
 
-	g_signal_connect ((gpointer) navbar.button_verse_down, "enter_notify_event",
-		    G_CALLBACK (on_down_enter_notify_event),
-		    GINT_TO_POINTER(VERSE_BUTTON));
-	g_signal_connect ((gpointer)navbar.button_verse_down , "leave_notify_event",
-		    G_CALLBACK (on_down_leave_notify_event),
-		    GINT_TO_POINTER(VERSE_BUTTON));
+	g_signal_connect((gpointer)navbar.button_verse_down,
+			 "enter_notify_event",
+			 G_CALLBACK(on_down_enter_notify_event),
+			 GINT_TO_POINTER(VERSE_BUTTON));
+	g_signal_connect((gpointer)navbar.button_verse_down,
+			 "leave_notify_event",
+			 G_CALLBACK(on_down_leave_notify_event),
+			 GINT_TO_POINTER(VERSE_BUTTON));
 
-	g_signal_connect((gpointer) navbar.button_history_back,
-			 "clicked", G_CALLBACK(on_button_history_back_clicked),
-			 NULL);
-	g_signal_connect((gpointer) navbar.button_history_next,
-			 "clicked", G_CALLBACK(on_button_history_next_clicked),
-			 NULL);
-	g_signal_connect((gpointer) navbar.button_history_menu,
+	g_signal_connect((gpointer)navbar.button_history_back,
+			 "clicked",
+			 G_CALLBACK(on_button_history_back_clicked), NULL);
+	g_signal_connect((gpointer)navbar.button_history_next, "clicked",
+			 G_CALLBACK(on_button_history_next_clicked), NULL);
+	g_signal_connect((gpointer)navbar.button_history_menu,
 			 "button_press_event",
-			 G_CALLBACK(select_button_press_callback),
-			 NULL);
-	g_signal_connect((gpointer) navbar.button_book_menu,
+			 G_CALLBACK(select_button_press_callback), NULL);
+	g_signal_connect((gpointer)navbar.button_book_menu,
 			 "button_press_event",
 			 G_CALLBACK(select_book_button_press_callback),
 			 NULL);
-	g_signal_connect((gpointer) navbar.button_chapter_menu,
+	g_signal_connect((gpointer)navbar.button_chapter_menu,
 			 "button_press_event",
 			 G_CALLBACK(select_chapter_button_press_callback),
-			NULL );
-	g_signal_connect((gpointer) navbar.button_verse_menu,
+			 NULL);
+	g_signal_connect((gpointer)navbar.button_verse_menu,
 			 "button_press_event",
 			 G_CALLBACK(select_verse_button_press_callback),
-			NULL );
-#ifndef HAVE_GTK_34	
-	g_signal_connect ((gpointer)navbar.button_verse_menu , "scroll_event",
-		    	 G_CALLBACK (on_button_verse_menu_verse_scroll_event),
-		    	 NULL);
-	g_signal_connect ((gpointer)navbar.button_chapter_menu , "scroll_event",
-		    	 G_CALLBACK (on_button_verse_menu_chapter_scroll_event),
-		    	 NULL);
-	g_signal_connect ((gpointer)navbar.button_book_menu , "scroll_event",
-		    	 G_CALLBACK (on_button_verse_menu_book_scroll_event),
-		    	 NULL);
+			 NULL);
+#ifndef HAVE_GTK_34
+	g_signal_connect((gpointer)navbar.button_verse_menu,
+			 "scroll_event",
+			 G_CALLBACK(on_button_verse_menu_verse_scroll_event), NULL);
+	g_signal_connect((gpointer)navbar.button_chapter_menu,
+			 "scroll_event",
+			 G_CALLBACK(on_button_verse_menu_chapter_scroll_event),
+			 NULL);
+	g_signal_connect((gpointer)navbar.button_book_menu,
+			 "scroll_event",
+			 G_CALLBACK(on_button_verse_menu_book_scroll_event), NULL);
 #endif
 }
 
@@ -949,34 +930,40 @@ GtkWidget *gui_navbar_versekey_new(void)
 	GladeXML *gxml;
 #endif
 #ifdef HAVE_GTK_34
-	GtkWidget * eventbox;
+	GtkWidget *eventbox;
 #endif
-	
-	gchar *glade_file = gui_general_user_file("navbar_versekey" UI_SUFFIX, FALSE);
-	g_return_val_if_fail((glade_file != NULL), NULL);
-	XI_message(("%s",glade_file));
 
-	/* build the widget */
+	gchar *glade_file =
+	    gui_general_user_file("navbar_versekey" UI_SUFFIX, FALSE);
+	g_return_val_if_fail((glade_file != NULL), NULL);
+	XI_message(("%s", glade_file));
+
+/* build the widget */
 #ifdef USE_GTKBUILDER
-	gxml = gtk_builder_new ();
-	gtk_builder_add_from_file (gxml, glade_file, NULL);
+	gxml = gtk_builder_new();
+	gtk_builder_add_from_file(gxml, glade_file, NULL);
 #else
 	gxml = glade_xml_new(glade_file, "navbar", NULL);
 #endif
 	navbar_versekey.dialog = FALSE;
-	navbar_versekey.module_name = g_string_new(settings.MainWindowModule);
-	navbar_versekey.key =  g_string_new(settings.currentverse);
+	navbar_versekey.module_name =
+	    g_string_new(settings.MainWindowModule);
+	navbar_versekey.key = g_string_new(settings.currentverse);
 
 	navbar_versekey.navbar = UI_GET_ITEM(gxml, "navbar");
 
-	navbar_versekey.button_history_back = UI_GET_ITEM(gxml, "button_history_back");
-	navbar_versekey.button_history_next = UI_GET_ITEM(gxml, "button_history_foward");
-	navbar_versekey.button_history_menu = UI_GET_ITEM(gxml, "togglebutton_history_list");
+	navbar_versekey.button_history_back =
+	    UI_GET_ITEM(gxml, "button_history_back");
+	navbar_versekey.button_history_next =
+	    UI_GET_ITEM(gxml, "button_history_foward");
+	navbar_versekey.button_history_menu =
+	    UI_GET_ITEM(gxml, "togglebutton_history_list");
 
 	navbar_versekey.button_book_up = UI_GET_ITEM(gxml, "eventbox9");
 	navbar_versekey.button_book_down = UI_GET_ITEM(gxml, "eventbox6");
 	navbar_versekey.button_chapter_up = UI_GET_ITEM(gxml, "eventbox8");
-	navbar_versekey.button_chapter_down = UI_GET_ITEM(gxml, "eventbox4");
+	navbar_versekey.button_chapter_down =
+	    UI_GET_ITEM(gxml, "eventbox4");
 	navbar_versekey.button_verse_up = UI_GET_ITEM(gxml, "eventbox7");
 	navbar_versekey.button_verse_down = UI_GET_ITEM(gxml, "eventbox1");
 
@@ -986,36 +973,41 @@ GtkWidget *gui_navbar_versekey_new(void)
 	navbar_versekey.arrow_book_down = UI_GET_ITEM(gxml, "image14");
 	navbar_versekey.arrow_chapter_up_box = UI_GET_ITEM(gxml, "image9");
 	navbar_versekey.arrow_chapter_up = UI_GET_ITEM(gxml, "image8");
-	navbar_versekey.arrow_chapter_down_box = UI_GET_ITEM(gxml, "image11");
+	navbar_versekey.arrow_chapter_down_box =
+	    UI_GET_ITEM(gxml, "image11");
 	navbar_versekey.arrow_chapter_down = UI_GET_ITEM(gxml, "image10");
 	navbar_versekey.arrow_verse_up_box = UI_GET_ITEM(gxml, "image7");
 	navbar_versekey.arrow_verse_up = UI_GET_ITEM(gxml, "image6");
-	navbar_versekey.arrow_verse_down_box = UI_GET_ITEM(gxml, "image16");
+	navbar_versekey.arrow_verse_down_box =
+	    UI_GET_ITEM(gxml, "image16");
 	navbar_versekey.arrow_verse_down = UI_GET_ITEM(gxml, "image5");
 
-	navbar_versekey.button_book_menu = UI_GET_ITEM(gxml, "togglebutton_book");
-	navbar_versekey.button_chapter_menu = UI_GET_ITEM(gxml, "togglebutton_chapter");
-	navbar_versekey.button_verse_menu = UI_GET_ITEM(gxml, "togglebutton_verse");
+	navbar_versekey.button_book_menu =
+	    UI_GET_ITEM(gxml, "togglebutton_book");
+	navbar_versekey.button_chapter_menu =
+	    UI_GET_ITEM(gxml, "togglebutton_chapter");
+	navbar_versekey.button_verse_menu =
+	    UI_GET_ITEM(gxml, "togglebutton_verse");
 	navbar_versekey.lookup_entry = UI_GET_ITEM(gxml, "entry_lookup");
 	navbar_versekey.label_book_menu = UI_GET_ITEM(gxml, "label_book");
-	navbar_versekey.label_chapter_menu = UI_GET_ITEM(gxml, "label_chapter");
-	navbar_versekey.label_verse_menu = UI_GET_ITEM(gxml, "label_verse");
+	navbar_versekey.label_chapter_menu =
+	    UI_GET_ITEM(gxml, "label_chapter");
+	navbar_versekey.label_verse_menu =
+	    UI_GET_ITEM(gxml, "label_verse");
 #ifdef HAVE_GTK_34
 	eventbox = UI_GET_ITEM(gxml, "eventbox_book");
-	g_signal_connect ((gpointer) eventbox, "scroll_event",
-		    	 G_CALLBACK (on_button_verse_menu_book_scroll_event),
-		    	 NULL);
-	
+	g_signal_connect((gpointer)eventbox, "scroll_event",
+			 G_CALLBACK(on_button_verse_menu_book_scroll_event), NULL);
+
 	eventbox = UI_GET_ITEM(gxml, "eventbox_chapter");
-	g_signal_connect ((gpointer) eventbox, "scroll_event",
-		    	 G_CALLBACK (on_button_verse_menu_chapter_scroll_event),
-		    	 NULL);
-	
+	g_signal_connect((gpointer)eventbox, "scroll_event",
+			 G_CALLBACK(on_button_verse_menu_chapter_scroll_event),
+			 NULL);
+
 	eventbox = UI_GET_ITEM(gxml, "eventbox_verse");
-	g_signal_connect ((gpointer) eventbox, "scroll_event",
-		    	 G_CALLBACK (on_button_verse_menu_verse_scroll_event),
-		    	 NULL);
-#endif	
+	g_signal_connect((gpointer)eventbox, "scroll_event",
+			 G_CALLBACK(on_button_verse_menu_verse_scroll_event), NULL);
+#endif
 	_connect_signals(navbar_versekey);
 
 	return navbar_versekey.navbar;
