@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * parallel_dialog.c - dialog for detached parallel
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,12 +20,12 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <gtk/gtk.h>
 #ifndef USE_GTKBUILDER
-  #include <glade/glade-xml.h>
+#include <glade/glade-xml.h>
 #endif
 #include "xiphos_html/xiphos_html.h"
 
@@ -62,17 +62,14 @@ static GtkWidget *dialog_parallel;
 static GtkWidget *parallel_UnDock_Dialog;
 static GtkWidget *vboxInt;
 static gboolean ApplyChangeBook;
-static NAVBAR navbar;
+//static NAVBAR navbar;
 NAVBAR_VERSEKEY navbar_parallel;
 
 static GtkWidget *create_parallel_dialog(void);
 static void sync_with_main(void);
 
-
 static void
-_popupmenu_requested_cb(XiphosHtml *html,
-			gchar *uri,
-			gpointer user_data)
+_popupmenu_requested_cb(XiphosHtml *html, gchar *uri, gpointer user_data)
 {
 	gui_popup_menu_parallel();
 }
@@ -102,10 +99,9 @@ void gui_undock_parallel_page(void)
 	parallel_UnDock_Dialog = create_parallel_dialog();
 
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-                                             FALSE);
+				   FALSE);
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-					0);
-
+				      0);
 
 	gtk_widget_show(parallel_UnDock_Dialog);
 	//main_update_parallel_page_detached();
@@ -134,7 +130,7 @@ void gui_undock_parallel_page(void)
  *   void
  */
 
-void gui_btnDockInt_clicked(GtkButton * button, gpointer user_data)
+void gui_btnDockInt_clicked(GtkButton *button, gpointer user_data)
 {
 	gtk_widget_destroy(parallel_UnDock_Dialog);
 }
@@ -158,15 +154,14 @@ void gui_btnDockInt_clicked(GtkButton * button, gpointer user_data)
  *   void
  */
 
-static void on_dlgparallel_destroy(GObject * object,
-				      gpointer user_data)
+static void on_dlgparallel_destroy(GObject *object, gpointer user_data)
 {
 
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-                                             TRUE);
+				   TRUE);
 
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-					1);
+				      1);
 	settings.dockedInt = TRUE;
 	main_update_parallel_page();
 
@@ -174,7 +169,6 @@ static void on_dlgparallel_destroy(GObject * object,
 	xml_set_value("Xiphos", "layout", "parallelopen", "0");
 }
 
-
 /******************************************************************************
  * Name
  *   sync_with_main
@@ -195,19 +189,18 @@ static void sync_with_main(void)
 {
 	gchar *buf = NULL;
 
-	buf = (gchar*)main_url_encode (settings.currentverse);
+	buf = (gchar *)main_url_encode(settings.currentverse);
 
 	if (buf && (strlen(buf) > 3)) {
 		gchar *url =
-		    g_strdup_printf ("passagestudy.jsp?action=showParallel&"
-					"type=verse&value=%s",
-					buf);
-		main_url_handler (url, TRUE);
-		g_free (url);
+		    g_strdup_printf("passagestudy.jsp?action=showParallel&"
+				    "type=verse&value=%s",
+				    buf);
+		main_url_handler(url, TRUE);
+		g_free(url);
 	}
 }
 
-
 /******************************************************************************
  * Name
  *   gui_keep_parallel_dialog_in_sync
@@ -225,11 +218,12 @@ static void sync_with_main(void)
 
 void gui_keep_parallel_dialog_in_sync(void)
 {
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(navbar_parallel.button_sync)))
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(navbar_parallel.button_sync)))
 		sync_with_main();
 }
 
-
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 /******************************************************************************
  * Name
  *   gui_set_parallel_navbar
@@ -245,12 +239,11 @@ void gui_keep_parallel_dialog_in_sync(void)
  *   void
  */
 
-void gui_set_parallel_navbar(const char * key)
+void gui_set_parallel_navbar(const char *key)
 {
 	main_navbar_set(navbar, key);
 }
-
-
+#endif
 
 /******************************************************************************
  * Name
@@ -273,7 +266,6 @@ static GtkWidget *create_nav_toolbar(void)
 	return gui_navbar_versekey_parallel_new();
 }
 
-
 /******************************************************************************
  * Name
  *   on_parallel_configure_event
@@ -293,18 +285,17 @@ static GtkWidget *create_nav_toolbar(void)
  *   gboolean
  */
 
-static gboolean on_parallel_configure_event(GtkWidget * widget,
-					    GdkEventConfigure * event,
+static gboolean on_parallel_configure_event(GtkWidget *widget,
+					    GdkEventConfigure *event,
 					    gpointer user_data)
 {
 	gchar layout[10];
 	gint x;
 	gint y;
 
- 	gdk_window_get_root_origin(
-	    GDK_WINDOW(gtk_widget_get_window (dialog_parallel)), &x, &y);
+	gdk_window_get_root_origin(GDK_WINDOW(gtk_widget_get_window(dialog_parallel)), &x, &y);
 
-	settings.parallel_width  = event->width;
+	settings.parallel_width = event->width;
 	settings.parallel_height = event->height;
 	settings.parallel_x = x;
 	settings.parallel_y = y;
@@ -341,10 +332,9 @@ static gboolean on_parallel_configure_event(GtkWidget * widget,
  * Return value
  *   GtkWidget *
  */
-static
-GtkWidget *create_parallel_dialog(void)
+static GtkWidget *create_parallel_dialog(void)
 {
-  	GtkWidget *box_parallel_labels;
+	GtkWidget *box_parallel_labels;
 	GtkWidget *dialog_vbox25;
 	GtkWidget *toolbar29;
 	GtkWidget *dialog_action_area25;
@@ -353,7 +343,7 @@ GtkWidget *create_parallel_dialog(void)
 	GtkWidget *scrolled_window;
 	gchar title[256];
 
-	sprintf(title,"%s - %s", settings.program_title, _("Parallel"));
+	sprintf(title, "%s - %s", settings.program_title, _("Parallel"));
 
 	dialog_parallel = gtk_dialog_new();
 	gtk_window_set_title(GTK_WINDOW(dialog_parallel), title);
@@ -365,24 +355,25 @@ GtkWidget *create_parallel_dialog(void)
 			  settings.parallel_height);
 	gtk_window_set_resizable(GTK_WINDOW(dialog_parallel), TRUE);
 
-	dialog_vbox25 = gtk_dialog_get_content_area (GTK_DIALOG(dialog_parallel));
-	g_object_set_data(G_OBJECT(dialog_parallel),
-			  "dialog_vbox25", dialog_vbox25);
+	dialog_vbox25 =
+	    gtk_dialog_get_content_area(GTK_DIALOG(dialog_parallel));
+	g_object_set_data(G_OBJECT(dialog_parallel), "dialog_vbox25",
+			  dialog_vbox25);
 	gtk_widget_show(dialog_vbox25);
 
 	UI_VBOX(vboxInt, FALSE, 0);
 	gtk_widget_show(vboxInt);
-	gtk_box_pack_start(GTK_BOX(dialog_vbox25), vboxInt, TRUE, TRUE,
-			   0);
+	gtk_box_pack_start(GTK_BOX(dialog_vbox25), vboxInt, TRUE, TRUE, 0);
 	toolbar29 = create_nav_toolbar();
 	gtk_widget_show(toolbar29);
-	gtk_box_pack_start(GTK_BOX(vboxInt), toolbar29, FALSE, FALSE,
-			   0);
+	gtk_box_pack_start(GTK_BOX(vboxInt), toolbar29, FALSE, FALSE, 0);
 
 	UI_HBOX(box_parallel_labels, TRUE, 2);
-	gtk_widget_show (box_parallel_labels);
-	gtk_box_pack_start (GTK_BOX (vboxInt), box_parallel_labels, FALSE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (box_parallel_labels), 2);
+	gtk_widget_show(box_parallel_labels);
+	gtk_box_pack_start(GTK_BOX(vboxInt), box_parallel_labels, FALSE,
+			   TRUE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(box_parallel_labels),
+				       2);
 
 #if 0
 	if (settings.parallel_list) {
@@ -393,28 +384,34 @@ GtkWidget *create_parallel_dialog(void)
 		for (modidx = 0; settings.parallel_list[modidx]; ++modidx) {
 			plabel = gtk_label_new(NULL);
 			gtk_widget_show(plabel);
-			gtk_box_pack_start(GTK_BOX (box_parallel_labels), plabel, FALSE, FALSE, 0);
+			gtk_box_pack_start(GTK_BOX(box_parallel_labels),
+					   plabel, FALSE, FALSE, 0);
 			gtk_label_set_use_markup(GTK_LABEL(plabel), TRUE);
 
-			label = g_strdup_printf("<span color='%s' weight='bold'>%s</span>",
-						settings.bible_verse_num_color,
-						settings.parallel_list[modidx]);
+			label =
+			    g_strdup_printf
+			    ("<span color='%s' weight='bold'>%s</span>",
+			     settings.bible_verse_num_color,
+			     settings.parallel_list[modidx]);
 			gtk_label_set_markup(GTK_LABEL(plabel), label);
 			g_free(label);
 		}
 	}
 #endif /* 0 */
-    
+
 	scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolled_window);
-	gtk_box_pack_start(GTK_BOX(vboxInt), scrolled_window, TRUE, TRUE,0);
+	gtk_box_pack_start(GTK_BOX(vboxInt), scrolled_window, TRUE, TRUE,
+			   0);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_ALWAYS);
-	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)scrolled_window,
-                                             settings.shadow_type);
+	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
+					    scrolled_window,
+					    settings.shadow_type);
 
-	widgets.html_parallel_dialog = GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, PARALLEL_TYPE));
+	widgets.html_parallel_dialog =
+	    GTK_WIDGET(XIPHOS_HTML_NEW(NULL, FALSE, PARALLEL_TYPE));
 	gtk_widget_show(widgets.html_parallel_dialog);
 
 	gtk_container_add(GTK_CONTAINER(scrolled_window),
@@ -422,48 +419,53 @@ GtkWidget *create_parallel_dialog(void)
 
 	g_signal_connect((gpointer)widgets.html_parallel_dialog,
 			 "popupmenu_requested",
-			 G_CALLBACK (_popupmenu_requested_cb),
-			 NULL);
+			 G_CALLBACK(_popupmenu_requested_cb), NULL);
 
 	dialog_action_area25 =
-	    gtk_dialog_get_action_area (GTK_DIALOG(dialog_parallel));
+#ifdef HAVE_GTK_312
+	    gtk_dialog_get_content_area(GTK_DIALOG(dialog_parallel));
+#else
+	    gtk_dialog_get_action_area(GTK_DIALOG(dialog_parallel));
+#endif
 	g_object_set_data(G_OBJECT(dialog_parallel),
-			  "dialog_action_area25",
-			  dialog_action_area25);
+			  "dialog_action_area25", dialog_action_area25);
 	gtk_widget_show(dialog_action_area25);
-	gtk_container_set_border_width(GTK_CONTAINER
-				       (dialog_action_area25), 10);
+	gtk_container_set_border_width(GTK_CONTAINER(dialog_action_area25), 10);
 
 #ifdef USE_GTK_3
-	hbuttonbox4 = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
+	hbuttonbox4 = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 #else
 	hbuttonbox4 = gtk_hbutton_box_new();
 #endif
 	gtk_widget_show(hbuttonbox4);
+
+#ifdef HAVE_GTK_312
+	gtk_box_pack_start(GTK_BOX(dialog_action_area25), hbuttonbox4,
+			   FALSE, TRUE, 3);
+#else
 	gtk_box_pack_start(GTK_BOX(dialog_action_area25), hbuttonbox4,
 			   TRUE, TRUE, 0);
+#endif
+
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox4),
 				  GTK_BUTTONBOX_END);
-	btnDockInt =    
+	btnDockInt =
 #ifdef HAVE_GTK_310
-		gtk_button_new_from_icon_name ("window-close",
-                               GTK_ICON_SIZE_BUTTON);
-#else	
-		gtk_button_new_from_stock (GTK_STOCK_CLOSE);
-#endif	
+	    gtk_button_new_from_icon_name("window-close",
+					  GTK_ICON_SIZE_BUTTON);
+#else
+	    gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+#endif
 	gtk_widget_show(btnDockInt);
 	gtk_container_add(GTK_CONTAINER(hbuttonbox4), btnDockInt);
-	gtk_widget_set_can_default (btnDockInt, 1);
-
+	gtk_widget_set_can_default(btnDockInt, 1);
 
 	g_signal_connect(G_OBJECT(dialog_parallel), "destroy",
-			   G_CALLBACK(on_dlgparallel_destroy),
-			   NULL);
+			 G_CALLBACK(on_dlgparallel_destroy), NULL);
 	g_signal_connect(G_OBJECT(btnDockInt), "clicked",
-			   G_CALLBACK(gui_btnDockInt_clicked),
-			   NULL);
+			 G_CALLBACK(gui_btnDockInt_clicked), NULL);
 
-	g_signal_connect((gpointer) dialog_parallel, 
+	g_signal_connect((gpointer)dialog_parallel,
 			 "configure_event",
 			 G_CALLBACK(on_parallel_configure_event), NULL);
 
@@ -484,7 +486,8 @@ GtkWidget *create_parallel_dialog(void)
 	if ((settings.parallel_y < 0) || (settings.parallel_y > 2000))
 		settings.parallel_y = 40;
 
- 	gtk_window_move(GTK_WINDOW(dialog_parallel),settings.parallel_x,settings.parallel_y);
+	gtk_window_move(GTK_WINDOW(dialog_parallel), settings.parallel_x,
+			settings.parallel_y);
 
 	return dialog_parallel;
 }
