@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * xiphos.c -
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -88,7 +88,6 @@
  *   void
  */
 
-
 void frontend_init(void)
 {
 	XI_print(("%s\n", "Initiating Xiphos"));
@@ -105,9 +104,9 @@ void frontend_init(void)
 	 */
 	if (settings.havebible) {
 		main_check_parallel_modules();
-		main_init_parallel_view();	
+		main_init_parallel_view();
 		gui_create_parallel_page();
-		gtk_widget_realize(widgets.html_parallel);	
+		gtk_widget_realize(widgets.html_parallel);
 		main_set_parallel_options_at_start();
 	}
 
@@ -135,7 +134,6 @@ void frontend_init(void)
 	main_init_previewer();
 }
 
-
 /******************************************************************************
  * Name
  *
@@ -152,27 +150,22 @@ void frontend_init(void)
  *   void
  */
 
-
 void frontend_display(const char *tabs)
 {
-	GdkScreen *screen  = gdk_screen_get_default();
-	gint screen_width  = gdk_screen_get_width(screen);
+	GdkScreen *screen = gdk_screen_get_default();
+	gint screen_width = gdk_screen_get_width(screen);
 	gint screen_height = gdk_screen_get_height(screen);
 
 	XI_print(("%s\n", "Displaying Xiphos"));
 	gui_show_main_window();
 
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
-				       (widgets.viewtexts_item),
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widgets.viewtexts_item),
 				       settings.showtexts);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
-				       (widgets.viewcomms_item),
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widgets.viewcomms_item),
 				       settings.showcomms);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
-				       (widgets.viewdicts_item),
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widgets.viewdicts_item),
 				       settings.showdicts);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
-				       (widgets.viewpreview_item),
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widgets.viewpreview_item),
 				       settings.showpreview);
 	gui_show_hide_preview(settings.showpreview);
 	gui_show_hide_texts(settings.showtexts);
@@ -186,23 +179,26 @@ void frontend_display(const char *tabs)
 	 * especially if it's due to just shutting linux down.
 	 */
 	if (settings.app_x < 0)
-		settings.app_x = 10;
+		settings.app_x = 0;
 	if (settings.app_x > (screen_width - 100))
 		settings.app_x = screen_width - 100;
 	if (settings.app_y < 0)
-		settings.app_y = 10;
+		settings.app_y = 0;
 	if (settings.app_y > (screen_height - 100))
 		settings.app_y = screen_height - 100;
+	if (settings.maximized)
+		gtk_window_maximize(GTK_WINDOW(widgets.app));
 
- 	gtk_window_move(GTK_WINDOW(widgets.app),settings.app_x,settings.app_y);
+	gtk_window_move(GTK_WINDOW(widgets.app), settings.app_x,
+			settings.app_y);
 
 	/* gecko  needs the widgets to be visible before writing */
 	sync_windows();
 
 	// setup passage notebook
-//	if (settings.browsing) {
-	gui_notebook_main_setup (settings.browsing, tabs);
-/*	} else {
+	//      if (settings.browsing) {
+	gui_notebook_main_setup(settings.browsing, tabs);
+	/*	} else {
 		url = g_strdup_printf("sword://%s/%s",settings.DictWindowModule,
 						      settings.dictkey);
 		main_url_handler(url);
@@ -222,13 +218,11 @@ void frontend_display(const char *tabs)
 	} */
 	/* must be set after tab stuff is done */
 
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
-				       (widgets.parallel_tab_item),
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widgets.parallel_tab_item),
 				       settings.showparatab);
 	g_signal_connect(G_OBJECT(widgets.parallel_tab_item),
-			   "toggled",
-			   G_CALLBACK(gui_parallel_tab_activate),
-			   NULL	);
+			 "toggled",
+			 G_CALLBACK(gui_parallel_tab_activate), NULL);
 	gui_show_previewer_in_sidebar(settings.show_previewer_in_sidebar);
 
 	/* open saved windows as needed */
@@ -245,12 +239,11 @@ void frontend_display(const char *tabs)
 		main_display_devotional();
 	else
 		main_init_previewer();
-	gtk_widget_grab_focus (sidebar.module_list);
+	gtk_widget_grab_focus(sidebar.module_list);
 
 	XI_print(("%s\n\n", "done"));
 }
 
-
 /******************************************************************************
  * Name
  *  shutdown_xiphos
@@ -269,19 +262,18 @@ void frontend_display(const char *tabs)
 
 void shutdown_frontend(void)
 {
-	RESULTS *list_item;
-	if(pixbufs->pixbuf_closed)
+	if (pixbufs->pixbuf_closed)
 		g_object_unref(pixbufs->pixbuf_closed);
-	if(pixbufs->pixbuf_opened)
+	if (pixbufs->pixbuf_opened)
 		g_object_unref(pixbufs->pixbuf_opened);
-	if(pixbufs->pixbuf_helpdoc)
+	if (pixbufs->pixbuf_helpdoc)
 		g_object_unref(pixbufs->pixbuf_helpdoc);
 
 	/* free verse list used for saving search results */
 	if (list_of_verses) {
 		GList *chaser = list_of_verses;
 		while (chaser) {
-			list_item = (RESULTS*)chaser->data;
+			RESULTS *list_item = (RESULTS *)chaser->data;
 			g_free(list_item->module);
 			g_free(list_item->key);
 			g_free(list_item);
@@ -295,7 +287,6 @@ void shutdown_frontend(void)
 
 	/* if study pad file has changed since last save */
 
-
 	xml_save_settings_doc(settings.fnconfigure);
 	xml_free_settings_doc();
 
@@ -303,7 +294,7 @@ void shutdown_frontend(void)
 
 	XIPHOS_HTML_SHUTDOWN();
 
-	gui_notebook_main_shutdown (settings.browsing);
+	gui_notebook_main_shutdown(settings.browsing);
 
 	/* free dir and file stuff */
 	g_free(settings.gSwordDir);
@@ -314,8 +305,8 @@ void shutdown_frontend(void)
 	main_delete_sidebar_search_backend();
 	main_delete_parallel_view();
 
-	g_string_free(navbar_versekey.module_name,TRUE);
-	g_string_free(navbar_versekey.key,TRUE);
+	g_string_free(navbar_versekey.module_name, TRUE);
+	g_string_free(navbar_versekey.key, TRUE);
 
 	XI_print(("\n%s\n", "Xiphos is shutdown"));
 }
