@@ -1,8 +1,8 @@
 /*
  * Xiphos Bible Study Tool
- * about_modules.h - About dialogs for Xiphos
+ * about_modules.h - About dialogs for modules
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,17 +28,15 @@ extern "C" {
 
 #include <gtk/gtk.h>
 
-void gui_display_about_module_dialog(gchar * modname);
+void gui_display_about_module_dialog(gchar *modname);
 void gui_core_display_about_dialog(const gchar *desc,
-				   gchar *abouttext,
-				   const gchar *version,
-				   gchar *modname);
-void about_module_display(GString * str,
-			  gchar * text,
-			  gboolean tooltip);
+				   const gchar *abouttext,
+				   const gchar *modname);
+void about_module_display(GString *str,
+			  const gchar *text,
+			  const gboolean tooltip);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
