@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * bibletext_dialog.h - view Bible text module in a dialog
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,19 +22,18 @@
 #ifndef __BIBLETEXT_DIALOG_H__
 #define __BIBLETEXT_DIALOG_H__
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 #include "main/module_dialogs.h"
 
-void gui_bible_dialog_sync_toggled(GtkToggleButton * button, DIALOG_DATA * c);
-void gui_create_bibletext_dialog(DIALOG_DATA * vt);
-void gui_text_dialog_create_menu(DIALOG_DATA * d);
+void gui_bible_dialog_sync_toggled(GtkToggleButton *button,
+				   DIALOG_DATA *c);
+void gui_create_bibletext_dialog(DIALOG_DATA *vt);
+void gui_text_dialog_create_menu(DIALOG_DATA *d);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
