@@ -1,8 +1,8 @@
 /*
  * Xiphos Bible Study Tool
- * bookmarks_treeview.h - gui for bookmarks
+ * bookmarks_treeview.h - gui for bookmarks in treeview
  *
- * Copyright (C) 2003-2014 Xiphos Developer Team
+ * Copyright (C) 2003-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,14 +38,15 @@ enum {
 	N_COLUMNS
 };
 
-
-typedef struct {
+typedef struct
+{
 	GdkPixbuf *pixbuf_opened;
 	GdkPixbuf *pixbuf_closed;
 	GdkPixbuf *pixbuf_helpdoc;
 } BookMarksPixbufs;
 
-struct _bookmark_data {
+struct _bookmark_data
+{
 	xmlNodePtr parent;
 	gchar *caption;
 	gchar *key;
@@ -61,19 +62,20 @@ typedef struct _bookmark_data BOOKMARK_DATA;
 extern BookMarksPixbufs *bm_pixbufs;
 extern GtkTreeView *bookmark_tree;
 
-void gui_load_removed(const xmlChar * file);
-void gui_add_columns(GtkTreeView * tree);
-void gui_add_item_to_tree(GtkTreeIter * iter, GtkTreeIter * parent,
-			     BOOKMARK_DATA * data);
-void gui_verselist_to_bookmarks(GList * verses, gint save_as_single);
+void gui_load_removed(const xmlChar *file);
+void gui_add_columns(GtkTreeView *tree);
+void gui_add_item_to_tree(GtkTreeIter *iter, GtkTreeIter *parent,
+			  BOOKMARK_DATA *data);
+void gui_verselist_to_bookmarks(GList *verses,
+				gint save_as_single);
 GtkWidget *gui_create_bookmark_tree(void);
-void gui_parse_bookmarks(GtkTreeView *tree, const xmlChar * file,
-			    GtkTreeIter *parent);
-GtkWidget* gui_create_dialog_add_bookmark(gchar * label,
-				gchar * module_name, gchar * key);
+void gui_parse_bookmarks(GtkTreeView *tree, const xmlChar *file,
+			 GtkTreeIter *parent);
+GtkWidget *gui_create_dialog_add_bookmark(gchar *label,
+					  gchar *module_name,
+					  gchar *key);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
