@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * cipher_key_dialog.h  - asks for key to unlock sword module
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,10 +26,10 @@
 extern "C" {
 #endif
 
-gchar * gui_add_cipher_key(const char *mod_name, gchar *cipher_old);
+gchar *gui_add_cipher_key(const char *mod_name,
+			  gchar *cipher_old);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
