@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * commentary_dialog.h - dialog for a commentary module
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,13 +28,15 @@ extern "C" {
 
 #include "main/module_dialogs.h"
 
-void gui_commentary_dialog_sync_toggled(GtkToggleButton * button, DIALOG_DATA * c);
-void gui_create_commentary_dialog(DIALOG_DATA * d, gboolean do_edit);
-void gui_display_commentary_with_struct(DIALOG_DATA *d, gchar *key);
-void gui_close_comm_dialog(DIALOG_DATA * d);
+void gui_commentary_dialog_sync_toggled(GtkToggleButton *button,
+					DIALOG_DATA *c);
+void gui_create_commentary_dialog(DIALOG_DATA *d,
+				  gboolean do_edit);
+void gui_display_commentary_with_struct(DIALOG_DATA *d,
+					gchar *key);
+void gui_close_comm_dialog(DIALOG_DATA *d);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
