@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * display_info.h - display information (ie strongs) in a dialog
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,12 +28,12 @@ extern "C" {
 
 extern GtkWidget *dialog_display_info;
 
-void gui_display_text_information(gchar * information);
-void gui_display_mod_and_key(const gchar * mod_name, const gchar * key);
+void gui_display_text_information(gchar *information);
+void gui_display_mod_and_key(const gchar *mod_name,
+			     const gchar *key);
 GtkWidget *gui_create_display_informtion_dialog(void);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
