@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * export_dialog.h -
  *
- * Copyright (C) 2007-2014 Xiphos Developer Team
+ * Copyright (C) 2007-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,11 +29,12 @@ extern "C" {
 gchar *gui_get_export_filename(void);
 void gui_export_dialog(void);
 void _get_export_filename(void);
-void on_dialog_export_passage_response(GtkDialog * dialog, gint response_id, gpointer user_data);
-gint _check_for_distribution_license(gchar * mod_name);
+void on_dialog_export_passage_response(GtkDialog *dialog,
+				       gint response_id,
+				       gpointer user_data);
+gint _check_for_distribution_license(gchar *mod_name);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _EXPORT_DIALOG_H_ */
