@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * parallel_dialog.h - dialog for detached parallel
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,13 +27,13 @@ extern "C" {
 #endif
 
 void gui_undock_parallel_page(void);
-void gui_btnDockInt_clicked(GtkButton *button, gpointer user_data);
+void gui_btnDockInt_clicked(GtkButton *button,
+			    gpointer user_data);
 GtkWidget *gui_create_parallel_dialog(void);
-void gui_set_parallel_navbar(const char * key);
+void gui_set_parallel_navbar(const char *key);
 void gui_keep_parallel_dialog_in_sync(void);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
