@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * parallel_tab.h - view parallel passages in a tab
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,17 +26,16 @@
 extern "C" {
 #endif
 
-
-void gui_parallel_tab_sync(const gchar * key);
+void gui_parallel_tab_sync(const gchar *key);
 GtkWidget *gui_create_parallel_tab(void);
 void gui_keep_parallel_tab_in_sync(void);
 void gui_force_parallel_tab_sync(void);
 void gui_destroy_parallel_tab(void);
-void gui_parallel_close_tab(GtkButton * button, gpointer user_data);
+void gui_parallel_close_tab(GtkButton *button,
+			    gpointer user_data);
 GtkWidget *_create_parallel_tab(void);
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif   /*  __parallel_TAB_H__  */
+#endif /*  __parallel_TAB_H__  */
