@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_sidebar.h - sidebar search gui
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,23 +27,24 @@ extern "C" {
 #endif
 
 typedef struct _sidebar_search SIDESEARCH;
-struct _sidebar_search {
+struct _sidebar_search
+{
 	GtkWidget *rrbUseBounds;
- 	GtkWidget *entrySearch;
+	GtkWidget *entrySearch;
 	GtkWidget *advanced_search;
- 	GtkWidget *entryLower;
- 	GtkWidget *entryUpper;
+	GtkWidget *entryLower;
+	GtkWidget *entryUpper;
 	GtkWidget *rbMultiword;
- 	GtkWidget *rbRegExp;
+	GtkWidget *rbRegExp;
 	GtkWidget *rbNoScope;
- 	GtkWidget *rbLastSearch;
- 	GtkWidget *rbPhraseSearch;
- 	GtkWidget *ckbCaseSensitive;
- 	GtkWidget *progressbar_search;
- 	GtkWidget *frame5;
- 	GtkWidget *frame_module;
- 	GtkWidget *radiobutton_search_text;
- 	GtkWidget *radiobutton_search_comm;
+	GtkWidget *rbLastSearch;
+	GtkWidget *rbPhraseSearch;
+	GtkWidget *ckbCaseSensitive;
+	GtkWidget *progressbar_search;
+	GtkWidget *frame5;
+	GtkWidget *frame_module;
+	GtkWidget *radiobutton_search_text;
+	GtkWidget *radiobutton_search_comm;
 };
 extern SIDESEARCH ss;
 
@@ -53,5 +54,4 @@ void gui_create_search_sidebar(void);
 #ifdef __cplusplus
 }
 #endif
-
 #endif
