@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * tabbed_browser.h - functions to facilitate tabbed browsing of different passages at once
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,14 +22,14 @@
 #ifndef __TABBED_BROWSER_H__
 #define __TABBED_BROWSER_H__
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
 #include <gtk/gtk.h>
 #include "main/tab_history.h"
 
-struct _passage_tab_info {
+struct _passage_tab_info
+{
 	GtkWidget *page_widget;
 	GtkLabel *tab_label;
 	GtkWidget *button_close;
@@ -65,22 +65,23 @@ void gui_save_tabs(const gchar *filename);
 void gui_load_tabs(const gchar *filename);
 void gui_select_nth_tab(gint page_num);
 void gui_set_tab_label(const gchar *key, gboolean one_tab);
-void gui_set_named_tab_label(const gchar *key, PASSAGE_TAB_INFO *pt, gboolean update);
+void gui_set_named_tab_label(const gchar *key,
+			     PASSAGE_TAB_INFO *pt,
+			     gboolean update);
 void gui_open_module_in_new_tab(gchar *module);
 void gui_open_passage_in_new_tab(gchar *key);
 void gui_open_parallel_view_in_new_tab(void);
 void gui_close_passage_tab(gint pagenum);
-void gui_update_tab_struct(const gchar * text_mod,
-			   const gchar * commentary_mod,
-			   const gchar * dictlex_mod,
-			   const gchar * book_mod,
-			   const gchar * dictlex_key,
-			   const gchar * book_offset,
+void gui_update_tab_struct(const gchar *text_mod,
+			   const gchar *commentary_mod,
+			   const gchar *dictlex_mod,
+			   const gchar *book_mod,
+			   const gchar *dictlex_key,
+			   const gchar *book_offset,
 			   gboolean comm_showing,
 			   gboolean showtexts,
 			   gboolean showpreview,
-			   gboolean showcomms,
-			   gboolean showdicts);
+			   gboolean showcomms, gboolean showdicts);
 void gui_close_all_tabs(void);
 void gui_open_tabs(void);
 
@@ -93,7 +94,8 @@ void gui_tab_set_showcomms(int show);
 void gui_tab_set_showdicts(int show);
 void gui_tabs_on_off(int on);
 
-void on_notebook_main_new_tab_clicked(GtkButton *button, gpointer user_data);
+void on_notebook_main_new_tab_clicked(GtkButton *button,
+				      gpointer user_data);
 
 extern gboolean change_tabs_no_redisplay;
 
@@ -102,16 +104,16 @@ void gui_recompute_view_menu_choices(void);
 void setup_book_editor_tab(PASSAGE_TAB_INFO *pt);
 GString *pick_tab_label(PASSAGE_TAB_INFO *pt);
 #ifdef USE_GTK_3
-void gui_notebook_main_switch_page(GtkNotebook * notebook, 
-                                   gpointer arg1, gint page_num, GList **tl);
+void gui_notebook_main_switch_page(GtkNotebook *notebook,
+				   gpointer arg1, gint page_num,
+				   GList **tl);
 #else
-void gui_notebook_main_switch_page(GtkNotebook * notebook,
-				   GtkNotebookPage * page,
+void gui_notebook_main_switch_page(GtkNotebook *notebook,
+				   GtkNotebookPage *page,
 				   gint page_num, GList **tl);
 #endif
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
