@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * treekey-editor.h -
  *
- * Copyright (C) 2007-2014 Xiphos Developer Team
+ * Copyright (C) 2007-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,15 +23,13 @@
 #define _TREEKEY_EDITOR_H
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
-GtkWidget *gui_create_editor_tree(EDITOR * editor);
-GtkWidget *create_edit_tree_menu (EDITOR * editor);
+GtkWidget *gui_create_editor_tree(EDITOR *editor);
+GtkWidget *create_edit_tree_menu(EDITOR *editor);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _TREEKEY_EDITOR_H */
