@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * biblesync_glue.h
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,21 +36,23 @@ using namespace std;
 
 extern "C" {
 
-typedef struct _speaker {
-    string uuid;
-    string user;
-    string ipaddr;
-    string app;
-    string device;
-    string ref;
-    string direct;
-    bool   listen;
+typedef struct _speaker
+{
+	string uuid;
+	string user;
+	string ipaddr;
+	string app;
+	string device;
+	string ref;
+	string direct;
+	bool listen;
 } BSP_Speaker;
 
-typedef std::map < string, BSP_Speaker > BSP_SpeakerMap;
+typedef std::map<string, BSP_Speaker> BSP_SpeakerMap;
 typedef BSP_SpeakerMap::iterator BSP_SpeakerMapIterator;
 
-int biblesync_compare_speaker(const void *Lvoid, const void *Rvoid);
+int biblesync_compare_speaker(const void *Lvoid,
+			      const void *Rvoid);
 
 #endif // __cplusplus
 
@@ -66,11 +68,11 @@ int biblesync_active_xmit_allowed();
 const char *biblesync_get_passphrase();
 void biblesync_transmit_verse_list(char *modname, char *vlist);
 void biblesync_privacy(gboolean privacy);
-void biblesync_prep_and_xmit(const char *mod_name, const char *key);
+void biblesync_prep_and_xmit(const char *mod_name,
+			     const char *key);
 void biblesync_set_clear_all_listen(gboolean listen);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _BIBLESYNC_GLUE_H__ */
