@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * configs.h -
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,8 @@ extern "C" {
 #endif
 
 typedef struct _mod_font MOD_FONT;
-struct  _mod_font {
+struct _mod_font
+{
 	const char *mod_name;
 	char *old_font;
 	const char *new_font;
@@ -37,11 +38,11 @@ struct  _mod_font {
 	int no_font;
 };
 
-char *get_conf_file_item(const char * file, const char * mod_name, const char * item);
-void save_conf_file_item(const char * file, const char * mod_name, const char * item,
-			const char * value);
+char *get_conf_file_item(const char *file, const char *mod_name,
+			 const char *item);
+void save_conf_file_item(const char *file, const char *mod_name,
+			 const char *item, const char *value);
 #ifdef __cplusplus
 }
 #endif
-
 #endif
