@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * export_passage.h -
  *
- * Copyright (C) 2007-2014 Xiphos Developer Team
+ * Copyright (C) 2007-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,13 +22,13 @@
 #ifndef ___EXPORT_PASSAGE_H_
 #define ___EXPORT_PASSAGE_H_
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 typedef struct _export_data EXPORT_DATA;
-struct _export_data {
+struct _export_data
+{
 	char *filename;
 	char *bookheader;
 	char *chapterheader_book;
@@ -37,7 +37,7 @@ struct _export_data {
 	char *verselayout_single_verse_ref_last;
 	char *verselayout_single_verse_ref_first;
 	char *verse_range_ref_last;
-	char *verse_range_ref_first;	
+	char *verse_range_ref_first;
 	char *plain_bookheader;
 	char *plain_chapterheader_book;
 	char *plain_chapterheader_chapter;
@@ -46,7 +46,7 @@ struct _export_data {
 	char *plain_verselayout_single_verse_ref_first;
 	char *plain_verse_range_ref_last;
 	char *plain_verse_range_ref_first;
-	char *verse_range_verse;	
+	char *verse_range_verse;
 	int passage_type;
 	int start_verse;
 	int end_verse;
@@ -71,5 +71,4 @@ void main_export_content(EXPORT_DATA data, gint format);
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* ___EXPORT_PASSAGE_H_ */
