@@ -1,8 +1,8 @@
 /*
  * Xiphos Bible Study Tool
- * mod_mgr.c
+ * mod_mgr.cc
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,19 +29,19 @@
 #include <swlocale.h>
 #include "main/mod_mgr.h"
 #include "main/sword.h"
+#include "main/parallel_view.h"
 
 #include "gui/mod_mgr.h"
 
 #include "backend/module_manager.hh"
 #include "backend/sword_main.hh"
 
-
-int main_module_mgr_index_mod(char * module_name)
+int main_module_mgr_index_mod(char *module_name)
 {
 	return backend->do_module_index(module_name);
 }
 
-int main_module_mgr_delete_index_mod(char * module_name)
+int main_module_mgr_delete_index_mod(char *module_name)
 {
 	return backend->do_module_delete_index(module_name);
 }
@@ -69,8 +69,11 @@ void main_update_module_lists(void)
 	backend = new BackEnd();
 	backend->init_SWORD(0);
 	main_init_lists();
-}
 
+	// parallel backend needs to know, too.
+	main_delete_parallel_view();
+	main_init_parallel_view();
+}
 
 /******************************************************************************
  * Name
@@ -95,7 +98,6 @@ void update_install_status(long total,
 	gui_update_install_status(total, done, message);
 }
 
-
 /******************************************************************************
  * Name
  *   update_install_progress
@@ -117,19 +119,17 @@ void update_install_progress(double fraction)
 	gui_update_install_progressbar(fraction);
 }
 
-
 void main_index_percent_update(char percent,
 			       void *userData)
 {
-	char maxHashes = *((char *) userData);
-	float num;
+	char maxHashes = *((char *)userData);
 	char buf[80];
 	static char printed = 0;
 
 	/* update search dialog progress */
-	while ((((float) percent) / 100) * maxHashes > printed) {
-		sprintf(buf, "%f", (((float) percent) / 100));
-		num = (float) percent / 100;
+	while ((((float)percent) / 100) * maxHashes > printed) {
+		sprintf(buf, "%f", (((float)percent) / 100));
+		float num = (float)percent / 100;
 		gui_update_install_progressbar((gdouble)num);
 		printed++;
 	}
@@ -157,7 +157,6 @@ GList *mod_mgr_list_remote_sources(void)
 	return backend_module_mgr_list_remote_sources();
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_list_local_sources
@@ -179,7 +178,6 @@ GList *mod_mgr_list_local_sources(void)
 	return backend_module_mgr_list_local_sources();
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_uninstall
@@ -201,7 +199,6 @@ int mod_mgr_uninstall(const char *dir, const char *mod_name)
 	return backend_uninstall_module(dir, mod_name);
 }
 
-
 /******************************************************************************
  * Name
  *  mod_mgr_remote_install
@@ -225,7 +222,6 @@ int mod_mgr_remote_install(const char *dir,
 	return backend_remote_install_module(dir, source_name, mod_name);
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_local_install_module
@@ -249,7 +245,6 @@ int mod_mgr_local_install_module(const char *destdir,
 	return backend_local_install_module(destdir, srcdir, mod_name);
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_list_local_modules
@@ -276,12 +271,11 @@ GList *mod_mgr_list_local_modules(const char *dir,
 
 	backend_module_mgr_list_local_modules_init(!augment);
 	while ((mod_info = backend_module_mgr_get_next_module()) != NULL) {
-		list = g_list_append(list, (MOD_MGR*) mod_info);
+		list = g_list_append(list, (MOD_MGR *)mod_info);
 	}
 	return list;
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_remote_list_modules
@@ -305,12 +299,11 @@ GList *mod_mgr_remote_list_modules(const char *source_name)
 
 	backend_module_mgr_remote_list_modules_init(source_name);
 	while ((mod_info = backend_module_mgr_get_next_module()) != NULL) {
-		list = g_list_append(list, (MOD_MGR*) mod_info);
+		list = g_list_append(list, (MOD_MGR *)mod_info);
 	}
 	return list;
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_refresh_remote_source
@@ -332,7 +325,6 @@ int mod_mgr_refresh_remote_source(const char *source_name)
 	return backend_module_mgr_refresh_remote_source(source_name);
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_init_config
@@ -369,14 +361,14 @@ void mod_mgr_reread_config(void)
 	backend_module_mgr_reread_config();
 }
 
-void mod_mgr_add_source(const char * vtype,
-			const char * type,
-			const char * caption,
-			const char * source,
-			const char * directory,
-			const char * user,
-			const char * pass,
-			const char * uid)
+void mod_mgr_add_source(const char *vtype,
+			const char *type,
+			const char *caption,
+			const char *source,
+			const char *directory,
+			const char *user,
+			const char *pass,
+			const char *uid)
 {
 	backend_module_mgr_add_source(vtype,
 				      type,
@@ -388,7 +380,6 @@ void mod_mgr_add_source(const char * vtype,
 				      uid);
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_init
@@ -433,7 +424,6 @@ void mod_mgr_terminate(void)
 	backend_terminate_module_mgr();
 }
 
-
 /******************************************************************************
  * Name
  *   mod_mgr_shut_down
