@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * mod_mgr.h
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,8 +33,10 @@ extern "C" {
 #include <glib.h>
 
 typedef struct _mm MOD_MGR;
-struct  _mm {
+struct _mm
+{
 	char *name;
+	char *abbreviation;
 	char *type;
 	const char *language;
 	char *old_version;
@@ -52,7 +54,8 @@ struct  _mm {
 };
 
 typedef struct _mms MOD_MGR_SOURCE;
-struct  _mms {
+struct _mms
+{
 	const char *caption;
 	const char *type;
 	const char *source;
@@ -61,22 +64,19 @@ struct  _mms {
 	const char *pass;
 	const char *uid;
 };
-int main_module_mgr_index_mod(char * module_name);
-int main_module_mgr_delete_index_mod(char * module_name);
-void main_index_percent_update(char percent,
-			       void *userData);
+int main_module_mgr_index_mod(char *module_name);
+int main_module_mgr_delete_index_mod(char *module_name);
+void main_index_percent_update(char percent, void *userData);
 void main_update_module_lists(void);
 MOD_MGR *mod_mgr_get_next_module(void);
 void update_install_status(long total,
-			   long done,
-			   const char *message);
+			   long done, const char *message);
 void update_install_progress(double fraction);
 GList *mod_mgr_list_local_modules(const char *dir,
 				  gboolean augment);
 GList *mod_mgr_list_remote_sources(void);
 GList *mod_mgr_list_local_sources(void);
-int mod_mgr_uninstall(const char *dir,
-		      const char *mod_name);
+int mod_mgr_uninstall(const char *dir, const char *mod_name);
 int mod_mgr_remote_install(const char *dir,
 			   const char *source_name,
 			   const char *mod_name);
@@ -89,22 +89,19 @@ void mod_mgr_init_config(void);
 int mod_mgr_init_config_extras(void);
 void mod_mgr_clear_config(void);
 void mod_mgr_reread_config(void);
-void mod_mgr_add_source(const char * vtype,
-			const char * type,
-			const char * caption,
-			const char * source,
-			const char * directory,
-			const char * user,
-			const char * pass,
-			const char * uid);
+void mod_mgr_add_source(const char *vtype,
+			const char *type,
+			const char *caption,
+			const char *source,
+			const char *directory,
+			const char *user,
+			const char *pass, const char *uid);
 void mod_mgr_init(const char *dir,
-		  gboolean augment,
-		  gboolean regular);
+		  gboolean augment, gboolean regular);
 void mod_mgr_shut_down(void);
 void mod_mgr_terminate(void);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif
