@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar.cc - glue between all navbars and sword
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,21 +20,19 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 #include <gtk/gtk.h>
 #include <swmgr.h>
 #include <swmodule.h>
 #include <versekey.h>
 
-
 #include "main/module_dialogs.h"
 #include "main/navbar.h"
 #include "main/settings.h"
 #include "main/sword.h"
 #include "main/url.hh"
 
-
 //#include "gui/toolbar_nav.h"
 #include "gui/commentary_dialog.h"
 #include "gui/bibletext_dialog.h"
@@ -48,31 +46,29 @@
 gboolean do_display;
 gboolean do_display_dict;
 
-
-void main_navbar_set(NAVBAR navbar, const char * key)
+void main_navbar_set(NAVBAR navbar, const char *key)
 {
 	char *gkey = NULL;
 	int book;
 	GtkTreeIter iter;
-	gint i,x;
+	gint i, x;
 
 	if (!navbar.module_name)
 		return;
 
 	SWModule *mod = backend->get_SWModule(navbar.module_name);
-	if (!mod) return;
+	if (!mod)
+		return;
 
 	VerseKey *vkey = (VerseKey *)mod->createKey();
 
 	navbar.key = backend->get_valid_key(navbar.module_name, key);
 	if (!navbar.is_dialog) {
-
-
 	}
-	GtkTreeModel* chapter_store = gtk_combo_box_get_model(
-			GTK_COMBO_BOX(navbar.comboboxentry_chapter));
-	GtkTreeModel* verse_store = gtk_combo_box_get_model(
-			GTK_COMBO_BOX(navbar.comboboxentry_verse));
+	GtkTreeModel *chapter_store = gtk_combo_box_get_model(
+	    GTK_COMBO_BOX(navbar.comboboxentry_chapter));
+	GtkTreeModel *verse_store = gtk_combo_box_get_model(
+	    GTK_COMBO_BOX(navbar.comboboxentry_verse));
 
 	do_display = FALSE;
 
@@ -82,24 +78,23 @@ void main_navbar_set(NAVBAR navbar, const char * key)
 	vkey->setText(key);
 
 	// we need the book index to highlight "active" in the pulldown.
-	if ((backend->module_has_testament(navbar.module_name, 1))
-	    && (vkey->getTestament() == 2))
-	        book = vkey->BMAX[0] + vkey->getBook();
+	if ((backend->module_has_testament(navbar.module_name, 1)) && (vkey->getTestament() == 2))
+		book = vkey->BMAX[0] + vkey->getBook();
 	else
-	        book = vkey->getBook();
+		book = vkey->getBook();
 
 	gtk_combo_box_set_active((GtkComboBox *)navbar.comboboxentry_book,
-                                             book-1);
+				 book - 1);
 
 	gtk_list_store_clear(GTK_LIST_STORE(chapter_store));
-	//char xtestament = vkey->Testament() ;
-	//char xbook = vkey->Book();
+
 	int xchapter = vkey->getChapter();
 	int xverse = vkey->getVerse();
+
 	x = (vkey->getChapterMax());
-	for(i=1; i <= x; i++) {
+	for (i = 1; i <= x; i++) {
 		char *num = main_format_number(i);
-		gtk_list_store_append (GTK_LIST_STORE(chapter_store), &iter);
+		gtk_list_store_append(GTK_LIST_STORE(chapter_store), &iter);
 		gtk_list_store_set(GTK_LIST_STORE(chapter_store),
 				   &iter,
 				   0,
@@ -108,17 +103,14 @@ void main_navbar_set(NAVBAR navbar, const char * key)
 		g_free(num);
 	}
 	gtk_combo_box_set_active((GtkComboBox *)navbar.comboboxentry_chapter,
-                                             xchapter-1);
+				 xchapter - 1);
 
 	gtk_list_store_clear(GTK_LIST_STORE(verse_store));
-	//xtestament = vkey->Testament() ;
-	//xbook = vkey->Book();
-	xchapter = vkey->getChapter();
-	xverse = vkey->getVerse();
+
 	x = (vkey->getVerseMax());
-	for(i=1; i <= x; i++) {
+	for (i = 1; i <= x; i++) {
 		char *num = main_format_number(i);
-		gtk_list_store_append (GTK_LIST_STORE(verse_store), &iter);
+		gtk_list_store_append(GTK_LIST_STORE(verse_store), &iter);
 		gtk_list_store_set(GTK_LIST_STORE(verse_store),
 				   &iter,
 				   0,
@@ -127,23 +119,25 @@ void main_navbar_set(NAVBAR navbar, const char * key)
 		g_free(num);
 	}
 	gtk_combo_box_set_active((GtkComboBox *)navbar.comboboxentry_verse,
-                                             xverse-1);
+				 xverse - 1);
 	gtk_entry_set_text(GTK_ENTRY(navbar.lookup_entry),
-				navbar.key);
+			   navbar.key);
 	do_display = TRUE;
 	g_free(gkey);
 
 	delete vkey;
 }
 
-
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 void main_navbar_fill_book_combo(NAVBAR navbar)
 {
 	if (!navbar.module_name)
 		return;
 
 	SWModule *mod = backend->get_SWModule(navbar.module_name);
-	if (!mod) return;
+	if (!mod)
+		return;
 
 	VerseKey *key = (VerseKey *)mod->createKey();
 	char *book = NULL;
@@ -157,17 +151,17 @@ void main_navbar_fill_book_combo(NAVBAR navbar)
 
 	do_display = FALSE;
 
-	GtkTreeModel* book_model = gtk_combo_box_get_model(
-			GTK_COMBO_BOX(navbar.comboboxentry_book));
+	GtkTreeModel *book_model = gtk_combo_box_get_model(
+	    GTK_COMBO_BOX(navbar.comboboxentry_book));
 	gtk_list_store_clear(GTK_LIST_STORE(book_model));
 
 	if (backend->module_has_testament(navbar.module_name, 1)) {
 		while (i < key->BMAX[0]) {
 			key->setTestament(1);
-			key->setBook(i+1);
-			book = strdup((const char *) key->getBookName());
-			XI_message(("book: %s",book));
-			gtk_list_store_append (GTK_LIST_STORE(book_model), &iter);
+			key->setBook(i + 1);
+			book = strdup((const char *)key->getBookName());
+			XI_message(("book: %s", book));
+			gtk_list_store_append(GTK_LIST_STORE(book_model), &iter);
 			gtk_list_store_set(GTK_LIST_STORE(book_model),
 					   &iter,
 					   0,
@@ -183,10 +177,10 @@ void main_navbar_fill_book_combo(NAVBAR navbar)
 	if (backend->module_has_testament(navbar.module_name, 2)) {
 		while (i < key->BMAX[1]) {
 			key->setTestament(2);
-			key->setBook(i+1);
-			book = strdup((const char *) key->getBookName());
-			XI_message(("book: %s",book));
-			gtk_list_store_append (GTK_LIST_STORE(book_model), &iter);
+			key->setBook(i + 1);
+			book = strdup((const char *)key->getBookName());
+			XI_message(("book: %s", book));
+			gtk_list_store_append(GTK_LIST_STORE(book_model), &iter);
 			gtk_list_store_set(GTK_LIST_STORE(book_model),
 					   &iter,
 					   0,
@@ -201,3 +195,4 @@ void main_navbar_fill_book_combo(NAVBAR navbar)
 
 	delete key;
 }
+#endif
