@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar.h - glue between all navbars and sword
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,24 +22,23 @@
 #ifndef _NAVBAR_H
 #define _NAVBAR_H
 
-
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 #include <config.h>
 
 typedef struct _navbar NAVBAR;
-struct _navbar {
+struct _navbar
+{
 	GtkWidget *button_back;
 	GtkWidget *button_forward;
 	GtkWidget *comboboxentry_book;
-//	SPINBUTTONS book;
+	//      SPINBUTTONS book;
 	GtkWidget *comboboxentry_chapter;
-//	SPINBUTTONS chapter;
+	//      SPINBUTTONS chapter;
 	GtkWidget *comboboxentry_verse;
-//	SPINBUTTONS verse;
+	//      SPINBUTTONS verse;
 	GtkWidget *lookup_entry;
 	gchar *key;
 	gchar *module_name;
@@ -48,11 +47,10 @@ struct _navbar {
 };
 extern NAVBAR navbar_main;
 
-void main_navbar_set(NAVBAR navbar, const char * key);
+void main_navbar_set(NAVBAR navbar, const char *key);
 void main_navbar_fill_book_combo(NAVBAR navbar);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _NAVBAR_H */
