@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar_book.h - glue between all navbar_book and sword
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,11 +23,11 @@
 #define _NAVBAR_BOOK_H
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 typedef struct _navbar_book NAVBAR_BOOK;
-struct _navbar_book {
+struct _navbar_book
+{
 	GtkWidget *button_up;
 	GtkWidget *button_down;
 	GtkWidget *button_left;
@@ -45,11 +45,10 @@ void main_navbar_book_parent(void);
 void main_navbar_book_first_child(void);
 void main_navbar_book_prev(void);
 void main_navbar_book_next(void);
-void main_setup_navbar_book(char * book_name, unsigned long offset);
-void main_navbar_book_entry_activate (const gchar* entry_text);
+void main_setup_navbar_book(char *book_name, unsigned long offset);
+void main_navbar_book_entry_activate(const gchar *entry_text);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _NAVBAR_BOOK_H */
