@@ -1,8 +1,8 @@
 /*
  * Xiphos Bible Study Tool
- * navbar.cc - glue between all navbars and sword
+ * navbar_book_dialog.cc - glue between all navbar_book_dialog and sword
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 #include <gtk/gtk.h>
 #include <versekey.h>
@@ -37,7 +37,7 @@
 
 #include "backend/sword_main.hh"
 
-DIALOG_DATA * cur_d;
+DIALOG_DATA *cur_d;
 
 /******************************************************************************
  * Name
@@ -55,11 +55,10 @@ DIALOG_DATA * cur_d;
  *   int
  */
 
-static
-int check_for_parent(DIALOG_DATA * d)
+static int check_for_parent(DIALOG_DATA *d)
 {
 	unsigned long offset_save;
-	BackEnd *be = (BackEnd *) d->backend;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	offset_save = d->offset;
 	be->set_treekey(d->offset);
@@ -71,8 +70,6 @@ int check_for_parent(DIALOG_DATA * d)
 	return 0;
 }
 
-
-
 /******************************************************************************
  * Name
  *  check_for_prev_sib
@@ -89,11 +86,10 @@ int check_for_parent(DIALOG_DATA * d)
  *   int
  */
 
-static
-int check_for_prev_sib(DIALOG_DATA * d)
+static int check_for_prev_sib(DIALOG_DATA *d)
 {
 	unsigned long offset_save;
-	BackEnd *be = (BackEnd *) d->backend;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	offset_save = d->offset;
 	be->set_treekey(d->offset);
@@ -105,8 +101,6 @@ int check_for_prev_sib(DIALOG_DATA * d)
 	return 0;
 }
 
-
-
 /******************************************************************************
  * Name
  *  check_for_next_sib
@@ -123,11 +117,10 @@ int check_for_prev_sib(DIALOG_DATA * d)
  *  int
  */
 
-static
-int check_for_next_sib(DIALOG_DATA * d)
+static int check_for_next_sib(DIALOG_DATA *d)
 {
 	unsigned long offset_save;
-	BackEnd *be = (BackEnd *) d->backend;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	offset_save = d->offset;
 	be->set_treekey(d->offset);
@@ -139,7 +132,6 @@ int check_for_next_sib(DIALOG_DATA * d)
 	return 0;
 }
 
-
 /******************************************************************************
  * Name
  *  main_navbar_book_dialog_parent
@@ -158,8 +150,8 @@ int check_for_next_sib(DIALOG_DATA * d)
 
 void main_navbar_book_dialog_parent(gpointer data)
 {
-	DIALOG_DATA * d = (DIALOG_DATA *) data;
-	BackEnd *be = (BackEnd *) d->backend;
+	DIALOG_DATA *d = (DIALOG_DATA *)data;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	be->set_treekey(d->offset);
 	if (be->treekey_parent(d->offset)) {
@@ -168,7 +160,6 @@ void main_navbar_book_dialog_parent(gpointer data)
 	}
 }
 
-
 /******************************************************************************
  * Name
  *  main_navbar_book_dialog_first_child
@@ -187,8 +178,8 @@ void main_navbar_book_dialog_parent(gpointer data)
 
 void main_navbar_book_dialog_first_child(gpointer data)
 {
-	DIALOG_DATA * d = (DIALOG_DATA *) data;
-	BackEnd *be = (BackEnd *) d->backend;
+	DIALOG_DATA *d = (DIALOG_DATA *)data;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	be->set_treekey(d->offset);
 	if (be->treekey_first_child(d->offset)) {
@@ -197,7 +188,6 @@ void main_navbar_book_dialog_first_child(gpointer data)
 	}
 }
 
-
 /******************************************************************************
  * Name
  *  main_navbar_book_dialog_prev
@@ -216,8 +206,8 @@ void main_navbar_book_dialog_first_child(gpointer data)
 
 void main_navbar_book_dialog_prev(gpointer data)
 {
-	DIALOG_DATA * d = (DIALOG_DATA *) data;
-	BackEnd *be = (BackEnd *) d->backend;
+	DIALOG_DATA *d = (DIALOG_DATA *)data;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	be->set_treekey(d->offset);
 	if (be->treekey_prev_sibling(d->offset)) {
@@ -226,7 +216,6 @@ void main_navbar_book_dialog_prev(gpointer data)
 	}
 }
 
-
 /******************************************************************************
  * Name
  *  main_navbar_book_dialog_next
@@ -245,8 +234,8 @@ void main_navbar_book_dialog_prev(gpointer data)
 
 void main_navbar_book_dialog_next(gpointer data)
 {
-	DIALOG_DATA * d = (DIALOG_DATA *) data;
-	BackEnd *be = (BackEnd *) d->backend;
+	DIALOG_DATA *d = (DIALOG_DATA *)data;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	be->set_treekey(d->offset);
 	if (be->treekey_next_sibling(d->offset)) {
@@ -255,7 +244,6 @@ void main_navbar_book_dialog_next(gpointer data)
 	}
 }
 
-
 /******************************************************************************
  * Name
  *  on_menu_select(
@@ -273,14 +261,12 @@ void main_navbar_book_dialog_next(gpointer data)
  *   void
  */
 
-static
-void on_menu_select(GtkMenuItem * menuitem, gpointer data)
+static void on_menu_select(GtkMenuItem *menuitem, gpointer data)
 {
 	cur_d->offset = GPOINTER_TO_INT(data);
 	main_setup_navbar_book_dialog(cur_d);
 }
 
-
 /******************************************************************************
  * Name
  *   main_book_dialog_drop_down_new
@@ -304,8 +290,8 @@ GtkWidget *main_navbar_book_dialog_drop_down_new(gpointer data)
 	GtkWidget *menu;
 	GtkWidget *item;
 	unsigned long offset;
-	DIALOG_DATA * d = (DIALOG_DATA *) data;
-	BackEnd *be = (BackEnd *) d->backend;
+	DIALOG_DATA *d = (DIALOG_DATA *)data;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	cur_d = d;
 	be->set_treekey(d->offset);
@@ -317,11 +303,11 @@ GtkWidget *main_navbar_book_dialog_drop_down_new(gpointer data)
 	}
 	/* add menu item for first sibling*/
 	tmpbuf = be->treekey_get_local_name(offset);
-	item = gtk_menu_item_new_with_label((gchar *) tmpbuf);
+	item = gtk_menu_item_new_with_label((gchar *)tmpbuf);
 	gtk_widget_show(item);
 	g_signal_connect(G_OBJECT(item), "activate",
 			 G_CALLBACK(on_menu_select),
-			GINT_TO_POINTER(offset) );
+			 GINT_TO_POINTER(offset));
 	gtk_container_add(GTK_CONTAINER(menu), item);
 	g_free(tmpbuf);
 
@@ -329,7 +315,7 @@ GtkWidget *main_navbar_book_dialog_drop_down_new(gpointer data)
 		offset = be->get_treekey_offset();
 		/* add menu item */
 		tmpbuf = be->treekey_get_local_name(offset);
-		item = gtk_menu_item_new_with_label((gchar *) tmpbuf);
+		item = gtk_menu_item_new_with_label((gchar *)tmpbuf);
 		gtk_widget_show(item);
 		g_signal_connect(G_OBJECT(item), "activate",
 				 G_CALLBACK(on_menu_select),
@@ -340,7 +326,6 @@ GtkWidget *main_navbar_book_dialog_drop_down_new(gpointer data)
 	return menu;
 }
 
-
 /******************************************************************************
  * Name
  *   main_setup_navbar_book_dialog
@@ -361,8 +346,8 @@ GtkWidget *main_navbar_book_dialog_drop_down_new(gpointer data)
 void main_setup_navbar_book_dialog(gpointer data)
 {
 	gchar *tmpbuf = NULL;
-	DIALOG_DATA * d = (DIALOG_DATA *) data;
-	BackEnd *be = (BackEnd *) d->backend;
+	DIALOG_DATA *d = (DIALOG_DATA *)data;
+	BackEnd *be = (BackEnd *)d->backend;
 
 	be->set_treekey(d->offset);
 	tmpbuf = be->get_key_from_offset(d->offset);
