@@ -1,8 +1,8 @@
 /*
  * Xiphos Bible Study Tool
- * navbar_book.h - glue between all navbar_book and sword
+ * navbar_book_dialog.h - glue between all navbar_book and sword
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,12 +19,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef  _NAVBAR_BOOK_DIALOG_H
+#ifndef _NAVBAR_BOOK_DIALOG_H
 #define _NAVBAR_BOOK_DIALOG_H
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 GtkWidget *main_navbar_book_dialog_drop_down_new(gpointer data);
@@ -34,9 +33,7 @@ void main_navbar_book_dialog_prev(gpointer data);
 void main_navbar_book_dialog_next(gpointer data);
 void main_setup_navbar_book_dialog(gpointer data);
 
-
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _NAVBAR_BOOK_DIALOG_H */
