@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * navbar_versekey.h - glue between all navbar_versekey and sword
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,15 +19,14 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef  _NAVBAR_VERSEKEY_H_
+#ifndef _NAVBAR_VERSEKEY_H_
 #define _NAVBAR_VERSEKEY_H_
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
-enum  {
+enum {
 	BOOK_BUTTON,
 	CHAPTER_BUTTON,
 	VERSE_BUTTON
@@ -41,7 +40,8 @@ enum {
 };
 
 typedef struct _navbar_versekey NAVBAR_VERSEKEY;
-struct _navbar_versekey {
+struct _navbar_versekey
+{
 	GtkWidget *navbar;
 	GtkWidget *button_sync;
 	GtkWidget *button_history_back;
@@ -79,7 +79,7 @@ struct _navbar_versekey {
 	GtkWidget *verse_menu;
 
 	GtkWidget *lookup_entry;
-  	//GtkTooltips *tooltips;
+	//GtkTooltips *tooltips;
 	GString *key;
 	gchar *book;
 	GString *module_name;
@@ -92,36 +92,44 @@ struct _navbar_versekey {
 extern NAVBAR_VERSEKEY navbar_versekey;
 extern NAVBAR_VERSEKEY navbar_parallel;
 
-const char *main_get_valid_key(const char *module_name, const char * key);
-GtkWidget *main_versekey_drop_down_book_menu(NAVBAR_VERSEKEY navbar,
+const char *main_get_valid_key(const char *module_name,
+			       const char *key);
+GtkWidget *main_versekey_drop_down_book_menu(NAVBAR_VERSEKEY
+						 navbar,
+					     gint nb_type,
+					     gpointer dialog,
+					     gpointer editor);
+GtkWidget *main_versekey_drop_down_verse_menu(NAVBAR_VERSEKEY
+						  navbar,
+					      gint nb_type,
+					      gpointer dialog,
+					      gpointer editor);
+GtkWidget *main_versekey_drop_down_chapter_menu(NAVBAR_VERSEKEY
+						    navbar,
 						gint nb_type,
 						gpointer dialog,
 						gpointer editor);
-GtkWidget *main_versekey_drop_down_verse_menu(NAVBAR_VERSEKEY navbar,
-						gint nb_type,
-						gpointer dialog,
-						gpointer editor);
-GtkWidget *main_versekey_drop_down_chapter_menu(NAVBAR_VERSEKEY navbar,
-						gint nb_type,
-						gpointer dialog,
-						gpointer editor);
-void main_navbar_versekey_spin_book(NAVBAR_VERSEKEY navbar, int direction);
-void main_navbar_versekey_spin_chapter(NAVBAR_VERSEKEY navbar, int direction);
-void main_navbar_versekey_spin_verse(NAVBAR_VERSEKEY navbar, int direction);
+void main_navbar_versekey_spin_book(NAVBAR_VERSEKEY navbar,
+				    int direction);
+void main_navbar_versekey_spin_chapter(NAVBAR_VERSEKEY navbar,
+				       int direction);
+void main_navbar_versekey_spin_verse(NAVBAR_VERSEKEY navbar,
+				     int direction);
 void main_navbar_versekey_book_prev(void);
 void main_navbar_versekey_book_next(void);
 void main_navbar_versekey_chapter_prev(void);
 void main_navbar_versekey_chapter_next(void);
 void main_navbar_versekey_verse_prev(void);
 void main_navbar_versekey_verse_next(void);
-void main_setup_navbar_versekey(char * module_name, char * key);
-void main_navbar_versekey_set(NAVBAR_VERSEKEY navbar, const char * key);
+void main_setup_navbar_versekey(char *module_name, char *key);
+void main_navbar_versekey_set(NAVBAR_VERSEKEY navbar,
+			      const char *key);
 
 gboolean access_on_up_eventbox_button_release_event(gint element);
-gboolean access_on_down_eventbox_button_release_event(gint element);
+gboolean access_on_down_eventbox_button_release_event(gint
+							  element);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _NAVBAR_VERSEKEY_H_ */
