@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * parallel_view.cc - support for displaying multiple modules
  *
- * Copyright (C) 2004-2014 Xiphos Developer Team
+ * Copyright (C) 2004-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@
 
 #include "gui/debug_glib_null.h"
 
-#define	HTML_START	"<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><style type=\"text/css\"><!-- A { text-decoration:none } *[dir=rtl] { text-align: right; } --></style></head>"
+#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><style type=\"text/css\"><!-- A { text-decoration:none } *[dir=rtl] { text-align: right; } --></style></head>"
 
 extern GtkWidget *entrycbIntBook;
 extern GtkWidget *sbIntChapter;
@@ -75,7 +75,6 @@ static const gchar *tf2of(int true_false)
 		return "Off";
 }
 
-
 /******************************************************************************
  * Name
  *   set_global_option
@@ -94,34 +93,33 @@ static const gchar *tf2of(int true_false)
  *   void
  */
 
-static void set_global_option(char * option, gboolean choice)
+static void set_global_option(char *option, gboolean choice)
 {
 	const char *on_off = tf2of(choice);
 	SWMgr *mgr = backend_p->get_mgr();
-	char *buf= g_strdup (option);
+	char *buf = g_strdup(option);
 
-//	XI_message (("option://%s\n\n",option));
+	//	XI_message (("option://%s\n\n",option));
 
 	mgr->setGlobalOption(buf, on_off);
 
 	xml_set_value("Xiphos",
 		      "parallel",
-		      (char*)g_strdelimit (buf,"' ", '_'),
-		      (char*)(choice ? "1" : "0"));
-	g_free (buf);
+		      (char *)g_strdelimit(buf, "' ", '_'),
+		      (char *)(choice ? "1" : "0"));
+	g_free(buf);
 }
 
-
-static void set_global_textual_reading (const char * option, int choice)
+static void set_global_textual_reading(const char *option, int choice)
 {
 	//gboolean primary = 0, secondary = 0, all = 0;
-	char *buf= g_strdup (option);
+	char *buf = g_strdup(option);
 	SWMgr *mgr = backend_p->get_mgr();
 
 	xml_set_value("Xiphos",
 		      "parallel",
-		      (char*)g_strdelimit (buf,"' ", '_'),
-		      (char*)(choice ? "1" : "0"));
+		      (char *)g_strdelimit(buf, "' ", '_'),
+		      (char *)(choice ? "1" : "0"));
 
 	/*switch (choice)
 	{
@@ -139,15 +137,15 @@ static void set_global_textual_reading (const char * option, int choice)
 		gui_generic_warning((char*)"Xiphos: invalid internal variant");
 		break;
 	}*/
-	XI_message (("set_global_textual_reading\noption://%s",option));
+	XI_message(("set_global_textual_reading\noption://%s", option));
 
 	mgr->setGlobalOption("Textual Variants", option);
 
-	g_free (buf);
-
+	g_free(buf);
 }
 
-
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 /******************************************************************************
  * Name
  *   main_parallel_change_verse
@@ -177,17 +175,15 @@ gchar *main_parallel_change_verse(void)
 
 	bookname = gtk_entry_get_text(GTK_ENTRY(entrycbIntBook));
 	chapter =
-	    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON
-					     (sbIntChapter));
+	    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sbIntChapter));
 	verse =
-	    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON
-					     (sbIntVerse));
+	    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(sbIntVerse));
 
 	sprintf(buf, "%s %d:%d", bookname, chapter, verse);
 
 	newbook = backend_p->key_get_book(settings.parallel_list[0], buf);
 	chapter = backend_p->key_get_chapter(settings.parallel_list[0], buf);
-	verse   = backend_p->key_get_verse(settings.parallel_list[0], buf);
+	verse = backend_p->key_get_verse(settings.parallel_list[0], buf);
 
 	if (strcmp(bookname, newbook))
 		gtk_entry_set_text(GTK_ENTRY(entrycbIntBook), newbook);
@@ -206,7 +202,7 @@ gchar *main_parallel_change_verse(void)
 	g_free(newbook);
 	return retval;
 }
-
+#endif
 
 /******************************************************************************
  * Name
@@ -227,12 +223,11 @@ gchar *main_parallel_change_verse(void)
  *   void
  */
 
-void main_set_parallel_module_global_options(GtkCheckMenuItem * menuitem,
-					   gpointer user_data)
+void main_set_parallel_module_global_options(GtkCheckMenuItem *menuitem,
+					     gpointer user_data)
 {
-	gchar *option = (gchar*) user_data;
-	gboolean choice = gtk_check_menu_item_get_active (menuitem);
-
+	gchar *option = (gchar *)user_data;
+	gboolean choice = gtk_check_menu_item_get_active(menuitem);
 
 	if (!strcmp(option, "Strong's Numbers")) {
 		settings.parallel_strongs = choice;
@@ -264,59 +259,68 @@ void main_set_parallel_module_global_options(GtkCheckMenuItem * menuitem,
 		set_global_option(option, choice);
 	}
 
-	if (!strcmp(option,"Cross-references")) {
+	if (!strcmp(option, "Cross-references")) {
 		settings.parallel_crossref = choice;
 		set_global_option(option, choice);
 	}
 
-	if (!strcmp(option,"Transliteration")) {
+	if (!strcmp(option, "Transliteration")) {
 		settings.parallel_transliteration = choice;
 		set_global_option(option, choice);
 	}
 
-	if (!strcmp(option,"Words of Christ in Red")) {
+	if (!strcmp(option, "Words of Christ in Red")) {
 		settings.parallel_red_words = choice;
 		set_global_option(option, choice);
 	}
 
-	if (!strcmp(option,"Morpheme Segmentation")) {
+	if (!strcmp(option, "Morpheme Segmentation")) {
 		settings.parallel_segmentation = choice;
 		set_global_option(option, choice);
 	}
 
-	if (!strcmp(option,"Headings")) {
+	if (!strcmp(option, "Headings")) {
 		settings.parallel_headings = choice;
 		set_global_option(option, choice);
 	}
 
-	if (!strcmp(option,"Lemmas")) {
+	if (!strcmp(option, "Lemmas")) {
 		settings.parallel_lemmas = choice;
 		set_global_option(option, choice);
 	}
 
-	if (!strcmp(option,"Primary Reading")) {
+	if (!strcmp(option, "Primary Reading")) {
 		settings.parallel_variants_primary = choice;
-		set_global_textual_reading (option, choice);
+		set_global_textual_reading(option, choice);
 	}
-	if (!strcmp(option,"Secondary Reading")) {
+	if (!strcmp(option, "Secondary Reading")) {
 		settings.parallel_variants_secondary = choice;
-		set_global_textual_reading (option, choice);
+		set_global_textual_reading(option, choice);
 	}
-	if (!strcmp(option,"All Readings")) {
+	if (!strcmp(option, "All Readings")) {
 		settings.parallel_variants_all = choice;
-		set_global_textual_reading (option, choice);
+		set_global_textual_reading(option, choice);
 	}
 
-	if (!strcmp(option,"Transliterated Forms")) {
+	if (!strcmp(option, "Transliterated Forms")) {
 		settings.parallel_xlit = choice;
 		set_global_option(option, choice);
 	}
 
-	if (!strcmp(option,"Enumerations")) {
+	if (!strcmp(option, "Enumerations")) {
 		settings.parallel_enumerated = choice;
 		set_global_option(option, choice);
 	}
 
+	if (!strcmp(option, "Glosses")) {
+		settings.parallel_glosses = choice;
+		set_global_option(option, choice);
+	}
+
+	if (!strcmp(option, "Morpheme Segmentation")) {
+		settings.parallel_morphseg = choice;
+		set_global_option(option, choice);
+	}
 
 	/* display change */
 	if (settings.dockedInt) {
@@ -349,32 +353,28 @@ void main_set_parallel_options_at_start(void)
 
 	GList *tmp = backend->get_module_options();
 	while (tmp) {
-		char *option = g_strdup((char*)tmp->data);
-		g_strdelimit (option,"' ", '_');
+		char *option = g_strdup((char *)tmp->data);
+		g_strdelimit(option, "' ", '_');
 		//XI_message(("\n\n%s\n%s\n", (char*)tmp->data, option));
 		value = xml_get_value("parallel", option);
 		int choice = (value ? atoi(value) : 0);
-		if (!strcmp((char*)tmp->data,"Textual Variants")) {
-			if (atoi (xml_get_value("parallel", "Primary_Reading")))
-				mgr->setGlobalOption ("Textual Variants",
-						      "Primary Reading");
-			else if (atoi (xml_get_value("parallel", "Secondary_Reading")))
-				mgr->setGlobalOption ("Textual Variants",
-						      "Secondary Reading");
+		if (!strcmp((char *)tmp->data, "Textual Variants")) {
+			if (atoi(xml_get_value("parallel", "Primary_Reading")))
+				mgr->setGlobalOption("Textual Variants",
+						     "Primary Reading");
+			else if (atoi(xml_get_value("parallel", "Secondary_Reading")))
+				mgr->setGlobalOption("Textual Variants",
+						     "Secondary Reading");
 			else
-				mgr->setGlobalOption ("Textual Variants",
-						      "All Readings");
+				mgr->setGlobalOption("Textual Variants",
+						     "All Readings");
 		} else
-			mgr->setGlobalOption((char*)tmp->data, choice ? "On" : "Off");
+			mgr->setGlobalOption((char *)tmp->data, choice ? "On" : "Off");
 		g_free(option);
 		tmp = g_list_next(tmp);
 	}
-
-
 }
 
-
-
 /******************************************************************************
  * Name
  *   main_load_g_ops_parallel
@@ -393,99 +393,90 @@ void main_set_parallel_options_at_start(void)
 
 void main_load_g_ops_parallel(GtkWidget *menu)
 {
-	GtkWidget * item;
-	GtkWidget * variants_menu;
+	GtkWidget *item;
+	GtkWidget *variants_menu;
 	GSList *group = NULL;
 
 	item = gtk_check_menu_item_new_with_label(_("Strong's Numbers"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item),settings.parallel_strongs);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_strongs);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*) "Strong's Numbers");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Strong's Numbers");
 
 	item = gtk_check_menu_item_new_with_label(_("Footnotes"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_footnotes);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_footnotes);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			   (char*) "Footnotes");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Footnotes");
 
 	item = gtk_check_menu_item_new_with_label(_("Morphological Tags"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_morphs);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_morphs);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*)  "Morphological Tags");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Morphological Tags");
 
 	item = gtk_check_menu_item_new_with_label(_("Hebrew Vowel Points"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_hebrewpoints);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_hebrewpoints);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*)  "Hebrew Vowel Points");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Hebrew Vowel Points");
 
 	item = gtk_check_menu_item_new_with_label(_("Hebrew Cantillation"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_cantillationmarks);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_cantillationmarks);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			   (char*) "Hebrew Cantillation");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Hebrew Cantillation");
 
 	item = gtk_check_menu_item_new_with_label(_("Greek Accents"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_greekaccents);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_greekaccents);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*)  "Greek Accents");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Greek Accents");
 
 	item = gtk_check_menu_item_new_with_label(_("Cross-references"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_crossref);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_crossref);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			   (char*) "Cross-references");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Cross-references");
 
 	item = gtk_check_menu_item_new_with_label(_("Lemmas"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_lemmas);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_lemmas);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*) "Lemmas");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Lemmas");
 
 	item = gtk_check_menu_item_new_with_label(_("Headings"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_headings);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_headings);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*)  "Headings");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Headings");
 
 	item = gtk_check_menu_item_new_with_label(_("Morpheme Segmentation"));
 #if 0
@@ -495,31 +486,28 @@ void main_load_g_ops_parallel(GtkWidget *menu)
 #endif
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_segmentation);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_segmentation);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*) "Morpheme Segmentation" );
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Morpheme Segmentation");
 
 	item = gtk_check_menu_item_new_with_label(_("Words of Christ in Red"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_red_words);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_red_words);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			   (char*) "Words of Christ in Red");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Words of Christ in Red");
 
 	item = gtk_check_menu_item_new_with_label(_("Transliteration"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_transliteration);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_transliteration);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			   (char*) "Transliteration");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Transliteration");
 
 	item = gtk_menu_item_new_with_label(_("Textual Variants"));
 	gtk_widget_show(item);
@@ -529,56 +517,70 @@ void main_load_g_ops_parallel(GtkWidget *menu)
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(item),
 				  variants_menu);
 
-	item = gtk_radio_menu_item_new_with_mnemonic (group, _("Primary Reading" ));
-  	group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
+	item = gtk_radio_menu_item_new_with_mnemonic(group, _("Primary Reading"));
+	group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(item));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(variants_menu), item);
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_variants_primary);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_variants_primary);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			   (char*) "Primary Reading");
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Primary Reading");
 
-	item = gtk_radio_menu_item_new_with_mnemonic (group, _("Secondary Reading" ));
-  	group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
+	item = gtk_radio_menu_item_new_with_mnemonic(group, _("Secondary Reading"));
+	group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(item));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(variants_menu), item);
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_variants_secondary);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_variants_secondary);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			   (char*) "Secondary Reading");
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Secondary Reading");
 
-	item = gtk_radio_menu_item_new_with_mnemonic (group, _("All Readings" ));
-  	group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
+	item = gtk_radio_menu_item_new_with_mnemonic(group, _("All Readings"));
+	//group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(item));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(variants_menu), item);
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), settings.parallel_variants_all);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_variants_all);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			   (char*) "All Readings");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"All Readings");
 
 	item = gtk_check_menu_item_new_with_label(_("Transliterated Forms"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_xlit);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_xlit);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*) "Transliterated Forms");
-
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Transliterated Forms");
 
 	item = gtk_check_menu_item_new_with_label(_("Enumerations"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_enumerated);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_enumerated);
 	g_signal_connect(G_OBJECT(item), "activate",
-	    G_CALLBACK(main_set_parallel_module_global_options),
-			  (char*) "Enumerations");
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Enumerations");
+
+	item = gtk_check_menu_item_new_with_label(_("Glosses"));
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_glosses);
+	g_signal_connect(G_OBJECT(item), "activate",
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Glosses");
+
+	item = gtk_check_menu_item_new_with_label(_("Morpheme Segmentation"));
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), settings.parallel_morphseg);
+	g_signal_connect(G_OBJECT(item), "activate",
+			 G_CALLBACK(main_set_parallel_module_global_options),
+			 (char *)"Morpheme Segmentation");
 }
 
-
-
 /******************************************************************************
  * Name
  *   gui_check_parallel_modules
@@ -603,23 +605,24 @@ void main_check_parallel_modules(void)
 	return;
 }
 
-
 void get_heading(SWBuf &text, BackEnd *p, gint modidx)
 {
-	const gchar *preverse, *preverse2, *buf;
+	const gchar *preverse;
 	gchar heading[8];
 
 	int x = 0;
 	sprintf(heading, "%d", x);
 	while ((preverse = p->get_entry_attribute("Heading", "Preverse",
 						  heading)) != NULL) {
+		const gchar *preverse2, *buf;
+
 		preverse2 = p->render_this_text(
-			       settings.parallel_list[modidx], preverse);
+		    settings.parallel_list[modidx], preverse);
 		buf = g_strdup_printf("<br/><b>%s</b><br/><br/>", preverse2);
 
 		text += buf;
 
-		g_free((gchar *)preverse2); 
+		g_free((gchar *)preverse2);
 		g_free((gchar *)preverse);
 		g_free((gchar *)buf);
 		++x;
@@ -645,27 +648,29 @@ void get_heading(SWBuf &text, BackEnd *p, gint modidx)
 
 void main_update_parallel_page(void)
 {
-	gchar *tmpBuf, *fontstring;
-	const gchar *rowcolor;
-	gchar *utf8str, *mod_name;
+	gchar *tmpBuf;
 	gint modidx;
 	gboolean is_rtol = FALSE;
 	GString *data;
-	MOD_FONT *mf;
 
 	settings.cvparallel = settings.currentverse;
 
 	tmpBuf = g_strdup_printf(HTML_START
-				  "<body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table>",
-				  settings.bible_bg_color,
-				  settings.bible_text_color, settings.link_color);
+				 "<body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table>",
+				 settings.bible_bg_color,
+				 settings.bible_text_color, settings.link_color);
 	data = g_string_new(tmpBuf);
 	g_free(tmpBuf);
 
 	if (settings.parallel_list) {
+		gchar *mod_name;
 		for (modidx = 0;
-		     (mod_name = settings.parallel_list[modidx]);
+		     mod_name = settings.parallel_list[modidx];
 		     modidx++) {
+			const gchar *rowcolor;
+			const char *real_mod = main_get_name(mod_name);
+			if (real_mod)
+				mod_name = (gchar *)real_mod;
 
 			// if a module was deleted, but still in parallels list,
 			// we will segfault when looking for content for the
@@ -678,38 +683,39 @@ void main_update_parallel_page(void)
 
 			is_rtol = main_is_mod_rtol(mod_name);
 
-			if (modidx % 2 == 1)	/* alternating background color */
+			if (modidx % 2 == 1) /* alternating background color */
 				rowcolor = "#c0c0c0";
 			else
 				rowcolor = settings.bible_bg_color;
 
 			if (modidx == 0) {
 				tmpBuf = g_strdup_printf(
-					"<tr><td><i><font color=\"%s\" size=\"%d\">[%s]</font></i></td></tr>",
-					settings.bible_verse_num_color,
-					settings.verse_num_font_size + settings.base_font_size,
-					settings.currentverse);
+				    "<tr><td><i><font color=\"%s\" size=\"%d\">[%s]</font></i></td></tr>",
+				    settings.bible_verse_num_color,
+				    settings.verse_num_font_size + settings.base_font_size,
+				    settings.currentverse);
 				g_string_append(data, tmpBuf);
 				g_free(tmpBuf);
 			}
 
-			mf = get_font(mod_name);
-			fontstring = g_strdup_printf((((strlen(mf->old_font) < 2) ||
-						       !strncmp(mf->old_font, "none", 4))
-						      ? "<font size=\"%+d\">"
-						      : "<font size=\"%+d\" face=\"%s\">"),
-						     mf->old_font_size_value, mf->old_font);
+			MOD_FONT *mf = get_font(mod_name);
+			gchar *fontstring = g_strdup_printf((((strlen(mf->old_font) < 2) ||
+							      !strncmp(mf->old_font, "none", 4))
+							     ? "<font size=\"%+d\">"
+							     : "<font size=\"%+d\" face=\"%s\">"),
+							    mf->old_font_size_value, mf->old_font);
 			free_font(mf);
 
+			const char *abbreviation = main_get_abbreviation(mod_name);
 			tmpBuf = g_strdup_printf(
-				"<tr bgcolor=\"%s\"><td>%s<b><a href=\"passagestudy.jsp?action=showModInfo&value=%s&module=%s\"><font color=\"%s\" size=\"%+d\">[%s]</font></a></b><br/>",
-				rowcolor,
-				fontstring,
-				main_get_module_description(mod_name),
-				mod_name,
-				settings.bible_verse_num_color,
-				settings.verse_num_font_size + settings.base_font_size,
-				mod_name);
+			    "<tr bgcolor=\"%s\"><td>%s<b><a href=\"passagestudy.jsp?action=showModInfo&value=%s&module=%s\"><font color=\"%s\" size=\"%+d\">[%s]</font></a></b><br/>",
+			    rowcolor,
+			    fontstring,
+			    main_get_module_description(mod_name),
+			    mod_name,
+			    settings.bible_verse_num_color,
+			    settings.verse_num_font_size + settings.base_font_size,
+			    (abbreviation ? abbreviation : mod_name));
 			g_free(fontstring);
 			g_string_append(data, tmpBuf);
 			g_free(tmpBuf);
@@ -718,21 +724,19 @@ void main_update_parallel_page(void)
 				g_string_append(data, "<br/><div align=right>");
 
 			// does this verse exist for this module?
-			if (!backend_p->is_Bible_key(settings.parallel_list[modidx],
+			if (!backend_p->is_Bible_key(mod_name,
 						     settings.cvparallel, settings.cvparallel)) {
 				g_string_append(data, no_content);
-			}
-			else
-			{
+			} else {
 				SWBuf text("");
-				backend_p->set_module_key(settings.parallel_list[modidx], settings.cvparallel);
+				backend_p->set_module_key(mod_name, settings.cvparallel);
 				get_heading(text, backend_p, modidx);
 				g_string_append(data, text.c_str());
 
-				utf8str = backend_p->get_render_text(mod_name, settings.currentverse);
+				gchar *utf8str = backend_p->get_render_text(mod_name, settings.currentverse);
 				if (utf8str) {
-				    g_string_append(data, utf8str);
-				    g_free(utf8str);
+					g_string_append(data, utf8str);
+					g_free(utf8str);
 				}
 			}
 
@@ -740,9 +744,9 @@ void main_update_parallel_page(void)
 				g_string_append(data, "</div><br/>");
 
 			tmpBuf = g_strdup_printf(
-				"<small><br/>[<a href=\"passagestudy.jsp?action=showParallel&"
-				"type=swap&value=%s\">%s</a>]</small></font></td></tr>",
-				mod_name,_("view context"));
+			    "<small><br/>[<a href=\"passagestudy.jsp?action=showParallel&"
+			    "type=swap&value=%s\">%s</a>]</small></font></td></tr>",
+			    mod_name, _("view context"));
 			g_string_append(data, tmpBuf);
 			g_free(tmpBuf);
 		}
@@ -750,14 +754,11 @@ void main_update_parallel_page(void)
 
 	g_string_append(data, "</table></body></html>");
 	HtmlOutput((char *)(settings.imageresize
-			    ? AnalyzeForImageSize
-			         (data->str,
-				  GDK_WINDOW(gtk_widget_get_window(widgets.html_parallel)))
-			    : data->str),
+				? AnalyzeForImageSize(data->str,
+						      GDK_WINDOW(gtk_widget_get_window(widgets.html_parallel)))
+				: data->str),
 		   widgets.html_parallel, NULL, NULL);
 	g_string_free(data, TRUE);
-
-						
 }
 
 /******************************************************************************
@@ -776,7 +777,7 @@ void main_update_parallel_page(void)
  *   void
  */
 
-static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_count, gint fraction)
+static void interpolate_parallel_display(SWBuf &text, gchar *key, gint parallel_count, gint fraction)
 {
 	// identify the module whose v11n will drive us.
 	// should be 1st parallel module.
@@ -784,11 +785,12 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 	char *module_name = (settings.parallel_list
 			     ? settings.parallel_list[0]
 			     : settings.MainWindowModule);
+	// might have an abbrev. get the real.
+	const char *real_mod = main_get_name(module_name);
+	if (real_mod)
+		module_name = (gchar *)real_mod;
 
-	gchar  	*utf8str,
-		*textColor,
-		*tmpkey,
-		tmpbuf[256];
+	gchar *utf8str, *textColor, *tmpkey, tmpbuf[256];
 	const gchar *bgColor;
 	gchar str[500];
 	gint cur_verse, cur_chapter, verse, modidx;
@@ -796,11 +798,13 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 	MOD_FONT **mf;
 	gboolean *is_rtol, *is_module, *is_bible_text;
 
-	if (!gtk_widget_get_realized(GTK_WIDGET(widgets.notebook_bible_parallel))) return;
+	if (!gtk_widget_get_realized(GTK_WIDGET(widgets.notebook_bible_parallel)))
+		return;
 
 	// need #verses to process in this chapter.
 	SWModule *mod = backend->get_SWModule(module_name);
-	if (!mod) return;
+	if (!mod)
+		return;
 
 	VerseKey *vkey = (VerseKey *)mod->createKey();
 	int xverses;
@@ -810,27 +814,29 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 	xverses = (vkey->getVerseMax());
 	delete vkey;
 
-	is_module     = g_new(gboolean, parallel_count);
-	is_rtol       = g_new(gboolean, parallel_count);
+	is_module = g_new(gboolean, parallel_count);
+	is_rtol = g_new(gboolean, parallel_count);
 	is_bible_text = g_new(gboolean, parallel_count);
-	mf            = g_new(MOD_FONT *, parallel_count);
+	mf = g_new(MOD_FONT *, parallel_count);
 
 	// quick cache of fonts/rtol/type info.
 	for (modidx = 0; modidx < parallel_count; ++modidx) {
+		gchar *mod = settings.parallel_list[modidx];
+		// might have an abbrev. get the real.
+		const char *real_mod = main_get_name(mod);
+		if (real_mod)
+			mod = (gchar *)real_mod;
+
 		// determine module presence once each.
-		is_module[modidx] = backend->is_module(settings.parallel_list[modidx]);
+		is_module[modidx] = backend->is_module(mod);
 
 		if (is_module[modidx]) {
-			is_rtol[modidx] = main_is_mod_rtol(settings.parallel_list[modidx]);
-			mf[modidx] = get_font(settings.parallel_list[modidx]);
+			is_rtol[modidx] = main_is_mod_rtol(mod);
+			mf[modidx] = get_font(mod);
 			is_bible_text[modidx] =
-			    (main_get_mod_type(settings.parallel_list[modidx])
-			     == TEXT_TYPE);
-		}
-		else
-		{
-			gui_generic_warning((unknown_parallel +
-					     (SWBuf)settings.parallel_list[modidx]).c_str());
+			    (main_get_mod_type(mod) == TEXT_TYPE);
+		} else {
+			gui_generic_warning((unknown_parallel + (SWBuf)mod).c_str());
 		}
 	}
 
@@ -842,9 +848,9 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 	// it's consistent, but very possibly wrong for all but the 1st.
 	tmpkey = backend_p->get_valid_key(module_name, key);
 
-	cur_book    = backend_p->key_get_book(module_name, tmpkey);
+	cur_book = backend_p->key_get_book(module_name, tmpkey);
 	cur_chapter = backend_p->key_get_chapter(module_name, tmpkey);
-	cur_verse   = backend_p->key_get_verse(module_name, tmpkey);
+	cur_verse = backend_p->key_get_verse(module_name, tmpkey);
 	settings.intCurVerse = cur_verse;
 
 	for (verse = 1; verse <= xverses; ++verse) {
@@ -861,8 +867,14 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 			bgColor = settings.bible_bg_color;
 
 		for (modidx = 0; modidx < parallel_count; modidx++) {
-			if (is_module[modidx]) {		
-				
+			gchar *mod = settings.parallel_list[modidx];
+			// might have an abbrev. get the real.
+			const char *real_mod = main_get_name(mod);
+			if (real_mod)
+				mod = (gchar *)real_mod;
+
+			if (is_module[modidx]) {
+
 				// mark current verse properly.
 				if ((verse == cur_verse) && is_bible_text[modidx])
 					textColor = settings.currentverse_color;
@@ -887,18 +899,17 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 					 mf[modidx]->old_font,
 					 mf[modidx]->old_font_size_value,
 					 textColor);
-				g_free((gchar*)newurl);
+				g_free((gchar *)newurl);
 				g_free(num);
 				text += str;
 
 				if (is_rtol[modidx])
 					text += "<br/><div align=right>";
 
-				backend_p->set_module_key(settings.parallel_list[modidx], tmpkey);
+				backend_p->set_module_key(mod, tmpkey);
 				get_heading(text, backend_p, modidx);
 
-				utf8str = backend_p->get_render_text
-						(settings.parallel_list[modidx], tmpkey);
+				utf8str = backend_p->get_render_text(mod, tmpkey);
 				if (utf8str) {
 					text += utf8str;
 					g_free(utf8str);
@@ -926,7 +937,6 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 	g_free(is_bible_text);
 }
 
-
 /******************************************************************************
  * Name
  *   main_update_parallel_page_detached
@@ -961,21 +971,22 @@ void main_update_parallel_page_detached(void)
 
 	/* get the per-column percentage width. */
 	/* 2 => 50, 4 => 25, 5 => 20, 10 => 10, ... */
-	fraction = (parallel_count ? (100/parallel_count) : 100);
+	fraction = (parallel_count ? (100 / parallel_count) : 100);
 
 	snprintf(buf, 499, HTML_START
-		"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table align=\"left\" valign=\"top\"><tr valign=\"top\" >",
-		settings.bible_bg_color, settings.bible_text_color,
-		settings.link_color);
+		 "<body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table align=\"left\" valign=\"top\"><tr valign=\"top\" >",
+		 settings.bible_bg_color, settings.bible_text_color,
+		 settings.link_color);
 	text += buf;
 
 	for (modidx = 0; settings.parallel_list[modidx]; ++modidx) {
+		const char *abbreviation = main_get_abbreviation(settings.parallel_list[modidx]);
 		snprintf(buf, 499,
 			 "<td valign=\"top\" width=\"%d%%\" bgcolor=\"#c0c0c0\"><font color=\"%s\" size=\"%+d\"><b>%s</b></font></td>",
 			 fraction,
 			 settings.bible_verse_num_color,
 			 settings.verse_num_font_size + settings.base_font_size,
-			 settings.parallel_list[modidx]);
+			 (abbreviation ? abbreviation : settings.parallel_list[modidx]));
 		text += buf;
 	}
 
@@ -986,10 +997,9 @@ void main_update_parallel_page_detached(void)
 	snprintf(buf, 499, "%d", settings.intCurVerse);
 
 	HtmlOutput((char *)(settings.imageresize
-			    ? AnalyzeForImageSize
-			         ((char *)text.c_str(),
-				  GDK_WINDOW(gtk_widget_get_window(widgets.html_parallel_dialog)))
-			    : (char *)text.c_str()),
+				? AnalyzeForImageSize((char *)text.c_str(),
+						      GDK_WINDOW(gtk_widget_get_window(widgets.html_parallel_dialog)))
+				: (char *)text.c_str()),
 		   widgets.html_parallel_dialog, NULL, buf);
 }
 
@@ -1016,7 +1026,8 @@ void main_swap_parallel_with_main(char *intmod)
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_bible_parallel), 0);
 }
 
-
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 /******************************************************************************
  * Name
  *   load_menu_formmod_list
@@ -1034,11 +1045,10 @@ void main_swap_parallel_with_main(char *intmod)
  *   void
  */
 
-void main_load_menu_form_mod_list(GtkWidget * pmInt, gchar * label,
-				   GCallback mycallback)
+void main_load_menu_form_mod_list(GtkWidget *pmInt, gchar *label,
+				  GCallback mycallback)
 {
 	GList *tmp = get_list(TEXT_DESC_LIST);
-	GtkWidget *item;
 	GtkWidget *view_module;
 	GtkWidget *view_module_menu;
 
@@ -1049,16 +1059,16 @@ void main_load_menu_form_mod_list(GtkWidget * pmInt, gchar * label,
 	view_module_menu = gtk_menu_new();
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(view_module),
 				  view_module_menu);
-/*	view_module_menu_accels =
+	/*	view_module_menu_accels =
 	    gtk_menu_ensure_uline_accel_group(GTK_MENU
 					      (view_module_menu));*/
 	while (tmp != NULL) {
-		item =
-		    gtk_menu_item_new_with_label((gchar *) tmp->data);
+		GtkWidget *item =
+		    gtk_menu_item_new_with_label((gchar *)tmp->data);
 		gtk_widget_show(item);
 		g_signal_connect(G_OBJECT(item), "activate",
-				   G_CALLBACK(mycallback),
-				   g_strdup((gchar *) tmp->data));
+				 G_CALLBACK(mycallback),
+				 g_strdup((gchar *)tmp->data));
 
 		gtk_container_add(GTK_CONTAINER(view_module_menu),
 				  item);
@@ -1066,7 +1076,7 @@ void main_load_menu_form_mod_list(GtkWidget * pmInt, gchar * label,
 	}
 	g_list_free(tmp);
 }
-
+#endif
 
 /******************************************************************************
  * Name
@@ -1091,7 +1101,6 @@ void main_init_parallel_view(void)
 	backend_p = new BackEnd();
 }
 
-
 /******************************************************************************
  * Name
  *   main_delete_parallel_view
