@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * prayerlists.h -  code to create several different prayer lists
  *
- * Copyright (C) 2008-2014 Xiphos Developer Team
+ * Copyright (C) 2008-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,8 +23,7 @@
 #define _PRAYERLISTS_H
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 gboolean main_prayerlist_basic_create(void);
@@ -36,5 +35,4 @@ gboolean main_prayerlist_outlined_topic_create(void);
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _PRAYERLISTS_H */
