@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * previewer.cc -
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ extern "C" {
 
 #include "gui/debug_glib_null.h"
 
-#define	HTML_START	"<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\">\
+#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\">\
 <style type=\"text/css\"><!-- \
 A { text-decoration:none } \
 *[dir=rtl] { text-align: right;} \
@@ -62,18 +62,21 @@ static GtkWidget *previewer_html_widget;
 
 void main_set_previewer_widget(int in_sidebar)
 {
-    if (in_sidebar)
-    	previewer_html_widget = sidebar.html_viewer_widget;
-    else
-	previewer_html_widget = widgets.html_previewer_text;
+	if (in_sidebar)
+		previewer_html_widget = sidebar.html_viewer_widget;
+	else
+		previewer_html_widget = widgets.html_previewer_text;
 }
 
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 GtkWidget *main_get_previewer_widget(void)
 {
-	return 	settings.show_previewer_in_sidebar
-		? sidebar.html_viewer_widget
-		: widgets.html_previewer_text;
+	return settings.show_previewer_in_sidebar
+		   ? sidebar.html_viewer_widget
+		   : widgets.html_previewer_text;
 }
+#endif
 
 /******************************************************************************
  * Name
@@ -110,7 +113,8 @@ void main_init_previewer(void)
 	g_string_free(str, TRUE);
 }
 
-
+#if 0
+// unneeded at this time.  disabled to silence cppcheck.
 /******************************************************************************
  * Name
  *   main_clear_viewer
@@ -136,7 +140,7 @@ void main_clear_viewer(void)
 	main_init_previewer();
 #endif /* USE_PREVIEWER_AUTOCLEAR */
 }
-
+#endif
 
 /******************************************************************************
  * Name
@@ -155,17 +159,17 @@ void main_clear_viewer(void)
  *   void
  */
 
-void main_information_viewer(const gchar * mod_name,
-			     const gchar * text,
-			     const gchar * key,
-			     const gchar * action,
-			     const gchar * type,
-			     const gchar * morph_text,
-			     const gchar * morph)
+void main_information_viewer(const gchar *mod_name,
+			     const gchar *text,
+			     const gchar *key,
+			     const gchar *action,
+			     const gchar *type,
+			     const gchar *morph_text,
+			     const gchar *morph)
 {
 	GString *tmp_str = g_string_new(NULL);
 	GString *str;
-	MOD_FONT *mf = get_font((gchar*)mod_name);
+	MOD_FONT *mf = get_font((gchar *)mod_name);
 
 	g_string_printf(tmp_str,
 			HTML_START
@@ -183,35 +187,33 @@ void main_information_viewer(const gchar * mod_name,
 					"<font color=\"grey\">%s</font><hr/>",
 					_("Footnote"));
 			str = g_string_append(str, tmp_str->str);
-		}
-		else if (*type == 'u') {
+		} else if (*type == 'u') {
 			g_string_printf(tmp_str,
 					"<font color=\"grey\">%s:<br/>%s</font><hr/>",
 					_("User Annotation"), key);
 			str = g_string_append(str, tmp_str->str);
-		}
-		else if (*type == 'x') {
+		} else if (*type == 'x') {
 			g_string_printf(tmp_str,
 					"<font color=\"grey\">%s</font><hr/>",
 					_("Cross Reference"));
 			str = g_string_append(str, tmp_str->str);
-		}
-		else if (!strcmp(action, "showStrongs")) {
+		} else if (!strcmp(action, "showStrongs")) {
 			g_string_printf(tmp_str,
 					"<font color=\"grey\">%s: %s</font><hr/>",
 					_("Strongs"), key);
 			str = g_string_append(str, tmp_str->str);
-		}
-		else if (!strcmp(action, "showMorph")) {
+		} else if (!strcmp(action, "showMorph")) {
 			g_string_printf(tmp_str,
 					"<font color=\"grey\">%s: %s</font><hr/>",
 					_("Morphology"), key);
 			str = g_string_append(str, tmp_str->str);
 		}
 	} else {
+		const char *abbreviation = main_get_abbreviation(mod_name);
 		g_string_printf(tmp_str,
 				"<font color=\"grey\">%s: %s</font><hr/>",
-				mod_name, key);
+				(abbreviation ? abbreviation : mod_name),
+				key);
 		str = g_string_append(str, tmp_str->str);
 	}
 
@@ -233,16 +235,14 @@ void main_information_viewer(const gchar * mod_name,
 
 	str = g_string_append(str, "</font></body></html>");
 
-	HtmlOutput((char *)AnalyzeForImageSize
-			   (str->str,
-			    GDK_WINDOW(gtk_widget_get_window(previewer_html_widget))),
-			   previewer_html_widget, mf, NULL);
+	HtmlOutput((char *)AnalyzeForImageSize(str->str,
+					       GDK_WINDOW(gtk_widget_get_window(previewer_html_widget))),
+		   previewer_html_widget, mf, NULL);
 	free_font(mf);
 	g_string_free(str, TRUE);
 	g_string_free(tmp_str, TRUE);
 }
 
-
 /******************************************************************************
  * Name
  *   mark_search_words
@@ -259,7 +259,7 @@ void main_information_viewer(const gchar * mod_name,
  *   void
  */
 
-void mark_search_words(GString * str)
+void mark_search_words(GString *str)
 {
 	gchar *tmpbuf, *buf, *searchbuf;
 	gint len_overall, len_word, len_tail, len_prefix;
@@ -270,7 +270,7 @@ void mark_search_words(GString * str)
 	    (settings.searchText[0] == '\0')) {
 		return;
 	}
-	GS_message(("%s", settings.searchText));
+	XI_message(("%s", settings.searchText));
 
 	/* open and close tags */
 	sprintf(openstr,
@@ -278,13 +278,13 @@ void mark_search_words(GString * str)
 		settings.highlight_fg, settings.highlight_bg);
 	sprintf(closestr, "</span>");
 
-	searchbuf = g_utf8_casefold(g_strdup(settings.searchText),-1);
+	searchbuf = g_utf8_casefold(g_strdup(settings.searchText), -1);
 	if (g_str_has_prefix(searchbuf, "\"")) {
 		searchbuf = g_strdelimit(searchbuf, "\"", ' ');
 		g_strstrip(searchbuf);
 	}
 
-	buf = g_utf8_casefold(str->str,-1);
+	buf = g_utf8_casefold(str->str, -1);
 
 	/* if we have a muti word search go here */
 	if (settings.searchType == -2 || settings.searchType == -4) {
@@ -295,17 +295,17 @@ void mark_search_words(GString * str)
 		list = NULL;
 		/* separate the search words and add them to a glist */
 		if ((token = strtok(searchbuf, " ")) != NULL) {
-			if (!isalnum(*token) && isalnum(*(token+1)))
-				token++;	// skip leading punctuation.
+			if (!isalnum(*token) && isalnum(*(token + 1)))
+				token++; // skip leading punctuation.
 			if (!strncmp(token, "lemma:", 6))
-				token += 7;	// skip the H/G qualifier.
+				token += 7; // skip the H/G qualifier.
 			list = g_list_append(list, token);
 			++count;
 			while ((token = strtok(NULL, " ")) != NULL) {
-				if (!isalnum(*token) && isalnum(*(token+1)))
+				if (!isalnum(*token) && isalnum(*(token + 1)))
 					token++;
 				if (!strncmp(token, "lemma:", 6))
-					token += 7;	// skip the H/G qualifier.
+					token += 7; // skip the H/G qualifier.
 				list = g_list_append(list, token);
 				++count;
 			}
@@ -328,10 +328,10 @@ void mark_search_words(GString * str)
 				if ((tmpbuf != list->data) && *tmpbuf)
 					*tmpbuf = '\0';
 				else if (!sword::stricmp((gchar *)list->data, "and") ||
-					 !sword::stricmp((gchar *)list->data, "or")  ||
+					 !sword::stricmp((gchar *)list->data, "or") ||
 					 !sword::stricmp((gchar *)list->data, "not")) {
-						// don't color boolean ops.
-						goto next_word;
+					// don't color boolean ops.
+					goto next_word;
 				}
 			}
 			len_word = strlen((gchar *)list->data);
@@ -372,7 +372,7 @@ void mark_search_words(GString * str)
 		next_word:
 			g_free(buf);
 			if ((list = g_list_next(list)))
-				buf = g_utf8_casefold(str->str,-1);
+				buf = g_utf8_casefold(str->str, -1);
 		}
 		g_list_free(listbase);
 
@@ -388,13 +388,13 @@ void mark_search_words(GString * str)
 			str = g_string_insert(str, (len_prefix + len_word),
 					      closestr);
 			/* then place start tag */
-			str = g_string_insert(str, len_prefix, openstr);
+			/* don't re-assign str here, to keep cppcheck happy */
+			(void) g_string_insert(str, len_prefix, openstr);
 		}
 	}
 	g_free(searchbuf);
 }
 
-
 /******************************************************************************
  * Name
  *   main_entry_display
@@ -412,13 +412,12 @@ void mark_search_words(GString * str)
  *   void
  */
 
-void main_entry_display(gpointer data, gchar * mod_name,
-		   gchar * text, gchar * key, gboolean show_key)
+void main_entry_display(gpointer data, gchar *mod_name,
+			gchar *text, gchar *key, gboolean show_key)
 {
-	GtkWidget *html_widget = (GtkWidget *) data;
+	GtkWidget *html_widget = (GtkWidget *)data;
 	GString *tmp_str = g_string_new(NULL);
 	GString *str;
-	GString *search_str;
 	MOD_FONT *mf = get_font(mod_name);
 
 	g_string_printf(tmp_str,
@@ -436,6 +435,7 @@ void main_entry_display(gpointer data, gchar * mod_name,
 
 	/* show key in html widget  */
 	if (show_key) {
+		const char *abbreviation = main_get_abbreviation(mod_name);
 		if ((settings.displaySearchResults)) {
 			g_string_printf(tmp_str,
 					"<a href=\"sword://%s/%s\">"
@@ -443,7 +443,8 @@ void main_entry_display(gpointer data, gchar * mod_name,
 					mod_name,
 					key,
 					settings.link_color,
-					mod_name, key);
+					(abbreviation ? abbreviation : mod_name),
+					key);
 		} else {
 			g_string_printf(tmp_str,
 					"<a href=\"passagestudy.jsp?action=showModInfo&value=%s&module=%s\">"
@@ -451,13 +452,14 @@ void main_entry_display(gpointer data, gchar * mod_name,
 					backend->module_description(mod_name),
 					mod_name,
 					settings.link_color,
-					mod_name, key);
+					(abbreviation ? abbreviation : mod_name),
+					key);
 		}
 		str = g_string_append(str, tmp_str->str);
 	}
 
 	if (settings.displaySearchResults) {
-		search_str = g_string_new(text);
+		GString *search_str = g_string_new(text);
 		mark_search_words(search_str);
 		str = g_string_append(str, search_str->str);
 		g_string_free(search_str, TRUE);
@@ -468,10 +470,9 @@ void main_entry_display(gpointer data, gchar * mod_name,
 	g_string_printf(tmp_str, " %s", "</font></body></html>");
 	str = g_string_append(str, tmp_str->str);
 
-	HtmlOutput((char *)AnalyzeForImageSize
-			   (str->str,
-			    GDK_WINDOW(gtk_widget_get_window(html_widget))),
-			    html_widget, mf, NULL);
+	HtmlOutput((char *)AnalyzeForImageSize(str->str,
+					       GDK_WINDOW(gtk_widget_get_window(html_widget))),
+		   html_widget, mf, NULL);
 	free_font(mf);
 	g_string_free(str, TRUE);
 	g_string_free(tmp_str, TRUE);
