@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * previewer.h -
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,23 +23,23 @@
 #define _PREVIEWER_H
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 void main_init_previewer(void);
 void main_set_previewer_widget(int in_sidebar);
 GtkWidget *main_get_previewer_widget(void);
 void main_clear_viewer(void);
-void main_information_viewer(const char * mod_name, const char * text, const char * key,
-		             const char * action, const char * type, const char * morph_text,
-			     const char * morph);
-void mark_search_words(GString * str);
-void main_entry_display(gpointer data, char * mod_name,
-		   char * text, char * key, gboolean show_key);
+void main_information_viewer(const char *mod_name,
+			     const char *text, const char *key,
+			     const char *action, const char *type,
+			     const char *morph_text,
+			     const char *morph);
+void mark_search_words(GString *str);
+void main_entry_display(gpointer data, char *mod_name,
+			char *text, char *key, gboolean show_key);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _PREVIEWER_H */
