@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_sidebar.h - glue
  *
- * Copyright (C) 2004-2014 Xiphos Developer Team
+ * Copyright (C) 2004-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,8 @@
 extern "C" {
 #endif
 
-void main_sidebar_search_percent_update(char percent, void *userData);
+void main_sidebar_search_percent_update(char percent,
+					void *userData);
 void main_do_sidebar_search(gpointer user_data);
 void main_sidebar_perscomm_dump(void);
 void main_init_sidebar_search_backend(void);
@@ -36,5 +37,4 @@ void main_search_sidebar_fill_bounds_combos(void);
 #ifdef __cplusplus
 }
 #endif
-
 #endif
