@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * settings.c - Guess what?
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -54,7 +53,6 @@
 #include "gui/debug_glib_null.h"
 #include <locale.h>
 
-
 /******************************************************************************
  * defines
  */
@@ -88,7 +86,8 @@ static int init_bookmarks(int new_bookmarks);
  *   gint
  */
 
-int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
+int settings_init(int argc, char **argv, int new_configs,
+		  int new_bookmarks)
 {
 	int retval = 0;
 	char *sword_dir = NULL;
@@ -102,7 +101,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	strcpy(settings.program_title, "Xiphos");
 
 	/* Get home dir */
-	if ((settings.homedir = (char*) g_getenv(HOMEVAR)) == NULL) {
+	if ((settings.homedir = (char *)g_getenv(HOMEVAR)) == NULL) {
 		gui_init(argc, argv);
 		gui_generic_warning_modal(_("$HOME is not set!"));
 		/* if not found in env exit */
@@ -110,15 +109,15 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	}
 
 	/* set gSwordDir to $home + .xiphos */
-	settings.gSwordDir = g_build_filename(settings.homedir, XI_DIR, NULL);
+	settings.gSwordDir =
+	    g_build_filename(settings.homedir, XI_DIR, NULL);
 
 	/* if gSwordDir does not exist, create it. */
 	if (g_access(settings.gSwordDir, F_OK) == -1) {
 		if ((Mkdir(settings.gSwordDir, S_IRWXU)) != 0) {
 			char msg[300];
 			gui_init(argc, argv);
-			sprintf(msg, _("Xiphos can not create directory "
-				       XI_DIR
+			sprintf(msg, _("Xiphos can not create directory " XI_DIR
 				       ":\n%s\n\nXiphos cannot continue."),
 				strerror(errno));
 			gui_generic_warning_modal(msg);
@@ -137,7 +136,8 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	}
 	g_free(sword_dir);
 	/* if .sword/mods.d does not exist create it */
-	sword_dir = g_strdup_printf("%s/%s", settings.homedir, DOTSWORD "/mods.d");
+	sword_dir =
+	    g_strdup_printf("%s/%s", settings.homedir, DOTSWORD "/mods.d");
 	if (g_access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
 			gui_init(argc, argv);
@@ -146,7 +146,9 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	}
 	g_free(sword_dir);
 	/* if .sword/modules does not exist create it */
-	sword_dir = g_strdup_printf("%s/%s", settings.homedir, DOTSWORD "/modules");
+	sword_dir =
+	    g_strdup_printf("%s/%s", settings.homedir,
+			    DOTSWORD "/modules");
 	if (g_access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
 			gui_init(argc, argv);
@@ -167,12 +169,14 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	main_init_lists();
 
 	/* set fnconfigure to gSwordDir and settings.xml */
-	settings.fnconfigure = g_strdup_printf("%s/settings.xml", settings.gSwordDir);
+	settings.fnconfigure =
+	    g_strdup_printf("%s/settings.xml", settings.gSwordDir);
 
 	/* check for a bad settings file. */
-	if ((stat(settings.fnconfigure, &buf) == 0) &&	/* exists... */
-	    (buf.st_size == 0)) {			/* ...but empty? */
-		char *backup_name = g_strdup_printf("%s.SAVE", settings.fnconfigure);
+	if ((stat(settings.fnconfigure, &buf) == 0) && /* exists... */
+	    (buf.st_size == 0)) {		       /* ...but empty? */
+		char *backup_name =
+		    g_strdup_printf("%s.SAVE", settings.fnconfigure);
 
 		/* toss out the bad one and look for recovery. */
 		unlink(settings.fnconfigure);
@@ -180,26 +184,21 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 			buf_says_empty = (buf.st_size == 0);
 			rename(backup_name, settings.fnconfigure);
 			gui_init(argc, argv);
-			gui_generic_warning_modal
-			    (_("Empty settings file -- backup recovery attempted.\n"
-			       "Some information may have been lost."));
-		}
-		else
-		{
-		    gui_generic_warning_modal
-			(_("Empty settings file -- no backup?!? Information lost!"));
+			gui_generic_warning_modal(_("Empty settings file -- backup recovery attempted.\n"
+						    "Some information may have been lost."));
+		} else {
+			gui_generic_warning_modal(_("Empty settings file -- no backup?!? Information lost!"));
 		}
 		g_free(backup_name);
 	}
 
 	/* if settings.xml does not exist create it */
 	if (buf_says_empty ||
-	    (g_access(settings.fnconfigure, F_OK) == -1) ||
-	    new_configs) {
+	    (g_access(settings.fnconfigure, F_OK) == -1) || new_configs) {
 		/* must be first run */
 		XI_print((buf_says_empty
-			  ? "\nSETTINGS FILE EXISTS BUT IS EMPTY - RECREATING.\n"
-			  : "\nFirst Run: need to create settings!\n"));
+			      ? "\nSETTINGS FILE EXISTS BUT IS EMPTY - RECREATING.\n"
+			      : "\nFirst Run: need to create settings!\n"));
 		settings.first_run = TRUE;
 
 		xml_create_settings_file(settings.fnconfigure);
@@ -215,11 +214,10 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 		gui_open_mod_mgr_initial_run();
 		main_init_lists();
 		if (settings.havebible == 0) {
-			gui_generic_warning_modal
-			    (_("There are no Bibles installed.\n"
-			       "Evidently, you declined to install any.\n\n"
-			       "Without any Bible modules to display,\n"
-			       "Xiphos cannot proceed,\nand will now exit."));
+			gui_generic_warning_modal(_("There are no Bibles installed.\n"
+						    "Evidently, you declined to install any.\n\n"
+						    "Without any Bible modules to display,\n"
+						    "Xiphos cannot proceed,\nand will now exit."));
 			exit(1);
 		}
 		gui_generic_warning_modal(_("Bible module installation complete."));
@@ -231,10 +229,10 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 		g_file_set_contents(tmp, " ", 1, NULL);
 	}
 	g_free(tmp);
-	
+
 	/* check for studypad.spt template file for studypad */
-	tmp = g_strdup_printf("%s/%s", settings.gSwordDir, "studypad.spt");
-	if ((g_access(tmp, F_OK) == -1)) {
+	tmp = g_build_filename(settings.gSwordDir, "studypad.spt", NULL);
+	if (g_access(tmp, F_OK) == -1) {
 		g_file_set_contents(tmp, studypad_template, -1, NULL);
 	}
 	g_free(tmp);
@@ -242,15 +240,15 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	load_settings_structure();
 
 	/* BibleSync */
-	settings.bs_mode       = 0;
-	settings.bs_privacy    = FALSE;
-	settings.bs_navdirect  = TRUE;
-	settings.bs_debug      = FALSE;
-	settings.bs_presence   = FALSE;
-	settings.bs_mismatch   = FALSE;
-	settings.bs_group_tab  = TRUE;
-	settings.bs_receiving  = FALSE;
-	settings.bs_listen_set = 0;	// selective
+	settings.bs_mode = 0;
+	settings.bs_privacy = FALSE;
+	settings.bs_navdirect = TRUE;
+	settings.bs_debug = FALSE;
+	settings.bs_presence = FALSE;
+	settings.bs_mismatch = FALSE;
+	settings.bs_group_tab = TRUE;
+	settings.bs_receiving = FALSE;
+	settings.bs_listen_set = 0; // selective
 	settings.bs_passphrase = g_strdup("BibleSync");
 
 	/* if the user had forced a locale, we must set it now. */
@@ -264,22 +262,22 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 		}
 		if (test != NULL) {
 			g_setenv("LC_ALL", test, TRUE);
-			XI_message(("set locale to %s", settings.special_locale));
+			XI_message(("set locale to %s",
+				    settings.special_locale));
 		}
 	}
 
 	/* find out what kind of peculiar language environment we have */
 	re_encode_digits = FALSE;
-	if (((env = (char*) g_getenv("LANG")) != NULL) &&
+	if (((env = (char *)g_getenv("LANG")) != NULL) &&
 	    // for now, farsi-sensitive only
-	    (strncmp (env, "fa", 2) == 0)) {
+	    (strncmp(env, "fa", 2) == 0)) {
 		re_encode_digits = TRUE;
 	}
 
 	return retval;
 }
 
-
 /******************************************************************************
  * Name
  *
@@ -304,7 +302,8 @@ int init_bookmarks(int new_bookmarks)
 	settings.load_xml_bookmarks = FALSE;
 
 	/* set bookmarks dir to settings.gSwordDir + /bookmarks */
-	settings.swbmDir = g_strdup_printf("%s/%s", settings.gSwordDir, "bookmarks");
+	settings.swbmDir =
+	    g_strdup_printf("%s/%s", settings.gSwordDir, "bookmarks");
 
 	/* if .xiphos/bookmarks does not exist create it */
 	if (g_access(settings.swbmDir, F_OK) == -1) {
@@ -333,7 +332,6 @@ int init_bookmarks(int new_bookmarks)
 	return 1;
 }
 
-
 /******************************************************************************
  * Name
  *
@@ -355,9 +353,11 @@ void load_settings_structure(void)
 	char *buf = NULL, *parallels;
 
 	settings.gs_version = VERSION;
-	if ((settings.MainWindowModule = xml_get_value("modules", "bible")) == NULL) {
+	if ((settings.MainWindowModule =
+		 xml_get_value("modules", "bible")) == NULL) {
 		/* by the time we are here, we *must* have at least 1 bible */
-		settings.MainWindowModule = g_strdup(get_list(TEXT_LIST)->data);
+		settings.MainWindowModule =
+		    g_strdup(get_list(TEXT_LIST)->data);
 	}
 	settings.CommWindowModule = xml_get_value("modules", "comm");
 	settings.DictWindowModule = xml_get_value("modules", "dict");
@@ -365,16 +365,17 @@ void load_settings_structure(void)
 	parallels = xml_get_value("modules", "parallels");
 	/* if no parallels are known, convert old fixed parallel set */
 	if (!parallels || (*parallels == '\0')) {
-		char intN[] = "intN", *oldparallel, i, *newhold;
+		char intN[] = "intN", i, *newhold;
 
-		g_free(parallels);	/* in case it was real but empty */
+		g_free(parallels); /* in case it was real but empty */
 		parallels = g_strdup("");
-		for (i = '1'; i <= '5'; ++i) {	/* the old set */
+		for (i = '1'; i <= '5'; ++i) { /* the old set */
 			intN[3] = i;
-			oldparallel = xml_get_value("modules", intN);
+			char *oldparallel = xml_get_value("modules", intN);
 			if (oldparallel && *oldparallel) {
-				newhold = g_strconcat(parallels, oldparallel,
-						      ",", NULL);
+				newhold =
+				    g_strconcat(parallels, oldparallel,
+						",", NULL);
 				g_free(parallels);
 				parallels = newhold;
 				g_free(oldparallel);
@@ -385,7 +386,8 @@ void load_settings_structure(void)
 		/* trim off the last comma */
 		if (*parallels) {
 			*(parallels + strlen(parallels) - 1) = '\0';
-			xml_set_new_element("modules", "parallels", parallels);
+			xml_set_new_element("modules", "parallels",
+					    parallels);
 		}
 	}
 	if (parallels && *parallels)
@@ -412,14 +414,17 @@ void load_settings_structure(void)
 			      settings.lex_hebrew);
 	}
 
-	settings.DefaultDict = xml_get_value("lexicons", "defaultdictionary");
+	settings.DefaultDict =
+	    xml_get_value("lexicons", "defaultdictionary");
 	if (!settings.DefaultDict) {
 		settings.DefaultDict = g_strdup("WebstersDict");
 		xml_set_value("Xiphos", "lexicons", "defaultdictionary",
 			      settings.DefaultDict);
 	}
-	settings.useDefaultDict = atoi((buf = xml_get_value("lexicons","usedefaultdict"))
-				       ? buf : "0");
+	settings.useDefaultDict =
+	    atoi((buf = xml_get_value("lexicons", "usedefaultdict"))
+		     ? buf
+		     : "0");
 
 	/* unusual locale setting */
 	if ((buf = xml_get_value("locale", "special")))
@@ -435,25 +440,31 @@ void load_settings_structure(void)
 		settings.mod_mgr_source = atoi(buf);
 	else {
 		xml_add_new_section_to_settings_doc("modmgr");
-		xml_add_new_item_to_section("modmgr", "mod_mgr_source", "1");
+		xml_add_new_item_to_section("modmgr", "mod_mgr_source",
+					    "1");
 		settings.mod_mgr_source = 1;
 	}
 	if ((buf = xml_get_value("modmgr", "mod_mgr_destination")))
 		settings.mod_mgr_destination = atoi(buf);
 	else {
-		xml_add_new_item_to_section("modmgr", "mod_mgr_destination", "0");
+		xml_add_new_item_to_section("modmgr",
+					    "mod_mgr_destination", "0");
 		settings.mod_mgr_destination = 0;
 	}
 	if ((buf = xml_get_value("modmgr", "mod_mgr_local_source_index")))
 		settings.mod_mgr_local_source_index = atoi(buf);
 	else {
-		xml_add_new_item_to_section("modmgr", "mod_mgr_local_source_index", "0");
+		xml_add_new_item_to_section("modmgr",
+					    "mod_mgr_local_source_index",
+					    "0");
 		settings.mod_mgr_local_source_index = 0;
 	}
 	if ((buf = xml_get_value("modmgr", "mod_mgr_remote_source_index")))
 		settings.mod_mgr_remote_source_index = atoi(buf);
 	else {
-		xml_add_new_item_to_section("modmgr", "mod_mgr_remote_source_index", "0");
+		xml_add_new_item_to_section("modmgr",
+					    "mod_mgr_remote_source_index",
+					    "0");
 		settings.mod_mgr_remote_source_index = 0;
 	}
 
@@ -468,7 +479,8 @@ void load_settings_structure(void)
 		settings.book_key = xml_get_value("keys", "book");
 	}
 	if (xml_get_value("keys", "offset"))
-		settings.book_offset = atol(xml_get_value("keys", "offset"));
+		settings.book_offset =
+		    atol(xml_get_value("keys", "offset"));
 	else {
 		xml_add_new_item_to_section("keys", "offset", "");
 		settings.book_offset = 0;
@@ -482,12 +494,15 @@ void load_settings_structure(void)
 	}
 
 	/* layout */
-	settings.sidebar_width = atoi((buf = xml_get_value("layout", "shortcutbar"))
-				      ? buf : "100");
+	settings.sidebar_width =
+	    atoi((buf = xml_get_value("layout", "shortcutbar"))
+		     ? buf
+		     : "100");
 	if ((buf = xml_get_value("layout", "vltoppaneheight")))
 		settings.verselist_toppane_height = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "vltoppaneheight", "210");
+		xml_add_new_item_to_section("layout", "vltoppaneheight",
+					    "210");
 		settings.verselist_toppane_height = 210;
 	}
 	if ((buf = xml_get_value("layout", "sidebar_notebook_height")))
@@ -495,11 +510,16 @@ void load_settings_structure(void)
 	else {
 		if ((buf = xml_get_value("layout", "sidebar_notebook_hight"))) { /* backward compatible */
 			settings.sidebar_notebook_height = atoi(buf);
-			xml_remove_node("layout", "sidebar_notebook_hight", 0);
+			xml_remove_node("layout", "sidebar_notebook_hight",
+					0);
 		} else
 			settings.sidebar_notebook_height = 250;
-		buf = g_strdup_printf("%d", settings.sidebar_notebook_height);
-		xml_add_new_item_to_section("layout", "sidebar_notebook_height", buf);
+		buf =
+		    g_strdup_printf("%d",
+				    settings.sidebar_notebook_height);
+		xml_add_new_item_to_section("layout",
+					    "sidebar_notebook_height",
+					    buf);
 		g_free(buf);
 	}
 
@@ -521,7 +541,8 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("layout", "advsearchopen")))
 		settings.display_advsearch = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "advsearchopen", "0");
+		xml_add_new_item_to_section("layout", "advsearchopen",
+					    "0");
 		settings.display_advsearch = 0;
 	}
 
@@ -536,7 +557,7 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("layout", "height")))
 		settings.gs_height = atoi(buf);
 	else {
-		if ((buf = xml_get_value("layout", "hight"))) {	/* backward compatible */
+		if ((buf = xml_get_value("layout", "hight"))) { /* backward compatible */
 			settings.gs_height = atoi(buf);
 			xml_remove_node("layout", "hight", 0);
 		} else
@@ -547,7 +568,7 @@ void load_settings_structure(void)
 	}
 	if ((buf = xml_get_value("layout", "width")))
 		settings.gs_width = atoi(buf);
-	else{
+	else {
 		xml_add_new_item_to_section("layout", "width", "500");
 		settings.gs_width = 500;
 	}
@@ -558,56 +579,70 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("layout", "parallel_height")))
 		settings.parallel_height = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "parallel_height", "361");
+		xml_add_new_item_to_section("layout", "parallel_height",
+					    "361");
 		settings.parallel_height = 361;
 	}
 	if ((buf = xml_get_value("layout", "parallel_width")))
 		settings.parallel_width = atoi(buf);
-	else{
-		xml_add_new_item_to_section("layout", "parallel_width", "657");
+	else {
+		xml_add_new_item_to_section("layout", "parallel_width",
+					    "657");
 		settings.parallel_width = 657;
 	}
 
 	if ((buf = xml_get_value("layout", "modmgr_height")))
 		settings.modmgr_height = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "modmgr_height", "450");
+		xml_add_new_item_to_section("layout", "modmgr_height",
+					    "450");
 		settings.modmgr_height = 450;
 	}
 	if ((buf = xml_get_value("layout", "modmgr_width")))
 		settings.modmgr_width = atoi(buf);
-	else{
-		xml_add_new_item_to_section("layout", "modmgr_width", "710");
+	else {
+		xml_add_new_item_to_section("layout", "modmgr_width",
+					    "710");
 		settings.modmgr_width = 710;
 	}
 
 	if ((buf = xml_get_value("layout", "advsearch_height")))
 		settings.advsearch_height = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "advsearch_height", "465");
+		xml_add_new_item_to_section("layout", "advsearch_height",
+					    "465");
 		settings.advsearch_height = 465;
 	}
 	if ((buf = xml_get_value("layout", "advsearch_width")))
 		settings.advsearch_width = atoi(buf);
-	else{
-		xml_add_new_item_to_section("layout", "advsearch_width", "665");
+	else {
+		xml_add_new_item_to_section("layout", "advsearch_width",
+					    "665");
 		settings.advsearch_width = 665;
 	}
 
 	if ((buf = xml_get_value("layout", "prefs_height")))
 		settings.prefs_height = atoi(buf);
 	else {
-		xml_add_new_item_to_section("layout", "prefs_height", "300");
+		xml_add_new_item_to_section("layout", "prefs_height",
+					    "300");
 		settings.prefs_height = 300;
 	}
 	if ((buf = xml_get_value("layout", "prefs_width")))
 		settings.prefs_width = atoi(buf);
-	else{
-		xml_add_new_item_to_section("layout", "prefs_width", "590");
+	else {
+		xml_add_new_item_to_section("layout", "prefs_width",
+					    "590");
 		settings.prefs_width = 590;
 	}
 
 	/* main window placement */
+	if ((buf = xml_get_value("layout", "maximized")))
+		settings.app_x = atoi(buf);
+	else {
+		xml_add_new_item_to_section("layout", "maximized", "0");
+		settings.maximized = 0;
+	}
 	if ((buf = xml_get_value("layout", "app_x")))
 		settings.app_x = atoi(buf);
 	else {
@@ -616,7 +651,7 @@ void load_settings_structure(void)
 	}
 	if ((buf = xml_get_value("layout", "app_y")))
 		settings.app_y = atoi(buf);
-	else{
+	else {
 		xml_add_new_item_to_section("layout", "app_y", "40");
 		settings.app_y = 40;
 	}
@@ -630,7 +665,7 @@ void load_settings_structure(void)
 	}
 	if ((buf = xml_get_value("layout", "parallel_y")))
 		settings.parallel_y = atoi(buf);
-	else{
+	else {
 		xml_add_new_item_to_section("layout", "parallel_y", "40");
 		settings.parallel_y = 40;
 	}
@@ -643,7 +678,7 @@ void load_settings_structure(void)
 	}
 	if ((buf = xml_get_value("layout", "modmgr_y")))
 		settings.modmgr_y = atoi(buf);
-	else{
+	else {
 		xml_add_new_item_to_section("layout", "modmgr_y", "40");
 		settings.modmgr_y = 40;
 	}
@@ -656,7 +691,7 @@ void load_settings_structure(void)
 	}
 	if ((buf = xml_get_value("layout", "advsearch_y")))
 		settings.advsearch_y = atoi(buf);
-	else{
+	else {
 		xml_add_new_item_to_section("layout", "advsearch_y", "40");
 		settings.advsearch_y = 40;
 	}
@@ -669,19 +704,21 @@ void load_settings_structure(void)
 	}
 	if ((buf = xml_get_value("layout", "prefs_y")))
 		settings.prefs_y = atoi(buf);
-	else{
+	else {
 		xml_add_new_item_to_section("layout", "prefs_y", "40");
 		settings.prefs_y = 40;
 	}
 
 	/* random geometry stuff */
-	settings.biblepane_width = atoi((buf = xml_get_value("layout", "textpane"))
-					? buf : "0");
+	settings.biblepane_width =
+	    atoi((buf = xml_get_value("layout", "textpane"))
+		     ? buf
+		     : "0");
 
 	if ((buf = xml_get_value("layout", "bibleheight")))
 		settings.biblepane_height = atoi(buf);
 	else {
-		if ((buf = xml_get_value("layout", "biblehight"))) {	/* backward compatible */
+		if ((buf = xml_get_value("layout", "biblehight"))) { /* backward compatible */
 			settings.biblepane_height = atoi(buf);
 			xml_remove_node("layout", "biblehight", 0);
 		} else
@@ -700,7 +737,8 @@ void load_settings_structure(void)
 		} else
 			settings.commpane_height = 240;
 		buf = g_strdup_printf("%d", settings.commpane_height);
-		xml_add_new_item_to_section("layout", "commentaryheight", buf);
+		xml_add_new_item_to_section("layout", "commentaryheight",
+					    buf);
 		g_free(buf);
 	}
 
@@ -715,14 +753,17 @@ void load_settings_structure(void)
 
 	if ((buf = xml_get_value("fontsize", "basefontsize"))) {
 		settings.base_font_size_str = buf;
-		settings.base_font_size = atoi(settings.base_font_size_str);
+		settings.base_font_size =
+		    atoi(settings.base_font_size_str);
 	} else {
 #ifndef WIN32
-		xml_add_new_item_to_section("fontsize", "basefontsize", "+0");
+		xml_add_new_item_to_section("fontsize", "basefontsize",
+					    "+0");
 		settings.base_font_size_str = g_strdup("+0");
 		settings.base_font_size = 0;
 #else
-		xml_add_new_item_to_section("fontsize", "basefontsize", "+1");
+		xml_add_new_item_to_section("fontsize", "basefontsize",
+					    "+1");
 		settings.base_font_size_str = g_strdup("+1");
 		settings.base_font_size = 1;
 #endif /* WIN32 */
@@ -742,13 +783,15 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("HTMLcolors", "highlight_fg")))
 		settings.highlight_fg = g_strdup(buf);
 	else {
-		xml_add_new_item_to_section("HTMLcolors", "highlight_fg", "#FFFF00");
+		xml_add_new_item_to_section("HTMLcolors", "highlight_fg",
+					    "#FFFF00");
 		settings.highlight_fg = g_strdup("#FFFF00");
 	}
 	if ((buf = xml_get_value("HTMLcolors", "highlight_bg")))
 		settings.highlight_bg = g_strdup(buf);
 	else {
-		xml_add_new_item_to_section("HTMLcolors", "highlight_bg", "#060680");
+		xml_add_new_item_to_section("HTMLcolors", "highlight_bg",
+					    "#060680");
 		settings.highlight_bg = g_strdup("#060680");
 	}
 
@@ -756,28 +799,32 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("parallel", "Strong_s_Numbers")))
 		settings.parallel_strongs = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Strong_s_Numbers", "0");
+		xml_add_new_item_to_section("parallel", "Strong_s_Numbers",
+					    "0");
 		settings.parallel_strongs = 0;
 	}
 
 	if ((buf = xml_get_value("parallel", "Morphological_Tags")))
 		settings.parallel_morphs = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Morphological_Tags", "0");
+		xml_add_new_item_to_section("parallel",
+					    "Morphological_Tags", "0");
 		settings.parallel_morphs = 0;
 	}
 
 	if ((buf = xml_get_value("parallel", "Hebrew_Vowel_Points")))
 		settings.parallel_hebrewpoints = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Hebrew_Vowel_Points", "1");
+		xml_add_new_item_to_section("parallel",
+					    "Hebrew_Vowel_Points", "1");
 		settings.parallel_hebrewpoints = 1;
 	}
 
 	if ((buf = xml_get_value("parallel", "Hebrew_Cantillation")))
 		settings.parallel_cantillationmarks = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Hebrew_Cantillation", "0");
+		xml_add_new_item_to_section("parallel",
+					    "Hebrew_Cantillation", "0");
 		settings.parallel_cantillationmarks = 0;
 	}
 
@@ -791,28 +838,32 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("parallel", "Cross-references")))
 		settings.parallel_crossref = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Cross-references", "1");
+		xml_add_new_item_to_section("parallel", "Cross-references",
+					    "1");
 		settings.parallel_crossref = 1;
 	}
 
 	if ((buf = xml_get_value("parallel", "Transliteration")))
 		settings.parallel_transliteration = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Transliteration", "0");
+		xml_add_new_item_to_section("parallel", "Transliteration",
+					    "0");
 		settings.parallel_transliteration = 0;
 	}
 
 	if ((buf = xml_get_value("parallel", "Words_of_Christ_in_Red")))
 		settings.parallel_red_words = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Words_of_Christ_in_Red", "1");
+		xml_add_new_item_to_section("parallel",
+					    "Words_of_Christ_in_Red", "1");
 		settings.parallel_red_words = 1;
 	}
 
 	if ((buf = xml_get_value("parallel", "Morpheme_Segmentation")))
 		settings.parallel_segmentation = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Morpheme_Segmentation", "0");
+		xml_add_new_item_to_section("parallel",
+					    "Morpheme_Segmentation", "0");
 		settings.parallel_segmentation = 0;
 	}
 
@@ -833,75 +884,107 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("parallel", "Primary_Reading")))
 		settings.parallel_variants_primary = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Primary_Reading", "1");
+		xml_add_new_item_to_section("parallel", "Primary_Reading",
+					    "1");
 		settings.parallel_variants_primary = 1;
 	}
 
 	if ((buf = xml_get_value("parallel", "Secondary_Reading")))
 		settings.parallel_variants_secondary = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Secondary_Reading", "0");
+		xml_add_new_item_to_section("parallel",
+					    "Secondary_Reading", "0");
 		settings.parallel_variants_secondary = 0;
 	}
 
 	if ((buf = xml_get_value("parallel", "All_Readings")))
 		settings.parallel_variants_all = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "All_Readings", "0");
+		xml_add_new_item_to_section("parallel", "All_Readings",
+					    "0");
 		settings.parallel_variants_all = 0;
 	}
 
 	if ((buf = xml_get_value("parallel", "Greek_Accents")))
 		settings.parallel_greekaccents = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Greek_Accents", "1");
+		xml_add_new_item_to_section("parallel", "Greek_Accents",
+					    "1");
 		settings.parallel_greekaccents = 1;
 	}
 
 	if ((buf = xml_get_value("parallel", "Transliterated_Forms")))
 		settings.parallel_xlit = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Transliterated_Forms", "0");
+		xml_add_new_item_to_section("parallel",
+					    "Transliterated_Forms", "0");
 		settings.parallel_xlit = 0;
 	}
 
 	if ((buf = xml_get_value("parallel", "Enumerations")))
 		settings.parallel_enumerated = atoi(buf);
 	else {
-		xml_add_new_item_to_section("parallel", "Enumerations", "0");
+		xml_add_new_item_to_section("parallel", "Enumerations",
+					    "0");
 		settings.parallel_enumerated = 0;
 	}
 
+	if ((buf = xml_get_value("parallel", "Glosses")))
+		settings.parallel_glosses = atoi(buf);
+	else {
+		xml_add_new_item_to_section("parallel", "Glosses", "0");
+		settings.parallel_glosses = 0;
+	}
+
+	if ((buf = xml_get_value("parallel", "Morpheme_Segmentation")))
+		settings.parallel_morphseg = atoi(buf);
+	else {
+		xml_add_new_item_to_section("parallel",
+					    "Morpheme_Segmentation", "0");
+		settings.parallel_morphseg = 0;
+	}
+
 	/*  Misc stuff  */
 
-	settings.showtexts = atoi((buf = xml_get_value("misc", "showtexts")) ? buf : "1");
-	settings.showcomms = atoi((buf = xml_get_value("misc", "showcomms")) ? buf : "1");
-	settings.showdicts = atoi((buf = xml_get_value("misc", "showdicts")) ? buf : "1");
+	settings.showtexts =
+	    atoi((buf = xml_get_value("misc", "showtexts")) ? buf : "1");
+	settings.showcomms =
+	    atoi((buf = xml_get_value("misc", "showcomms")) ? buf : "1");
+	settings.showdicts =
+	    atoi((buf = xml_get_value("misc", "showdicts")) ? buf : "1");
 	if (xml_get_value("misc", "showpreview"))
-		settings.showpreview = atol(xml_get_value("misc", "showpreview"));
+		settings.showpreview =
+		    atol(xml_get_value("misc", "showpreview"));
 	else {
 		xml_add_new_item_to_section("misc", "showpreview", "1");
 		settings.showpreview = 1;
 	}
 
 	if (xml_get_value("misc", "show_side_preview"))
-		settings.show_previewer_in_sidebar = atol(xml_get_value("misc", "show_side_preview"));
+		settings.show_previewer_in_sidebar =
+		    atol(xml_get_value("misc", "show_side_preview"));
 	else {
-		xml_add_new_item_to_section("misc", "show_side_preview", "1");
+		xml_add_new_item_to_section("misc", "show_side_preview",
+					    "1");
 		settings.show_previewer_in_sidebar = 1;
 	}
 
 	if (xml_get_value("misc", "showparatab"))
-		settings.showparatab = atol(xml_get_value("misc", "showparatab"));
+		settings.showparatab =
+		    atol(xml_get_value("misc", "showparatab"));
 	else {
 		xml_add_new_item_to_section("misc", "showparatab", "0");
 		settings.showparatab = 0;
 	}
 
-	settings.showsplash = atoi((buf = xml_get_value("misc", "splash")) ? buf : "1");
+	settings.showsplash =
+	    atoi((buf = xml_get_value("misc", "splash")) ? buf : "1");
 
 	settings.showdevotional =
-	    atoi((buf = xml_get_value("misc", "dailydevotional")) ? buf : "1");
+	    atoi((buf =
+		      xml_get_value("misc", "dailydevotional"))
+		     ? buf
+		     : "1");
 	settings.versestyle =
 	    atoi((buf = xml_get_value("misc", "versestyle")) ? buf : "1");
 
@@ -936,14 +1019,16 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("misc", "verse_num_bracket")))
 		settings.verse_num_bracket = atoi(buf);
 	else {
-		xml_add_new_item_to_section("misc", "verse_num_bracket", "0");
+		xml_add_new_item_to_section("misc", "verse_num_bracket",
+					    "0");
 		settings.verse_num_bracket = 0;
 	}
 
 	if ((buf = xml_get_value("misc", "verse_num_superscript")))
 		settings.verse_num_superscript = atoi(buf);
 	else {
-		xml_add_new_item_to_section("misc", "verse_num_superscript", "0");
+		xml_add_new_item_to_section("misc",
+					    "verse_num_superscript", "0");
 		settings.verse_num_superscript = 0;
 	}
 
@@ -957,28 +1042,30 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("misc", "annotatehighlight")))
 		settings.annotate_highlight = atoi(buf);
 	else {
-		xml_add_new_item_to_section("misc", "annotatehighlight", "1");
+		xml_add_new_item_to_section("misc", "annotatehighlight",
+					    "1");
 		settings.annotate_highlight = 1;
 	}
 
 	if ((buf = xml_get_value("misc", "xrefsinverselist")))
 		settings.xrefs_in_verse_list = atoi(buf);
 	else {
-		xml_add_new_item_to_section("misc", "xrefsinverselist", "1");
+		xml_add_new_item_to_section("misc", "xrefsinverselist",
+					    "1");
 		settings.xrefs_in_verse_list = 1;
 	}
 
 	if ((buf = xml_get_value("misc", "chapter-scroll"))) {
 		settings.chapter_scroll = atoi(buf);
 	} else {
-		xml_add_new_item_to_section("misc","chapter-scroll","0");
+		xml_add_new_item_to_section("misc", "chapter-scroll", "0");
 		settings.chapter_scroll = 0;
 	}
 
 	if ((buf = xml_get_value("misc", "imageresize"))) {
 		settings.imageresize = atoi(buf);
 	} else {
-		xml_add_new_item_to_section("misc","imageresize","1");
+		xml_add_new_item_to_section("misc", "imageresize", "1");
 		settings.imageresize = 1;
 	}
 #ifdef WIN32
@@ -989,41 +1076,48 @@ void load_settings_structure(void)
 	if ((buf = xml_get_value("editor", "spell_language")))
 		settings.spell_language = g_strdup(buf);
 	else {
-		xml_add_new_item_to_section("editor","spell_language","unknown");
+		xml_add_new_item_to_section("editor", "spell_language",
+					    "unknown");
 		settings.spell_language = "unknown";
 	}
 
-	settings.studypadfilename =
-	    xml_get_value("studypad", "lastfile");
+	settings.studypadfilename = xml_get_value("studypad", "lastfile");
 	settings.studypaddir = xml_get_value("studypad", "directory");
 
 	if ((buf = xml_get_value("misc", "show_sidebar"))) {
 		settings.showshortcutbar = atoi(buf);
 	} else {
-		xml_add_new_item_to_section("misc","show_sidebar","1");
+		xml_add_new_item_to_section("misc", "show_sidebar", "1");
 		settings.showshortcutbar = 1;
 	}
 	if ((buf = xml_get_value("misc", "sidebar_docked"))) {
 		settings.docked = atoi(buf);
 	} else {
-		xml_add_new_item_to_section("misc","sidebar_docked","1");
+		xml_add_new_item_to_section("misc", "sidebar_docked", "1");
 		settings.docked = 1;
 	}
 
 	if ((buf = xml_get_value("misc", "prayerlist"))) {
-		settings.prayerlist =  atoi(buf);
+		settings.prayerlist = atoi(buf);
 	} else {
-		xml_add_new_item_to_section("misc","prayerlist","1");
+		xml_add_new_item_to_section("misc", "prayerlist", "1");
 		settings.prayerlist = 1;
 	}
 
+	if ((buf = xml_get_value("misc", "statusbar"))) {
+		settings.statusbar = atoi(buf);
+	} else {
+		xml_add_new_item_to_section("misc", "statusbar", "1");
+		settings.statusbar = 1;
+	}
+
 #if 1
-	settings.browsing = 1;	/* unconditional - no longer toggle-able. */
+	settings.browsing = 1; /* unconditional - no longer toggle-able. */
 #else
 	if ((buf = xml_get_value("tabs", "browsing"))) {
-		settings.browsing =  atoi(buf);
+		settings.browsing = atoi(buf);
 	} else {
-		xml_add_new_item_to_section("tabs","browsing","1");
+		xml_add_new_item_to_section("tabs", "browsing", "1");
 		settings.browsing = 1;
 	}
 #endif
