@@ -1,8 +1,8 @@
 /*
  * Xiphos Bible Study Tool
- * utilities.h - support functions
+ * sidebar.h - sidebar interface to sword
  *
- * Copyright (C) 2000-2014 Xiphos Developer Team
+ * Copyright (C) 2000-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,8 @@ extern "C" {
 
 #include <gtk/gtk.h>
 
-typedef struct {
+typedef struct
+{
 	GdkPixbuf *pixbuf_opened;
 	GdkPixbuf *pixbuf_closed;
 	GdkPixbuf *pixbuf_helpdoc;
@@ -37,16 +38,19 @@ typedef struct {
 extern TreePixbufs *pixbufs;
 
 #ifdef USE_TREEVIEW_PATH
-gboolean main_expand_treeview_to_path (GtkTreeModel *model, GtkTreeIter iter);
+gboolean main_expand_treeview_to_path(GtkTreeModel *model,
+				      GtkTreeIter iter);
 #endif
 
-void main_open_bookmark_in_new_tab(gchar * mod_name, gchar * key);
-void main_display_verse_list_in_sidebar(gchar * key, gchar * module_name,
-						gchar * verse_list);
+void main_open_bookmark_in_new_tab(gchar *mod_name, gchar *key);
+void main_display_verse_list_in_sidebar(gchar *key,
+					gchar *module_name,
+					gchar *verse_list);
 void main_create_pixbufs(void);
-void main_load_module_tree(GtkWidget * tree);
-void main_add_mod_tree_columns(GtkTreeView * tree);
-void main_mod_treeview_button_one(GtkTreeModel *model, GtkTreeIter selected);
+void main_load_module_tree(GtkWidget *tree);
+void main_add_mod_tree_columns(GtkTreeView *tree);
+void main_mod_treeview_button_one(GtkTreeModel *model,
+				  GtkTreeIter selected);
 
 #ifdef __cplusplus
 }
