@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sword_treekey.h -  treekey stuff for book editor
  *
- * Copyright (C) 2008-2014 Xiphos Developer Team
+ * Copyright (C) 2008-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,20 +23,24 @@
 #define _SWORD_TREEKEY_HH
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
-unsigned long main_treekey_remove (char *book, char *name, char * offset);
-unsigned long main_treekey_append_sibling (char *book, char *name, char * offset);
-unsigned long main_treekey_append_child (char *book, char *name, char * offset);
-void main_treekey_set_local_name(char * book, char * name, char * offset);
-void main_load_book_tree_in_editor (GtkTreeView * treeview, char * book);
-char *main_get_book_raw_text (char *book, char * offset);
-void main_treekey_save_book_text (char *book, char * offset, char * text);
+unsigned long main_treekey_remove(char *book, char *name,
+				  char *offset);
+unsigned long main_treekey_append_sibling(char *book, char *name,
+					  char *offset);
+unsigned long main_treekey_append_child(char *book, char *name,
+					char *offset);
+void main_treekey_set_local_name(char *book, char *name,
+				 char *offset);
+void main_load_book_tree_in_editor(GtkTreeView *treeview,
+				   char *book);
+char *main_get_book_raw_text(char *book, char *offset);
+void main_treekey_save_book_text(char *book, char *offset,
+				 char *text);
 
 #ifdef __cplusplus
 }
 #endif
-
 #endif /* _SWORD_TREEKEY_HH */
