@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * tab_history.c - add, remove and navigate history
  *
- * Copyright (C) 2005-2014 Xiphos Developer Team
+ * Copyright (C) 2005-2015 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 
 #include <gtk/gtk.h>
 
-
 #include "gui/main_menu.h"
 #include "gui/main_window.h"
 #include "gui/tabbed_browser.h"
@@ -43,8 +42,8 @@
 #include "main/navbar_versekey.h"
 
 /* de-uglify all references to button sensitivitiy */
-# define BUTTON_BACK	navbar_versekey.button_history_back
-# define BUTTON_FORW	navbar_versekey.button_history_next
+#define BUTTON_BACK navbar_versekey.button_history_back
+#define BUTTON_FORW navbar_versekey.button_history_next
 
 /******************************************************************************
  * Name
@@ -64,8 +63,7 @@
  */
 
 void
-on_menu_historyitem_activate(GtkMenuItem * menuitem,
-			     gpointer user_data)
+on_menu_historyitem_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	main_change_verse_tab_history(GPOINTER_TO_INT(user_data));
 }
@@ -91,7 +89,7 @@ void main_clear_tab_history(void)
 	PASSAGE_TAB_INFO *tab = cur_passage_tab;
 
 	//gui_remove_menu_items(_("H_istory/<Separator>"),
-	//		      tab->history_items + 1);
+	//                    tab->history_items + 1);
 	//gui_add_separator2menu(widgets.app, _("H_istory/C_lear"));
 
 	/* set sensitivity of history buttons */
@@ -103,7 +101,6 @@ void main_clear_tab_history(void)
 	tab->first_back_click = TRUE;
 }
 
-
 /******************************************************************************
  * Name
  *   main_update_tab_history_menu
@@ -122,17 +119,17 @@ void main_clear_tab_history(void)
 
 void main_update_tab_history_menu(gpointer data)
 {
-	PASSAGE_TAB_INFO *tab = (PASSAGE_TAB_INFO*) data;
+	PASSAGE_TAB_INFO *tab = (PASSAGE_TAB_INFO *)data;
 
 	/* set sensitivity of history buttons */
 	gtk_widget_set_sensitive(BUTTON_BACK,
 				 (tab->current_history_item > 0));
 
 	gtk_widget_set_sensitive(BUTTON_FORW,
-				 (tab->current_history_item < (tab->history_items - 1)));
+				 (tab->current_history_item <
+				  (tab->history_items - 1)));
 }
 
-
 /******************************************************************************
  * Name
  *   main_add_tab_history_item
@@ -151,12 +148,13 @@ void main_update_tab_history_menu(gpointer data)
 void main_add_tab_history_item(gpointer data)
 {
 	gint i;
-	PASSAGE_TAB_INFO *tab = (PASSAGE_TAB_INFO*) data;
+	PASSAGE_TAB_INFO *tab = (PASSAGE_TAB_INFO *)data;
 
 	/* check to see if item is already in list
 	   if so do nothing except set button sensitivity */
 	for (i = 0; i < tab->history_items; ++i) {
-		if (!strcmp(tab->history_list[i].verseref, tab->text_commentary_key)) {
+		if (!strcmp(tab->history_list[i].verseref,
+			    tab->text_commentary_key)) {
 			tab->current_history_item = i;
 			main_update_tab_history_menu(data);
 			return;
@@ -172,11 +170,14 @@ void main_add_tab_history_item(gpointer data)
 	}
 
 	/* add item to history menu */
-	strcpy(tab->history_list[tab->history_items].verseref, tab->text_commentary_key);
+	strcpy(tab->history_list[tab->history_items].verseref,
+	       tab->text_commentary_key);
 	if (tab->text_mod)
-		strcpy(tab->history_list[tab->history_items].textmod, tab->text_mod);
+		strcpy(tab->history_list[tab->history_items].textmod,
+		       tab->text_mod);
 	if (tab->commentary_mod)
-		strcpy(tab->history_list[tab->history_items].commod, tab->commentary_mod);
+		strcpy(tab->history_list[tab->history_items].commod,
+		       tab->commentary_mod);
 
 	tab->current_history_item = tab->history_items;
 	++tab->history_items;
@@ -202,27 +203,29 @@ void main_add_tab_history_item(gpointer data)
  */
 void main_fake_tab_history_item(char *reference)
 {
-    PASSAGE_TAB_INFO *tab = cur_passage_tab;
-    int i;
+	PASSAGE_TAB_INFO *tab = cur_passage_tab;
 
-    /* if we have hit max length, dispose of oldest */
-    if (tab->history_items == TABHISTORYLENGTH) {
-	for (i = 0; i < (TABHISTORYLENGTH - 1); ++i) {
-	    tab->history_list[i] = tab->history_list[i + 1];
+	/* if we have hit max length, dispose of oldest */
+	if (tab->history_items == TABHISTORYLENGTH) {
+		int i;
+		for (i = 0; i < (TABHISTORYLENGTH - 1); ++i) {
+			tab->history_list[i] = tab->history_list[i + 1];
+		}
+		--tab->history_items;
 	}
-	--tab->history_items;
-    }
 
-    /* add item to history menu */
-    strcpy(tab->history_list[tab->history_items].verseref, reference);
-    if (tab->text_mod)
-	strcpy(tab->history_list[tab->history_items].textmod, tab->text_mod);
-    if (tab->commentary_mod)
-	strcpy(tab->history_list[tab->history_items].commod, tab->commentary_mod);
+	/* add item to history menu */
+	strcpy(tab->history_list[tab->history_items].verseref, reference);
+	if (tab->text_mod)
+		strcpy(tab->history_list[tab->history_items].textmod,
+		       tab->text_mod);
+	if (tab->commentary_mod)
+		strcpy(tab->history_list[tab->history_items].commod,
+		       tab->commentary_mod);
 
-    ++tab->history_items;
-    /* do not update what's current in history list. */
-    main_update_tab_history_menu(tab);
+	++tab->history_items;
+	/* do not update what's current in history list. */
+	main_update_tab_history_menu(tab);
 }
 
 /******************************************************************************
@@ -243,7 +246,7 @@ void main_fake_tab_history_item(char *reference)
  *   void
  */
 
-void on_clear_activate(GtkMenuItem * menuitem, gpointer user_data)
+void on_clear_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	main_clear_tab_history();
 }
@@ -265,24 +268,25 @@ void on_clear_activate(GtkMenuItem * menuitem, gpointer user_data)
  *   void
  */
 
-void on_history_to_verse_list_activate(GtkMenuItem * menuitem, gpointer user_data)
+void on_history_to_verse_list_activate(GtkMenuItem *menuitem,
+				       gpointer user_data)
 {
-    int i;
-    gboolean first = TRUE;
-    GString *list = g_string_new("");
+	int i;
+	gboolean first = TRUE;
+	GString *list = g_string_new("");
 
-    for (i = 0; i < cur_passage_tab->history_items; ++i) {
-	if (!first)
-	    g_string_append_c(list, ';');
-	g_string_append(list, cur_passage_tab->history_list[i].verseref);
-	first = FALSE;
-    }
+	for (i = 0; i < cur_passage_tab->history_items; ++i) {
+		if (!first)
+			g_string_append_c(list, ';');
+		g_string_append(list,
+				cur_passage_tab->history_list[i].verseref);
+		first = FALSE;
+	}
 
-    main_display_verse_list_in_sidebar
-	(settings.currentverse, settings.MainWindowModule, list->str);
+	main_display_verse_list_in_sidebar(settings.currentverse, settings.MainWindowModule, list->str);
 
-    g_string_free(list, TRUE);
-    return;
+	g_string_free(list, TRUE);
+	return;
 }
 
 GtkWidget *main_versekey_drop_down_new(gpointer data)
@@ -292,7 +296,7 @@ GtkWidget *main_versekey_drop_down_new(gpointer data)
 	GtkWidget *item;
 	PASSAGE_TAB_INFO *tab = NULL;
 
-	tab = (PASSAGE_TAB_INFO*) data;
+	tab = (PASSAGE_TAB_INFO *)data;
 	menu = gtk_menu_new();
 
 	item = gtk_menu_item_new_with_label(_("Clear History"));
@@ -304,24 +308,25 @@ GtkWidget *main_versekey_drop_down_new(gpointer data)
 	item = gtk_menu_item_new_with_label(_("History ➛ Verse List"));
 	gtk_widget_show(item);
 	g_signal_connect(G_OBJECT(item), "activate",
-			 G_CALLBACK(on_history_to_verse_list_activate), NULL);
+			 G_CALLBACK(on_history_to_verse_list_activate),
+			 NULL);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 
 	for (i = 0; i < tab->history_items; ++i) {
-		item = gtk_menu_item_new_with_label(tab->history_list[i].verseref);
+		item =
+		    gtk_menu_item_new_with_label(tab->history_list[i].verseref);
 		gtk_widget_show(item);
 		gtk_container_add(GTK_CONTAINER(menu), item);
 		g_signal_connect(G_OBJECT(item), "activate",
-				   G_CALLBACK
-				   (on_menu_historyitem_activate),
-				   GINT_TO_POINTER(i));
-		if (!strcmp(tab->history_list[i].verseref, tab->text_commentary_key))
-			gtk_widget_set_sensitive(item,FALSE);
+				 G_CALLBACK(on_menu_historyitem_activate),
+				 GINT_TO_POINTER(i));
+		if (!strcmp(tab->history_list[i].verseref,
+			    tab->text_commentary_key))
+			gtk_widget_set_sensitive(item, FALSE);
 	}
 	return menu;
 }
 
-
 /******************************************************************************
  * Name
  *   main_change_verse_tab_history
@@ -346,18 +351,20 @@ void main_change_verse_tab_history(gint historynum)
 	tab->current_history_item = historynum;
 	settings.addhistoryitem = tab->first_back_click;
 
-	XI_print(("commod = %s\n",tab->history_list[historynum].commod));
-	XI_print(("textmod = %s\n",tab->history_list[historynum].textmod));
+	XI_print(("commod = %s\n", tab->history_list[historynum].commod));
+	XI_print(("textmod = %s\n",
+		  tab->history_list[historynum].textmod));
 
-	key = main_update_nav_controls(tab->history_list[historynum].textmod,
-				       tab->history_list[historynum].verseref);
+	key =
+	    main_update_nav_controls(tab->history_list[historynum].textmod,
+				     tab->history_list[historynum].verseref);
 	main_display_commentary(tab->history_list[historynum].commod, key);
 	main_display_bible(tab->history_list[historynum].textmod, key);
 	main_keep_bibletext_dialog_in_sync(key);
-	if (key) g_free(key);
+	if (key)
+		g_free(key);
 }
 
-
 /******************************************************************************
  * Name
  *   main_navigate_tab_history
@@ -398,6 +405,6 @@ void main_navigate_tab_history(gint direction)
 		}
 	}
 
-	main_update_tab_history_menu((gpointer) tab);
+	main_update_tab_history_menu((gpointer)tab);
 	settings.addhistoryitem = TRUE;
 }
